@@ -1,7 +1,7 @@
 /* acconfig.h
  * #ifdefs to be controlled by "configure"
  *
- * $Id: acconfig.h,v 1.18 2000/10/17 09:21:51 guy Exp $
+ * $Id: acconfig.h,v 1.19 2001/06/02 06:21:13 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -37,7 +37,7 @@
 
 #undef NEED_STRERROR_H
 
-#undef NEED_MKSTEMP
+#undef NEED_STRPTIME_H
 
 #undef HAVE_LIBPCAP
 
