@@ -1,7 +1,7 @@
 /* capture.c
  * Routines for packet capture windows
  *
- * $Id: capture.c,v 1.149 2001/05/01 00:18:46 guy Exp $
+ * $Id: capture.c,v 1.153 2001/06/18 01:49:16 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -299,7 +299,7 @@ do_capture(char *capfile_name)
     }
     return;
   }
-  close_cap_file(&cfile, info_bar);
+  close_cap_file(&cfile);
   g_assert(cfile.save_file == NULL);
   cfile.save_file = capfile_name;
 
@@ -536,27 +536,30 @@ do_capture(char *capfile_name)
     } else {
       /* Failure - the child process sent us a message indicating
 	 what the problem was. */
-      msg = g_malloc(byte_count + 1);
-      if (msg == NULL) {
-	simple_dialog(ESD_TYPE_WARN, NULL,
-		"Capture child process failed, but its error message was too big.");
-      } else if (byte_count == 0) {
-      	/* Zero-length message? */
+      if (byte_count == 0) {
+	/* Zero-length message? */
 	simple_dialog(ESD_TYPE_WARN, NULL,
 		"Capture child process failed, but its error message was empty.");
       } else {
-	i = read(sync_pipe[READ], msg, byte_count);
-	if (i < 0) {
+	msg = g_malloc(byte_count + 1);
+	if (msg == NULL) {
 	  simple_dialog(ESD_TYPE_WARN, NULL,
+		"Capture child process failed, but its error message was too big.");
+	} else {
+	  i = read(sync_pipe[READ], msg, byte_count);
+	  msg[byte_count] = '\0';
+	  if (i < 0) {
+	    simple_dialog(ESD_TYPE_WARN, NULL,
 		  "Capture child process failed: Error %s reading its error message.",
 		  strerror(errno));
-	} else if (i == 0) {
-	  simple_dialog(ESD_TYPE_WARN, NULL,
+	  } else if (i == 0) {
+	    simple_dialog(ESD_TYPE_WARN, NULL,
 		  "Capture child process failed: EOF reading its error message.");
-	  wait_for_child(FALSE);
-	} else
-	  simple_dialog(ESD_TYPE_WARN, NULL, msg);
-	g_free(msg);
+	    wait_for_child(FALSE);
+	  } else
+	    simple_dialog(ESD_TYPE_WARN, NULL, msg);
+	  g_free(msg);
+	}
 
 	/* Close the sync pipe. */
 	close(sync_pipe[READ]);
@@ -1205,7 +1208,8 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
   bpf_u_int32 netnum, netmask;
   struct bpf_program fcode;
   time_t      upd_time, cur_time;
-  int         err, inpkts, i;
+  int         err, inpkts;
+  unsigned int i;
   static const char capstart_msg = SP_CAPSTART;
   char        errmsg[4096+1];
 #ifndef _WIN32
@@ -1230,17 +1234,17 @@ capture(gboolean *stats_known, struct pcap_stat *stats)
       gint *value_ptr;
       GtkWidget *label, *value, *percent;
   } counts[] = {
-      { "Total", &ld.counts.total },
-      { "SCTP", &ld.counts.sctp },
-      { "TCP", &ld.counts.tcp },
-      { "UDP", &ld.counts.udp },
-      { "ICMP", &ld.counts.icmp },
-      { "OSPF", &ld.counts.ospf },
-      { "GRE", &ld.counts.gre },
-      { "NetBIOS", &ld.counts.netbios },
-      { "IPX", &ld.counts.ipx },
-      { "VINES", &ld.counts.vines },
-      { "Other", &ld.counts.other }
+      { "Total", &ld.counts.total, NULL, NULL, NULL },
+      { "SCTP", &ld.counts.sctp, NULL, NULL, NULL },
+      { "TCP", &ld.counts.tcp, NULL, NULL, NULL },
+      { "UDP", &ld.counts.udp, NULL, NULL, NULL },
+      { "ICMP", &ld.counts.icmp, NULL, NULL, NULL },
+      { "OSPF", &ld.counts.ospf, NULL, NULL, NULL },
+      { "GRE", &ld.counts.gre, NULL, NULL, NULL },
+      { "NetBIOS", &ld.counts.netbios, NULL, NULL, NULL },
+      { "IPX", &ld.counts.ipx, NULL, NULL, NULL },
+      { "VINES", &ld.counts.vines, NULL, NULL, NULL },
+      { "Other", &ld.counts.other, NULL, NULL, NULL }
   };
 
 #define N_COUNTS (sizeof counts / sizeof counts[0])
