@@ -1,6 +1,6 @@
 /* epan.h
  *
- * $Id: epan.c,v 1.6 2001/02/01 20:21:16 gram Exp $
+ * $Id: epan.c,v 1.10 2001/04/02 00:38:34 hagbard Exp $
  *
  * Ethereal Protocol Analyzer Library
  *
@@ -42,12 +42,14 @@
  * libraries are located.)
  */
 void
-epan_init(const char *plugin_dir)
+epan_init(const char *plugin_dir, void (register_all_protocols)(void),
+	  void (register_all_handoffs)(void))
 {
 	except_init();
 	tvbuff_init();
+	frame_data_init();
+	proto_init(plugin_dir,register_all_protocols,register_all_handoffs);
 	packet_init();
-	proto_init(plugin_dir);
 	dfilter_init();
 }
 
@@ -57,6 +59,7 @@ epan_cleanup(void)
 	dfilter_cleanup();
 	proto_cleanup();
 	packet_cleanup();
+	frame_data_cleanup();
 	tvbuff_cleanup();
 	except_deinit();
 }
@@ -77,6 +80,11 @@ epan_dissect_new(void* pseudo_header, const guint8* data, frame_data *fd, proto_
 
 	edt = g_new(epan_dissect_t, 1);
 
+	/* start with empty data source list */
+	if ( fd->data_src)
+                g_slist_free( fd->data_src);
+        fd->data_src = 0;
+
 	/* XXX - init tree */
 	edt->tree = tree;
 
