@@ -1,12 +1,11 @@
 /* packet.h
  * Definitions for packet disassembly structures and routines
  *
- * $Id: packet.h,v 1.32 2001/04/17 06:43:21 guy Exp $
+ * $Id: packet.h,v 1.35 2001/06/29 09:46:54 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -121,7 +120,6 @@ void dissector_add(const char *abbrev, guint32 pattern,
 
 /* Add a sub-dissector to a dissector table.  Called by the protocol routine */
 /* that wants to de-register a sub-dissector.  */
-void old_dissector_delete(const char *name, guint32 pattern, old_dissector_t dissector);
 void dissector_delete(const char *name, guint32 pattern, dissector_t dissector);
 
 /* Reset a dissector in a sub-dissector table to its initial value. */
@@ -132,8 +130,6 @@ void dissector_reset(const char *name, guint32 pattern);
 /* Look for a given port in a given dissector table and, if found, call
    the dissector with the arguments supplied, and return TRUE, otherwise
    return FALSE. */
-gboolean old_dissector_try_port(dissector_table_t sub_dissectors, guint32 port,
-    const u_char *pd, int offset, frame_data *fd, proto_tree *tree);
 gboolean dissector_try_port(dissector_table_t sub_dissectors, guint32 port,
     tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
@@ -144,8 +140,6 @@ gboolean dissector_try_port(dissector_table_t sub_dissectors, guint32 port,
 typedef GSList *heur_dissector_list_t;
 
 /* Type of a heuristic dissector */
-typedef gboolean (*old_heur_dissector_t)(const u_char *, int, frame_data *,
-	proto_tree *);
 typedef gboolean (*heur_dissector_t)(tvbuff_t *, packet_info *,
 	proto_tree *);
 
@@ -154,8 +148,6 @@ void register_heur_dissector_list(const char *name, heur_dissector_list_t *list)
 
 /* Add a sub-dissector to a heuristic dissector list.  Called by the
    protocol routine that wants to register a sub-dissector.  */
-void old_heur_dissector_add(const char *name, old_heur_dissector_t dissector,
-    int proto);
 void heur_dissector_add(const char *name, heur_dissector_t dissector,
     int proto);
 
@@ -184,15 +176,12 @@ void register_conv_dissector_list(const char *name, conv_dissector_list_t *list)
 
 /* Add a sub-dissector to a conversation dissector list.  Called by the
    protocol routine that wants to register a sub-dissector.  */
-void old_conv_dissector_add(const char *name, old_dissector_t dissector,
-    int proto);
 void conv_dissector_add(const char *name, dissector_t dissector,
     int proto);
 
 /* Opaque structure - provides type checking but no access to components */
 typedef struct conv_dtbl_entry conv_dtbl_entry_t;
 
-gboolean conv_dissector_get_old_flag (conv_dtbl_entry_t *entry);
 gint conv_dissector_get_proto (conv_dtbl_entry_t * entry);
 void dissector_conv_foreach(char *name, DATFunc func, gpointer user_data);
 void dissector_all_conv_foreach(DATFunc func, gpointer user_data);
@@ -217,6 +206,14 @@ void dissect_init(void);
 
 void dissect_cleanup(void);
 
+/*
+ * Given a tvbuff, a packet_info *, and a length from a packet header,
+ * adjust the length of the tvbuff, and the "len" and "captured_len"
+ * members of the "packet_info" structure, to reflect the specified
+ * length.
+ */
+void set_actual_length(tvbuff_t *tvb, packet_info *pinfo, guint specified_len);
+
 /* Allow protocols to register "init" routines, which are called before
    we make a pass through a capture file and dissect all its packets
    (e.g., when we read in a new capture file, or run a "filter packets"
