@@ -1,12 +1,11 @@
 /* packet_info.h
  * Definitions for packet info structures and routines
  *
- * $Id: packet_info.h,v 1.1 2001/04/01 04:50:42 hagbard Exp $
+ * $Id: packet_info.h,v 1.4 2001/06/04 07:27:50 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -55,6 +54,26 @@ typedef struct _address {
 	(addr)->data = (addr_data); \
 	}
 
+/*
+ * Given two addresses, return "true" if they're equal, "false" otherwise.
+ */
+#define ADDRESSES_EQUAL(addr1, addr2) \
+	((addr1)->type == (addr2)->type && \
+	 (addr1)->len == (addr2)->len && \
+	 memcmp((addr1)->data, (addr2)->data, (addr1)->len) == 0)
+
+/*
+ * Copy an address, allocating a new buffer for the address data.
+ */
+#define COPY_ADDRESS(to, from) { \
+	guint8 *COPY_ADDRESS_data; \
+	(to)->type = (from)->type; \
+	(to)->len = (from)->len; \
+	COPY_ADDRESS_data = g_malloc((from)->len); \
+	memcpy(COPY_ADDRESS_data, (from)->data, (from)->len); \
+	(to)->data = COPY_ADDRESS_data; \
+	}
+
 /* Types of port numbers Ethereal knows about. */
 typedef enum {
   PT_NONE,		/* no port number */
@@ -92,6 +111,15 @@ typedef struct _packet_info {
   int     iplen;
   int     iphdrlen;
   int	  p2p_dir;
+  union {
+    struct {
+      guint8	type;
+      guint8	flags;
+      guint16	serviceid;
+      guint32	callnumber;
+      guint32	seq;
+    } rx;			/* fields specific for RX protocol */
+  } ps;				/* protocol specific data */
 } packet_info;
 
 void blank_packetinfo(void);
