@@ -1,12 +1,11 @@
 /* proto.c
  * Routines for protocol tree
  *
- * $Id: proto.c,v 1.27 2001/05/09 01:22:46 guy Exp $
+ * $Id: proto.c,v 1.30 2001/07/13 00:55:53 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -169,7 +168,7 @@ proto_init(const char *plugin_dir,void (register_all_protocols)(void),
 	static hf_register_info hf[] = {
 		{ &hf_text_only,
 		{ "",	"", FT_NONE, BASE_NONE, NULL, 0x0,
-			NULL }},
+			NULL, HFILL }},
 	};
 
 	if (gmc_hfinfo)
@@ -2832,12 +2831,60 @@ hfinfo_numeric_format(header_field_info *hfinfo)
 	return format;
 }
 
+/*
+ * Returns TRUE if we can do a "match selected" on the field, FALSE
+ * otherwise.
+ */
+gboolean
+proto_can_match_selected(field_info *finfo)
+{
+	header_field_info	*hfinfo;
+
+	hfinfo = finfo->hfinfo;
+	g_assert(hfinfo);
+
+	switch(hfinfo->type) {
+
+		case FT_BOOLEAN:
+		case FT_UINT8:
+		case FT_UINT16:
+		case FT_UINT24:
+		case FT_UINT32:
+		case FT_INT8:
+		case FT_INT16:
+		case FT_INT24:
+		case FT_INT32:
+		case FT_IPv4:
+		case FT_IPXNET:
+		case FT_IPv6:
+		case FT_DOUBLE:
+		case FT_ETHER:
+		case FT_ABSOLUTE_TIME:
+		case FT_RELATIVE_TIME:
+		case FT_STRING:
+		case FT_BYTES:
+			/*
+			 * These all have values, so we can match.
+			 */
+			return TRUE;
+
+		default:
+			/*
+			 * This doesn't have a value, so we'd match
+			 * on the raw bytes at this address;
+			 * however, if the length is 0, there's nothing
+			 * to match, so we can't match.
+			 */
+			return (finfo->length != 0);
+	}
+}
+
 char*
 proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 {
 	header_field_info	*hfinfo;
 	int			abbrev_len;
-	char			*buf, *stringified, *format, *ptr;
+	char			*buf, *stringified, *format, *ptr, *value_str;
 	int			dfilter_len, i;
 	guint8			*c;
 
@@ -2905,25 +2952,37 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 					hfinfo->abbrev,
 					ether_to_str(fvalue_get(finfo->value)));
 			break;
-#if 0
 
 		case FT_ABSOLUTE_TIME:
-		case FT_RELATIVE_TIME:
-			memcpy(&fi->value.time, va_arg(ap, struct timeval*),
-				sizeof(struct timeval));
+			value_str =
+			    abs_time_to_str((struct timeval *)fvalue_get(finfo->value));
+			dfilter_len = abbrev_len + strlen(value_str) + 7;
+			buf = g_malloc0(dfilter_len);
+			snprintf(buf, dfilter_len, "%s == \"%s\"",
+					hfinfo->abbrev, value_str);
 			break;
 
+		case FT_RELATIVE_TIME:
+			value_str =
+			    rel_time_to_str((struct timeval *)fvalue_get(finfo->value));
+			dfilter_len = abbrev_len + strlen(value_str) + 4;
+			buf = g_malloc0(dfilter_len);
+			snprintf(buf, dfilter_len, "%s == %s",
+					hfinfo->abbrev, value_str);
+			break;
+
+#if 0
 		case FT_TEXT_ONLY:
 			; /* nothing */
 			break;
 #endif
 
 		case FT_STRING:
-			dfilter_len = abbrev_len + 
-			  strlen(fvalue_get(finfo->value)) + 7;
+			value_str = fvalue_get(finfo->value);
+			dfilter_len = abbrev_len + strlen(value_str) + 7;
 			buf = g_malloc0(dfilter_len);
 			snprintf(buf, dfilter_len, "%s == \"%s\"",
-				 hfinfo->abbrev, (char*)fvalue_get(finfo->value));
+				 hfinfo->abbrev, value_str);
 			break;
 
 		case FT_BYTES:
@@ -2934,6 +2993,7 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 				 hfinfo->abbrev,
 				 bytes_to_str_punct(fvalue_get(finfo->value), finfo->length,':'));
 			break;       
+
 		default:
 			c = pd + finfo->start;
 			buf = g_malloc0(32 + finfo->length * 3);
