@@ -1,12 +1,11 @@
 /* proto.h
  * Definitions for protocol display
  *
- * $Id: proto.h,v 1.11 2001/04/02 00:38:34 hagbard Exp $
+ * $Id: proto.h,v 1.13 2001/06/18 02:18:24 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -103,7 +102,12 @@ struct _header_field_info {
 	header_field_info		*same_name_prev; /* Link to previous hfinfo with same abbrev*/
 };
 
-
+/*
+ * HFILL initializes all the "set by proto routines" fields in a
+ * "header_field_info"; if new fields are added or removed, it should
+ * be changed as necessary.
+ */
+#define HFILL 0, 0, 0, NULL, NULL
 
 /* Used when registering many fields at once */
 typedef struct hf_register_info {
@@ -559,6 +563,13 @@ extern int           num_tree_types;
 int
 hfinfo_bitwidth(header_field_info *hfinfo);
 
+/*
+ * Returns TRUE if we can do a "match selected" on the field, FALSE
+ * otherwise.
+ */
+gboolean
+proto_can_match_selected(field_info *finfo);
+
 char*
 proto_alloc_dfilter_string(field_info *finfo, guint8 *pd);
 
