@@ -9,14 +9,13 @@
  * 		the data of a backing tvbuff, or can be a composite of
  * 		other tvbuffs.
  *
- * $Id: tvbuff.c,v 1.16 2001/03/23 14:44:02 jfoster Exp $
+ * $Id: tvbuff.c,v 1.18 2001/07/02 07:11:40 guy Exp $
  *
  * Copyright (c) 2000 by Gilbert Ramirez <gram@xiexie.org>
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1218,7 +1217,10 @@ tvb_strnlen(tvbuff_t *tvb, gint offset, guint maxlength)
  * Implement strneql etc
  */
 
-/* Call strncmp after checking if enough chars left, otherwise return -1 */
+/*
+ * Call strncmp after checking if enough chars left, returning 0 if
+ * it returns 0 (meaning "equal") and -1 otherwise, otherwise return -1.
+ */
 gint
 tvb_strneql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
 {
@@ -1242,7 +1244,10 @@ tvb_strneql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
 	}
 }
 
-/* Call strncasecmp after checking if enough chars left, otherwise return -1 */
+/*
+ * Call strncasecmp after checking if enough chars left, returning 0 if
+ * it returns 0 (meaning "equal") and -1 otherwise, otherwise return -1.
+ */
 gint
 tvb_strncaseeql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
 {
@@ -1266,6 +1271,33 @@ tvb_strncaseeql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
 	}
 }
 
+/*
+ * Call memcmp after checking if enough chars left, returning 0 if
+ * it returns 0 (meaning "equal") and -1 otherwise, otherwise return -1.
+ */
+gint
+tvb_memeql(tvbuff_t *tvb, gint offset, const guint8 *str, gint size)
+{
+	guint8 *ptr;
+
+	ptr = ensure_contiguous(tvb, offset, size);
+
+	if (ptr) {
+		int cmp = memcmp(ptr, str, size);
+
+		/*
+		 * Return 0 if equal, -1 otherwise.
+		 */
+		return (cmp == 0 ? 0 : -1);
+	} else {
+		/*
+		 * Not enough characters in the tvbuff to match the
+		 * string.
+		 */
+		return -1;
+	}
+}
+
 /*
  * Format the data in the tvb from offset for length ...
  */
