@@ -1,12 +1,11 @@
 /* file.c
  * File I/O routines
  *
- * $Id: file.c,v 1.236 2001/05/01 00:18:46 guy Exp $
+ * $Id: file.c,v 1.242 2001/07/05 00:34:38 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -83,16 +82,17 @@
 #include "simple_dialog.h"
 #include "progress_dlg.h"
 #include "ui_util.h"
+#include "statusbar.h"
 #include "prefs.h"
 #include "gtk/proto_draw.h"
 #include "gtk/packet_win.h"
 #include "dfilter/dfilter.h"
 #include "conversation.h"
+#include "reassemble.h"
 #include "globals.h"
 #include "gtk/colors.h"
 
-extern GtkWidget *packet_list, *info_bar, *byte_nb_ptr, *tree_view;
-extern guint      file_ctx;
+extern GtkWidget *packet_list, *byte_nb_ptr, *tree_view;
 
 static guint32 firstsec, firstusec;
 static guint32 prevsec, prevusec;
@@ -123,7 +123,6 @@ open_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
 {
   wtap       *wth;
   int         err;
-  FILE_T      fh;
   int         fd;
   struct stat cf_stat;
 
@@ -132,7 +131,6 @@ open_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
     goto fail;
 
   /* Find the size of the file. */
-  fh = wtap_file(wth);
   fd = wtap_fd(wth);
   if (fstat(fd, &cf_stat) < 0) {
     err = errno;
@@ -142,7 +140,7 @@ open_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
 
   /* The open succeeded.  Close whatever capture file we had open,
      and fill in the information for this file. */
-  close_cap_file(cf, info_bar);
+  close_cap_file(cf);
 
   /* Initialize the table of conversations. */
   epan_conversation_init();
@@ -150,6 +148,12 @@ open_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
   /* Initialize protocol-specific variables */
   init_all_protocols();
 
+  /* Initialize the common data structures for fragment reassembly.
+     Must be done *after* "init_all_protocols()", as "init_all_protocols()"
+     may free up space for fragments, which it finds by using the
+     data structures that "reassemble_init()" frees. */
+  reassemble_init();
+
   /* We're about to start reading the file. */
   cf->state = FILE_READ_IN_PROGRESS;
 
@@ -196,7 +200,7 @@ fail:
 
 /* Reset everything to a pristine state */
 void
-close_cap_file(capture_file *cf, void *w)
+close_cap_file(capture_file *cf)
 {
   /* Die if we're in the middle of reading a file. */
   g_assert(cf->state != FILE_READ_IN_PROGRESS);
@@ -242,7 +246,7 @@ close_cap_file(capture_file *cf, void *w)
   /* Clear any file-related status bar messages.
      XXX - should be "clear *ALL* file-related status bar messages;
      will there ever be more than one on the stack? */
-  gtk_statusbar_pop(GTK_STATUSBAR(w), file_ctx);
+  statusbar_pop_file_msg();
 
   /* Restore the standard title bar message. */
   set_main_window_name("The Ethereal Network Analyzer");
@@ -291,7 +295,7 @@ set_display_filename(capture_file *cf)
     done_msg = g_malloc(msg_len);
     snprintf(done_msg, msg_len, done_fmt_nodrops, name_ptr);
   }
-  gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, done_msg);
+  statusbar_push_file_msg(done_msg);
   g_free(done_msg);
 
   msg_len = strlen(name_ptr) + strlen(win_name_fmt) + 1;
@@ -320,7 +324,7 @@ read_cap_file(capture_file *cf, int *err)
   msg_len = strlen(name_ptr) + strlen(load_fmt) + 2;
   load_msg = g_malloc(msg_len);
   snprintf(load_msg, msg_len, load_fmt, name_ptr);
-  gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, load_msg);
+  statusbar_push_file_msg(load_msg);
 
   /* Update the progress bar when it gets to this value. */
   cf->progbar_nextstep = 0;
@@ -358,7 +362,7 @@ read_cap_file(capture_file *cf, int *err)
       destroy_progress_dlg(progbar);
       cf->state = FILE_READ_ABORTED;	/* so that we're allowed to close it */
       gtk_clist_thaw(GTK_CLIST(packet_list));	/* undo our freeze */
-      close_cap_file(cf, info_bar);
+      close_cap_file(cf);
       return (READ_ABORTED);
     }
     read_packet(cf, data_offset);
@@ -382,7 +386,7 @@ read_cap_file(capture_file *cf, int *err)
   cf->current_frame = cf->first_displayed;
   thaw_clist(cf);
 
-  gtk_statusbar_pop(GTK_STATUSBAR(info_bar), file_ctx);
+  statusbar_pop_file_msg();
   set_display_filename(cf);
 
   /* Enable menu items that make sense if you have a capture file you've
@@ -464,8 +468,7 @@ start_tail_cap_file(char *fname, gboolean is_tempfile, capture_file *cf)
       }
     }
 
-    gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, 
-		       " <live capture in progress>");
+    statusbar_push_file_msg(" <live capture in progress>");
   }
   return err;
 }
@@ -534,7 +537,7 @@ finish_tail_cap_file(capture_file *cf, int *err)
        it's probably exited), so we can just close the capture
        file; we return READ_ABORTED so our caller can do whatever
        is appropriate when that happens. */
-    close_cap_file(cf, info_bar);
+    close_cap_file(cf);
     return READ_ABORTED;
   }
 
@@ -559,7 +562,7 @@ finish_tail_cap_file(capture_file *cf, int *err)
   cf->lnk_t = wtap_file_encap(cf->wth);
 
   /* Pop the "<live capture in progress>" message off the status bar. */
-  gtk_statusbar_pop(GTK_STATUSBAR(info_bar), file_ctx);
+  statusbar_pop_file_msg();
 
   set_display_filename(cf);
 
@@ -888,7 +891,7 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
   gboolean stop_flag;
   guint32 progbar_quantum;
   guint32 progbar_nextstep;
-  int count;
+  unsigned int count;
   frame_data *selected_frame;
   int selected_row;
   int row;
@@ -914,6 +917,12 @@ rescan_packets(capture_file *cf, const char *action, gboolean refilter,
 
     /* Initialize protocol-specific variables */
     init_all_protocols();
+
+    /* Initialize the common data structures for fragment reassembly.
+       Must be done *after* "init_all_protocols()", as "init_all_protocols()"
+       may free up space for fragments, which it finds by using the
+       data structures that "reassemble_init()" frees. */
+    reassemble_init();
   }
 
   /* Freeze the packet list while we redo it, so we don't get any
@@ -1225,7 +1234,7 @@ print_packets(capture_file *cf, print_args_t *print_args)
 
         /* Print the information in that tree. */
         proto_tree_print(FALSE, print_args, (GNode *)protocol_tree,
-			cf->pd, fdata, cf->print_fh);
+			fdata, cf->print_fh);
 
         proto_tree_free(protocol_tree);
 
@@ -1271,7 +1280,7 @@ change_time_formats(capture_file *cf)
   gboolean stop_flag;
   guint32 progbar_quantum;
   guint32 progbar_nextstep;
-  int count;
+  unsigned int count;
   int row;
   int i;
   GtkStyle  *pl_style;
@@ -1368,34 +1377,6 @@ change_time_formats(capture_file *cf)
   thaw_clist(cf);
 }
 
-static void
-clear_tree_and_hex_views(void)
-{
-  /* Clear the hex dump. */
-
-  GtkWidget *byte_view;
-  int i;
-
-/* Get the current tab scroll window, then get the text widget  */
-/* from the E_BYTE_VIEW_TEXT_INFO_KEY data field 		*/
-
-  i = gtk_notebook_get_current_page( GTK_NOTEBOOK(byte_nb_ptr));
-
-  if ( i >= 0){
-    byte_view = gtk_notebook_get_nth_page( GTK_NOTEBOOK(byte_nb_ptr), i);
-    byte_view = gtk_object_get_data(GTK_OBJECT(byte_view), E_BYTE_VIEW_TEXT_INFO_KEY);
-
-    gtk_text_freeze(GTK_TEXT(byte_view));
-    gtk_text_set_point(GTK_TEXT(byte_view), 0);
-    gtk_text_forward_delete(GTK_TEXT(byte_view),
-      gtk_text_get_length(GTK_TEXT(byte_view)));
-    gtk_text_thaw(GTK_TEXT(byte_view));
-  }
-  /* Remove all nodes in ctree. This is how it's done in testgtk.c in GTK+ */
-  gtk_clist_clear ( GTK_CLIST(tree_view) );
-
-}
-
 gboolean
 find_packet(capture_file *cf, dfilter_t *sfcode)
 {
@@ -1406,7 +1387,7 @@ find_packet(capture_file *cf, dfilter_t *sfcode)
   gboolean stop_flag;
   guint32 progbar_quantum;
   guint32 progbar_nextstep;
-  int count;
+  unsigned int count;
   proto_tree *protocol_tree;
   gboolean frame_matched;
   int row;
@@ -1586,6 +1567,10 @@ select_packet(capture_file *cf, int row)
       proto_tree_free(cf->protocol_tree);
   cf->protocol_tree = proto_tree_create_root();
   proto_tree_is_visible = TRUE;
+  if (cf->edt != NULL) {
+    epan_dissect_free(cf->edt);
+    cf->edt = NULL;
+  }
   cf->edt = epan_dissect_new(&cf->pseudo_header, cf->pd, cf->current_frame,
 		cf->protocol_tree);
   proto_tree_is_visible = FALSE;
@@ -1610,20 +1595,24 @@ select_packet(capture_file *cf, int row)
 void
 unselect_packet(capture_file *cf)
 {
-  /* Destroy the protocol tree for that packet. */
+  /* Destroy the protocol tree and epan_dissect_t for that packet. */
   if (cf->protocol_tree != NULL) {
     proto_tree_free(cf->protocol_tree);
     cf->protocol_tree = NULL;
-    epan_dissect_free(cf->edt);
   }
-
-  finfo_selected = NULL;
+  if (cf->edt != NULL) {
+    epan_dissect_free(cf->edt);
+    cf->edt = NULL;
+  }
 
   /* Clear out the display of that packet. */
   clear_tree_and_hex_views();
 
   /* No packet is selected. */
   set_menus_for_selected_packet(FALSE);
+
+  /* No protocol tree means no selected field. */
+  unselect_field();
 }
 
 /* Set the selected row and the focus row of the packet list to the specified
@@ -1647,6 +1636,15 @@ set_selected_row(int row)
   gtk_clist_select_row(GTK_CLIST(packet_list), row, -1);
 }
 
+/* Unset the selected protocol tree field, if any. */
+void
+unselect_field(void)
+{
+  statusbar_pop_field_msg();
+  finfo_selected = NULL;
+  set_menus_for_selected_tree_row(FALSE);
+}
+
 static void
 freeze_clist(capture_file *cf)
 {
@@ -1704,7 +1702,7 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
   msg_len = strlen(name_ptr) + strlen(save_fmt) + 2;
   save_msg = g_malloc(msg_len);
   snprintf(save_msg, msg_len, save_fmt, name_ptr);
-  gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, save_msg);
+  statusbar_push_file_msg(save_msg);
   g_free(save_msg);
 
   if (!save_filtered && !save_marked && save_format == cf->cd_t) {
@@ -1816,7 +1814,7 @@ save_cap_file(char *fname, capture_file *cf, gboolean save_filtered, gboolean sa
 done:
 
   /* Pop the "Saving:" message off the status bar. */
-  gtk_statusbar_pop(GTK_STATUSBAR(info_bar), file_ctx);
+  statusbar_pop_file_msg();
   if (err == 0) {
     if (!save_filtered && !save_marked) {
       /* We saved the entire capture, not just some packets from it.
