@@ -1,12 +1,11 @@
 /* globals.h
  * Global defines, etc.
  *
- * $Id: globals.h,v 1.25 2001/05/01 00:18:46 guy Exp $
+ * $Id: globals.h,v 1.26 2001/06/05 07:38:33 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,7 +32,6 @@
 #define MIN_PACKET_SIZE 68	/* minimum amount of packet data we can read */
 
 extern capture_file cfile;
-extern guint        main_ctx, file_ctx;
 extern gchar       *ethereal_path;
 extern gchar       *last_open_dir;
 extern field_info  *finfo_selected;
