@@ -1,6 +1,6 @@
 /* decode_as_dlg.c
  *
- * $Id: decode_as_dlg.c,v 1.6 2001/04/23 17:51:37 guy Exp $
+ * $Id: decode_as_dlg.c,v 1.9 2001/06/25 08:10:38 guy Exp $
  *
  * Routines to modify dissector tables on the fly.
  *
@@ -612,9 +612,6 @@ decode_network (GtkWidget *notebook_pg)
     /* Now tweak a local table of protocol ids currently decoded as TCP/UDP */
     port_num = GPOINTER_TO_INT(gtk_object_get_data(GTK_OBJECT(notebook_pg),
 						E_PAGE_VALUE));
-    clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(notebook_pg), E_PAGE_CLIST));
-    row = GPOINTER_TO_INT(clist->selection->data);
-    assigned = GPOINTER_TO_INT(gtk_clist_get_row_data(clist, row));
 
     /* Ignore changes to the normal TCP and UDP protocol numbers */
     if ((port_num == IP_PROTO_TCP) || (port_num == IP_PROTO_UDP))
@@ -627,7 +624,12 @@ decode_network (GtkWidget *notebook_pg)
 	return;
     }
 
-    /* Not assigning TCP or UDP - remove any entry for this IP protocol number */
+    /* Not assigning TCP or UDP - remove any entry for this IP protocol number.
+       Note: if the action was E_DECODE_NO, the selection on the clist
+       was cleared, so the code to get "row" below would blow up. */
+    clist = GTK_CLIST(gtk_object_get_data(GTK_OBJECT(notebook_pg), E_PAGE_CLIST));
+    row = GPOINTER_TO_INT(clist->selection->data);
+    assigned = GPOINTER_TO_INT(gtk_clist_get_row_data(clist, row));
     if ((assigned != IP_PROTO_TCP) && (assigned != IP_PROTO_UDP)) {
 	decode_as_tcpudp =
 	    g_slist_remove(decode_as_tcpudp, GINT_TO_POINTER(port_num));
@@ -1023,7 +1025,7 @@ decode_add_to_clist (gchar *table_name, gpointer key,
     clist = info->clist;
     if (info->conv) {
 	proto = conv_dissector_get_proto(value);
-	isold = conv_dissector_get_old_flag(value) ? "TRUE" : "FALSE";
+	isold = "FALSE";
 	isconv = "TRUE";
     } else {
 	proto = dissector_get_proto(value);
@@ -1185,8 +1187,8 @@ decode_add_transport_menu (GtkWidget *page)
 /**************************************************/
 
 /*
- * This routine creates a somple notebook page ni the dialog box.
- * This notebook page provides a promp specifying what is being
+ * This routine creates a somple notebook page in the dialog box.
+ * This notebook page provides a prompt specifying what is being
  * changed and its current value (e.g. "IP Protocol number (17)"), and
  * a clist specifying all the available choices.  The list of choices
  * is conditionally enabled, based upon the setting of the
