@@ -1,6 +1,6 @@
 /* main.c
  *
- * $Id: main.c,v 1.198 2001/05/01 00:41:46 guy Exp $
+ * $Id: main.c,v 1.203 2001/07/05 00:34:40 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -79,6 +79,10 @@
 #include <pcap.h>
 #endif
 
+#ifdef HAVE_LIBZ
+#include <zlib.h>	/* to get the libz version number */
+#endif
+
 #ifdef NEED_SNPRINTF_H
 # include "snprintf.h"
 #endif
@@ -126,6 +130,7 @@
 #include "print.h"
 #include "resolv.h"
 #include "util.h"
+#include "statusbar.h"
 #include "simple_dialog.h"
 #include "proto_draw.h"
 #include "dfilter/dfilter.h"
@@ -146,11 +151,11 @@
 packet_info  pi;
 capture_file cfile;
 GtkWidget   *top_level, *packet_list, *tree_view, *byte_nb_ptr,
-            *info_bar, *tv_scrollw, *pkt_scrollw;
-static GtkWidget	*bv_scrollw;
+            *tv_scrollw, *pkt_scrollw;
+static GtkWidget	*info_bar, *bv_scrollw;
 GdkFont     *m_r_font, *m_b_font;
 guint		m_font_height, m_font_width;
-guint        main_ctx, file_ctx, help_ctx;
+static guint    main_ctx, file_ctx, help_ctx;
 static GString *comp_info_str;
 gchar       *ethereal_path = NULL;
 gchar       *last_open_dir = NULL;
@@ -211,14 +216,6 @@ match_selected_cb(GtkWidget *w, gpointer data)
 
     filter_te = gtk_object_get_data(GTK_OBJECT(w), E_DFILTER_TE_KEY);
 
-    if (!finfo_selected) {
-	simple_dialog(ESD_TYPE_CRIT, NULL,
-		      "Error determining selected bytes.  Please make\n"
-		      "sure you have selected a field within the tree\n"
-		      "view to be matched.");
-	return;
-    }
-
     buf = proto_alloc_dfilter_string(finfo_selected, cfile.pd);
 
     /* create a new one and set the display filter entry accordingly */
@@ -463,7 +460,6 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 	g_assert(byte_data);
 
 	finfo_selected = finfo;
-
 	set_menus_for_selected_tree_row(TRUE);
 
 	if (finfo->hfinfo) {
@@ -474,13 +470,14 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 	  } else {
 	    length = strlen(finfo->hfinfo->name);
 	  }
+	  statusbar_pop_field_msg();	/* get rid of current help msg */
           if (length) {
 	    length += strlen(finfo->hfinfo->abbrev) + 10;
 	    help_str = g_malloc(sizeof(gchar) * length);
 	    sprintf(help_str, "%s (%s)", 
 	       (has_blurb) ? finfo->hfinfo->blurb : finfo->hfinfo->name,
 	       finfo->hfinfo->abbrev);
-	    gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, help_str);
+	    statusbar_push_field_msg(help_str);
 	    g_free(help_str);
           } else {
             /*
@@ -489,6 +486,9 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 	     * a field, and we don't want "Text (text)" showing up
 	     * on the status line if you've selected such a field.
 	     *
+	     * XXX - there are zero-length fields for which we *do*
+	     * want to show the field name.
+	     *
 	     * XXX - perhaps the name and abbrev field should be null
 	     * pointers rather than null strings for that pseudo-field,
 	     * but we'd have to add checks for null pointers in some
@@ -499,7 +499,7 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 	     * with no pseudo-field being used, but that might also
 	     * require special checks for -1 to be added.
 	     */
-	    gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, "");
+	    statusbar_push_field_msg("");
           }
 	}
 
@@ -513,16 +513,16 @@ tree_view_unselect_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer us
 	GtkWidget	*byte_view;
 	guint8	*data;
 	gint	len;	
-	field_info* fi;
-
-	fi = (field_info*)user_data;
 
+	/*
+	 * Which byte view is displaying the current protocol tree
+	 * row's data?
+	 */
 	len = get_byte_view_and_data( byte_nb_ptr, &byte_view, &data);
+	if ( len < 0)
+		return;	/* none */
 
-	if ( len < 0) return;
-	gtk_statusbar_pop(GTK_STATUSBAR(info_bar), help_ctx);
-	finfo_selected = NULL;
-	set_menus_for_selected_tree_row(FALSE);
+	unselect_field();
 	packet_hex_print(GTK_TEXT(byte_view), data, cfile.current_frame,
 		NULL, len);
 }
@@ -539,8 +539,8 @@ void expand_all_cb(GtkWidget *widget, gpointer data) {
 
 void resolve_name_cb(GtkWidget *widget, gpointer data) {
   if (cfile.protocol_tree) {
-    int tmp = prefs.name_resolve;
-    prefs.name_resolve = 1;
+    gint tmp = prefs.name_resolve;
+    prefs.name_resolve = PREFS_RESOLV_ALL;
     gtk_clist_clear ( GTK_CLIST(tree_view) );
     proto_tree_draw(cfile.protocol_tree, tree_view);
     prefs.name_resolve = tmp;
@@ -663,6 +663,46 @@ set_plist_font(GdkFont *font)
 	}
 }
 
+/*
+ * Push a message referring to file access onto the statusbar.
+ */
+void
+statusbar_push_file_msg(gchar *msg)
+{
+	gtk_statusbar_push(GTK_STATUSBAR(info_bar), file_ctx, msg);
+}
+
+/*
+ * Pop a message referring to file access off the statusbar.
+ */
+void
+statusbar_pop_file_msg(void)
+{
+	gtk_statusbar_pop(GTK_STATUSBAR(info_bar), file_ctx);
+}
+
+/*
+ * XXX - do we need multiple statusbar contexts?
+ */
+
+/*
+ * Push a message referring to the currently-selected field onto the statusbar.
+ */
+void
+statusbar_push_field_msg(gchar *msg)
+{
+	gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, msg);
+}
+
+/*
+ * Pop a message referring to the currently-selected field off the statusbar.
+ */
+void
+statusbar_pop_field_msg(void)
+{
+	gtk_statusbar_pop(GTK_STATUSBAR(info_bar), help_ctx);
+}
+
 static gboolean
 main_window_delete_event_cb(GtkWidget *widget, GdkEvent *event, gpointer data)
 {
@@ -716,7 +756,7 @@ file_quit_cmd_cb (GtkWidget *widget, gpointer data)
 		   which we'd call here, and another routine that
 		   calls that routine and also cleans up the UI, which
 		   we'd call elsewhere? */
-		close_cap_file(&cfile, info_bar);
+		close_cap_file(&cfile);
 
 		/* Exit by leaving the main loop, so that any quit functions
 		   we registered get called. */
@@ -730,17 +770,19 @@ print_usage(void) {
   fprintf(stderr, "This is GNU " PACKAGE " " VERSION ", compiled %s\n",
 	  comp_info_str->str);
 #ifdef HAVE_LIBPCAP
-  fprintf(stderr, "%s [ -vh ] [ -klpQS ] [ -B <byte view height> ] [ -c count ]\n",
+  fprintf(stderr, "%s [ -vh ] [ -klpQS ] [ -B <byte view height> ] [ -c <count> ]\n",
 	  PACKAGE);
-  fprintf(stderr, "\t[ -f <capture filter> ] [ -i interface ] [ -m <medium font> ] \n");
-  fprintf(stderr, "\t[ -n ] [ -o <preference setting> ] ... [ -P <packet list height> ]\n");
-  fprintf(stderr, "\t[ -r infile ] [ -R <read filter> ] [ -s snaplen ] \n");
-  fprintf(stderr, "\t[ -t <time stamp format> ] [ -T <tree view height> ] [ -w savefile ]\n");
+  fprintf(stderr, "\t[ -f <capture filter> ] [ -i <interface> ] [ -m <medium font> ] \n");
+  fprintf(stderr, "\t[ -n ] [ -N <resolving> ]\n");
+  fprintf(stderr, "\t[ -o <preference setting> ] ... [ -P <packet list height> ]\n");
+  fprintf(stderr, "\t[ -r <infile> ] [ -R <read filter> ] [ -s <snaplen> ] \n");
+  fprintf(stderr, "\t[ -t <time stamp format> ] [ -T <tree view height> ] [ -w <savefile> ]\n");
 #else
-  fprintf(stderr, "%s [ -vh ] [ -B <byte view height> ] [ -m <medium font> ] [ -n ]\n",
+  fprintf(stderr, "%s [ -vh ] [ -B <byte view height> ] [ -m <medium font> ]\n",
 	  PACKAGE);
+  fprintf(stderr, "\t[ -n ] [ -N <resolving> ]\n");
   fprintf(stderr, "\t[ -o <preference setting> ... [ -P <packet list height> ]\n");
-  fprintf(stderr, "\t[ -r infile ] [ -R <read filter> ] [ -t <time stamp format> ]\n");
+  fprintf(stderr, "\t[ -r <infile> ] [ -R <read filter> ] [ -t <time stamp format> ]\n");
   fprintf(stderr, "\t[ -T <tree view height> ]\n");
 #endif
 }
@@ -823,6 +865,7 @@ main(int argc, char *argv[])
   dfilter_t           *rfcode = NULL;
   gboolean             rfilter_parse_failed = FALSE;
   e_prefs             *prefs;
+  char                 badopt;
   char                *bold_font_name;
 
   ethereal_path = argv[0];
@@ -898,6 +941,16 @@ main(int argc, char *argv[])
   /* Read the preference files. */
   prefs = read_prefs(&gpf_open_errno, &gpf_path, &pf_open_errno, &pf_path);
 
+#ifdef HAVE_LIBPCAP
+  /* If this is a capture child process, it should pay no attention
+     to the "prefs.capture_prom_mode" setting in the preferences file;
+     it should do what the parent process tells it to do, and if
+     the parent process wants it not to run in promiscuous mode, it'll
+     tell it so with a "-p" flag. */
+  if (capture_child)
+    prefs->capture_prom_mode = TRUE;
+#endif
+
   /* Read the capture filter file. */
   read_filter_list(CFILTER_LIST, &cf_path, &cf_open_errno);
 
@@ -983,7 +1036,7 @@ main(int argc, char *argv[])
 #endif
 
   /* Now get our args */
-  while ((opt = getopt(argc, argv, "B:c:f:hi:klm:no:pP:Qr:R:Ss:t:T:w:W:vZ:")) !=  EOF) {
+  while ((opt = getopt(argc, argv, "B:c:f:hi:klm:nN:o:pP:Qr:R:Ss:t:T:w:W:vZ:")) !=  EOF) {
     switch (opt) {
       case 'B':        /* Byte view pane height */
         bv_size = get_positive_int(optarg, "byte view pane height");
@@ -1032,11 +1085,21 @@ main(int argc, char *argv[])
       case 'm':        /* Fixed-width font for the display */
         if (prefs->gui_font_name != NULL)
           g_free(prefs->gui_font_name);
-	prefs->gui_font_name = g_strdup(optarg);
-	break;
+        prefs->gui_font_name = g_strdup(optarg);
+        break;
       case 'n':        /* No name resolution */
-	prefs->name_resolve = 0;
-	break;
+        prefs->name_resolve = PREFS_RESOLV_NONE;
+        break;
+      case 'N':        /* Select what types of addresses/port #s to resolve */
+        if (prefs->name_resolve == PREFS_RESOLV_ALL)
+          prefs->name_resolve = PREFS_RESOLV_NONE;
+        badopt = string_to_name_resolve(optarg, &prefs->name_resolve);
+        if (badopt != '\0') {
+          fprintf(stderr, "ethereal: -N specifies unknown resolving option '%c'; valid options are 'm', 'n', and 't'\n",
+			badopt);
+          exit(1);
+        }
+        break;
       case 'o':        /* Override preference from command line */
         switch (prefs_set_pref(optarg)) {
 
@@ -1054,7 +1117,7 @@ main(int argc, char *argv[])
         break;
       case 'p':        /* Don't capture in promiscuous mode */
 #ifdef HAVE_LIBPCAP
-	prefs->capture_prom_mode = 0;
+	prefs->capture_prom_mode = FALSE;
 #else
         capture_option_specified = TRUE;
         arg_error = TRUE;
