@@ -1,12 +1,11 @@
 /* menu.c
  * Menu routines
  *
- * $Id: menu.c,v 1.52 2001/04/15 03:37:16 guy Exp $
+ * $Id: menu.c,v 1.54 2001/06/27 10:00:14 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -122,7 +121,9 @@ static GtkItemFactoryEntry menu_items[] =
   {"/Edit/_Unmark All Frames", NULL, GTK_MENU_FUNC(unmark_all_frames_cb), 0, NULL},
   {"/Edit/<separator>", NULL, NULL, 0, "<Separator>"},
   {"/Edit/_Preferences...", NULL, GTK_MENU_FUNC(prefs_cb), 0, NULL},
+#ifdef HAVE_LIBPCAP
   {"/Edit/_Capture Filters...", NULL, GTK_MENU_FUNC(cfilter_dialog_cb), 0, NULL},
+#endif
   {"/Edit/_Display Filters...", NULL, GTK_MENU_FUNC(dfilter_dialog_cb), 0, NULL},
   {"/Edit/P_rotocols...", NULL, GTK_MENU_FUNC(proto_cb), 0, NULL},
 #ifdef HAVE_LIBPCAP
@@ -378,7 +379,6 @@ set_menus_for_captured_packets(gboolean have_captured_packets)
   set_menu_sensitivity("/File/Print...", have_captured_packets);
   set_menu_sensitivity("/Edit/Find Frame...", have_captured_packets);
   set_menu_sensitivity("/Edit/Go To Frame...", have_captured_packets);
-  set_menu_sensitivity("/Display/Match Selected", have_captured_packets);
   set_menu_sensitivity("/Display/Colorize Display...", have_captured_packets);
   set_menu_sensitivity("/Tools/Summary", have_captured_packets);
   set_menu_sensitivity("/Tools/Protocol Hierarchy Statistics", have_captured_packets);
@@ -403,11 +403,13 @@ set_menus_for_selected_packet(gboolean have_selected_packet)
       have_selected_packet && !prefs.name_resolve);  
 }
 
-/* Enable or disable menu items based on whether a tree row is selected. */
+/* Enable or disable menu items based on whether a tree row is selected
+   and and on whether a "Match Selected" can be done. */
 void
 set_menus_for_selected_tree_row(gboolean have_selected_tree)
 {
   gboolean properties = FALSE;
+
   if (finfo_selected) {
 	header_field_info *hfinfo = finfo_selected->hfinfo;
 	if (hfinfo->parent == -1) {
@@ -415,6 +417,10 @@ set_menus_for_selected_tree_row(gboolean have_selected_tree)
 	} else {
 	  properties = prefs_is_registered_protocol(proto_registrar_get_abbrev(hfinfo->parent));
 	}
-  }
+	set_menu_sensitivity("/Display/Match Selected",
+	  proto_can_match_selected(finfo_selected));
+  } else
+	set_menu_sensitivity("/Display/Match Selected", FALSE);
+
   set_menu_sensitivity("/Protocol Properties...", have_selected_tree && properties);
 }
