@@ -1,10 +1,10 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: proto_draw.c,v 1.33 2001/04/10 12:07:40 gram Exp $
+ * $Id: proto_draw.c,v 1.36 2001/07/09 22:54:15 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Jeff Foster,    2001/03/12,  added support for displaying named
@@ -37,6 +37,7 @@
 #include <stdarg.h>
 
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #ifdef NEED_SNPRINTF_H
 # include "snprintf.h"
@@ -184,6 +185,16 @@ collapse_tree(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data)
 	*val = FALSE;
 }
 
+static void
+toggle_tree(GtkCTree *ctree, GdkEventKey *event, gpointer user_data)
+{
+	GtkCTreeNode *node;
+
+	if (event->keyval != GDK_Return)
+		return;
+	gtk_ctree_toggle_expansion(ctree, GTK_CTREE_NODE(ctree->clist.selection->data));
+}
+
 /* Which byte the offset is referring to. Associates
  * whitespace with the preceding digits. */
 static int
@@ -814,7 +825,7 @@ create_tree_view(gint tv_size, e_prefs *prefs, GtkWidget *pane,
   /* Tree view */
   tv_scrollw = gtk_scrolled_window_new(NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(tv_scrollw),
-    GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
+    GTK_POLICY_ALWAYS, GTK_POLICY_ALWAYS);
   set_scrollbar_placement_scrollw(tv_scrollw, pos);
   remember_scrolled_window(tv_scrollw);
   gtk_paned_pack1(GTK_PANED(pane), tv_scrollw, TRUE, TRUE);
@@ -822,6 +833,12 @@ create_tree_view(gint tv_size, e_prefs *prefs, GtkWidget *pane,
   gtk_widget_show(tv_scrollw);
   
   tree_view = gtk_ctree_new(1, 0);
+  gtk_signal_connect( GTK_OBJECT(tree_view), "key-press-event",
+		      (GtkSignalFunc) toggle_tree, NULL );
+  gtk_signal_connect( GTK_OBJECT(tree_view), "tree-expand",
+		      (GtkSignalFunc) expand_tree, NULL );
+  gtk_signal_connect( GTK_OBJECT(tree_view), "tree-collapse",
+		      (GtkSignalFunc) collapse_tree, NULL );
   /* I need this next line to make the widget work correctly with hidden
    * column titles and GTK_SELECTION_BROWSE */
   gtk_clist_set_column_auto_resize( GTK_CLIST(tree_view), 0, TRUE );
@@ -874,11 +891,6 @@ proto_tree_draw(proto_tree *protocol_tree, GtkWidget *tree_view)
 	g_node_children_foreach((GNode*) protocol_tree, G_TRAVERSE_ALL,
 		proto_tree_draw_node, &info);
 
-	gtk_signal_connect( GTK_OBJECT(info.ctree), "tree-expand",
-		(GtkSignalFunc) expand_tree, NULL );
-	gtk_signal_connect( GTK_OBJECT(info.ctree), "tree-collapse",
-		(GtkSignalFunc) collapse_tree, NULL );
-
 	gtk_clist_thaw ( GTK_CLIST(tree_view) );
 }
 
@@ -898,7 +910,8 @@ proto_tree_draw_node(GNode *node, gpointer data)
 	if (!fi->visible)
 		return;
 	i= find_notebook_page( byte_nb_ptr, fi->ds_name);
-	if ( i < 0) return; 	/* no notebook pages ?? */
+	if ( i < 0)
+		return; 	/* no notebook pages ?? */
 	set_notebook_page( byte_nb_ptr, i);
 
 	/* was a free format label produced? */
@@ -937,3 +950,34 @@ proto_tree_draw_node(GNode *node, gpointer data)
 			proto_tree_draw_node, &info);
 	}
 }
+
+/*
+ * Clear the hex dump and protocol tree panes.
+ */
+void
+clear_tree_and_hex_views(void)
+{
+  /* Clear the hex dump. */
+
+  GtkWidget *byte_view;
+  int i;
+
+/* Get the current tab scroll window, then get the text widget  */
+/* from the E_BYTE_VIEW_TEXT_INFO_KEY data field 		*/
+
+  i = gtk_notebook_get_current_page( GTK_NOTEBOOK(byte_nb_ptr));
+
+  if ( i >= 0){
+    byte_view = gtk_notebook_get_nth_page( GTK_NOTEBOOK(byte_nb_ptr), i);
+    byte_view = gtk_object_get_data(GTK_OBJECT(byte_view), E_BYTE_VIEW_TEXT_INFO_KEY);
+
+    gtk_text_freeze(GTK_TEXT(byte_view));
+    gtk_text_set_point(GTK_TEXT(byte_view), 0);
+    gtk_text_forward_delete(GTK_TEXT(byte_view),
+      gtk_text_get_length(GTK_TEXT(byte_view)));
+    gtk_text_thaw(GTK_TEXT(byte_view));
+  }
+  /* Remove all nodes in ctree. This is how it's done in testgtk.c in GTK+ */
+  gtk_clist_clear ( GTK_CLIST(tree_view) );
+
+}
