@@ -1,7 +1,7 @@
 /* ipproto.c
  * Routines for converting IPv4 protocol/v6 nxthdr field into string
  *
- * $Id: ipproto.c,v 1.10 2001/03/05 20:11:36 guy Exp $
+ * $Id: ipproto.c,v 1.13 2001/04/17 06:29:12 guy Exp $
  *
  * Gilbert Ramirez <gram@xiexie.org>
  *
@@ -43,12 +43,10 @@
 # include "snprintf.h"
 #endif
 
-#include "globals.h"
+#include "ipproto.h"
 #include "packet.h"
-#include "etypes.h"
-#include "resolv.h"
+#include "prefs.h"
 #include "packet-ip.h"
-#include "packet-ipv6.h"
 
 static const value_string ipproto_val[] = {
     { IP_PROTO_ICMP,	"ICMP" },
@@ -106,7 +104,7 @@ const char *ipprotostr(int proto) {
 	goto ok;
 
 #ifdef HAVE_GETPROTOBYNUMBER
-    if (g_resolving_actif) {
+    if (prefs.name_resolve) {
 	pe = getprotobynumber(proto);
 	if (pe) {
 	    s = pe->p_name;
