@@ -2,7 +2,7 @@
  * Routines for BACnet (APDU) dissection
  * Copyright 2001, Hartmut Mueller <hartmut@abmlinux.org>, FH Dortmund
  *
- * $Id: packet-bacapp.c,v 1.2 2001/04/20 20:34:28 guy Exp $
+ * $Id: packet-bacapp.c,v 1.4 2001/06/18 02:17:44 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -78,7 +78,6 @@ dissect_bacapp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	guint8 bacapp_type;
 	tvbuff_t *next_tvb;
 
-	pinfo->current_proto = "BACapp";
 	if (check_col(pinfo->fd, COL_PROTOCOL))
 		col_set_str(pinfo->fd, COL_PROTOCOL, "BACnet-APDU");
 	if (check_col(pinfo->fd, COL_INFO))
@@ -112,7 +111,7 @@ proto_register_bacapp(void)
 	static hf_register_info hf[] = {
 		{ &hf_bacapp_type,
 			{ "APDU Type",           "bacapp.bacapp_type",
-			FT_UINT8, BASE_DEC, NULL, 0xf0, "APDU Type" }
+			FT_UINT8, BASE_DEC, NULL, 0xf0, "APDU Type", HFILL }
 		},
 	};
 	static gint *ett[] = {
