@@ -1,12 +1,12 @@
 /* packet-bpdu.c
  * Routines for BPDU (Spanning Tree Protocol) disassembly
  *
- * $Id: packet-bpdu.c,v 1.24 2001/03/13 21:34:23 gram Exp $
+ * $Id: packet-bpdu.c,v 1.26 2001/06/18 02:17:45 guy Exp $
  *
  * Copyright 1999 Christophe Tronche <ch.tronche@computer.org>
  * 
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -45,9 +45,6 @@
 #include "ppptypes.h"
 #include "resolv.h"
 
-/* Include this for GVRP dissector */
-#include "packet-gvrp.h"
-
 /* Offsets of fields within a BPDU */
 
 #define BPDU_IDENTIFIER          0
@@ -79,6 +76,8 @@ static int hf_bpdu_forward_delay = -1;
 
 static gint ett_bpdu = -1;
 
+static dissector_handle_t gvrp_handle;
+
 static void
 dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
       guint16 protocol_identifier;
@@ -126,7 +125,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
 
 	    case 0x21:
 		  /* for GVRP */
-		  dissect_gvrp(tvb, pinfo, tree);
+		  call_dissector(gvrp_handle, tvb, pinfo, tree);
 		  return;
 	    }
 
@@ -276,51 +275,51 @@ proto_register_bpdu(void)
     { &hf_bpdu_proto_id,
       { "Protocol Identifier",		"stp.protocol",
 	FT_UINT16,	BASE_HEX,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_version_id,
       { "Protocol Version Identifier",	"stp.version",
 	FT_UINT8,	BASE_DEC,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_type,
       { "BPDU type",			"stp.type",
 	FT_UINT8,	BASE_HEX,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_flags,
       { "BPDU flags",			"stp.flags",
 	FT_UINT8,	BASE_HEX,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_root_mac,
       { "Root Identifier",		"stp.root.hw",
 	FT_ETHER,	BASE_NONE,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_root_cost,
       { "Root Path Cost",		"stp.root.cost",
 	FT_UINT32,	BASE_DEC,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_bridge_mac,
       { "Bridge Identifier",		"stp.bridge.hw",
 	FT_ETHER,	BASE_NONE,	NULL,	0x0,
-      	""}},
+      	"", HFILL }},
     { &hf_bpdu_port_id,
       { "Port identifier",		"stp.port",
 	FT_UINT16,	BASE_HEX,	NULL,	0x0,
-      	""}},
+      	"", HFILL }},
     { &hf_bpdu_msg_age,
       { "Message Age",			"stp.msg_age",
 	FT_DOUBLE,	BASE_NONE,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_max_age,
       { "Max Age",			"stp.max_age",
 	FT_DOUBLE,	BASE_NONE,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_hello_time,
       { "Hello Time",			"stp.hello",
 	FT_DOUBLE,	BASE_NONE,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_bpdu_forward_delay,
       { "Forward Delay",		"stp.forward",
 	FT_DOUBLE,	BASE_NONE,	NULL,	0x0,
-      	"" }},
+      	"", HFILL }},
   };
   static gint *ett[] = {
     &ett_bpdu,
@@ -336,6 +335,11 @@ proto_register_bpdu(void)
 void
 proto_reg_handoff_bpdu(void)
 {
+  /*
+   * Get handle for the GVRP dissector.
+   */
+  gvrp_handle = find_dissector("gvrp");
+
   dissector_add("llc.dsap", SAP_BPDU, dissect_bpdu, proto_bpdu);
   dissector_add("ppp.protocol", PPP_BPDU, dissect_bpdu, proto_bpdu);
 }
