@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c,v 1.36 2001/03/15 09:11:00 guy Exp $
+ * $Id: packet-cdp.c,v 1.38 2001/06/20 05:18:36 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -134,6 +134,18 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	while (tvb_reported_length_remaining(tvb, offset) != 0) {
 	    type = tvb_get_ntohs(tvb, offset + TLV_TYPE);
 	    length = tvb_get_ntohs(tvb, offset + TLV_LENGTH);
+	    if (length < 4) {
+		tlvi = proto_tree_add_text(cdp_tree, tvb, offset, 4,
+		    "TLV with invalid length %u (< 4)",
+		    length);
+		tlv_tree = proto_item_add_subtree(tlvi, ett_cdp_tlv);
+		proto_tree_add_uint(tlv_tree, hf_cdp_tlvtype, tvb,
+			    offset + TLV_TYPE, 2, type);
+		proto_tree_add_uint(tlv_tree, hf_cdp_tlvlength, tvb,
+			    offset + TLV_LENGTH, 2, length);
+		offset += 4;
+		break;
+	    }
 
 	    switch (type) {
 
@@ -539,23 +551,23 @@ proto_register_cdp(void)
     static hf_register_info hf[] = {
 	{ &hf_cdp_version,
 	{ "Version",		"cdp.version",  FT_UINT8, BASE_DEC, NULL, 0x0,
-	  "" }},
+	  "", HFILL }},
 
 	{ &hf_cdp_ttl,
 	{ "TTL",		"cdp.ttl", FT_UINT16, BASE_DEC, NULL, 0x0,
-	  "" }},
+	  "", HFILL }},
 
 	{ &hf_cdp_checksum,
 	{ "Checksum",		"cdp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-	  "" }},
+	  "", HFILL }},
 
 	{ &hf_cdp_tlvtype,
 	{ "Type",		"cdp.tlv.type", FT_UINT16, BASE_HEX, VALS(type_vals), 0x0,
-	  "" }},
+	  "", HFILL }},
 
 	{ &hf_cdp_tlvlength,
 	{ "Length",		"cdp.tlv.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-	  "" }},
+	  "", HFILL }},
     };
     static gint *ett[] = {
 	&ett_cdp,
