@@ -1,7 +1,7 @@
 /* packet-chdlc.c
  * Routines for Cisco HDLC packet disassembly
  *
- * $Id: packet-chdlc.c,v 1.3 2001/04/10 14:04:31 guy Exp $
+ * $Id: packet-chdlc.c,v 1.4 2001/06/18 02:17:45 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -168,10 +168,10 @@ proto_register_chdlc(void)
   static hf_register_info hf[] = {
     { &hf_chdlc_addr,
       { "Address", "chdlc.address", FT_UINT8, BASE_HEX,
-        VALS(chdlc_address_vals), 0x0, "" }},
+        VALS(chdlc_address_vals), 0x0, "", HFILL }},
     { &hf_chdlc_proto,
       { "Protocol", "chdlc.protocol", FT_UINT16, BASE_HEX,
-        VALS(chdlc_vals), 0x0, "" }},
+        VALS(chdlc_vals), 0x0, "", HFILL }},
   };
   static gint *ett[] = {
     &ett_chdlc,
@@ -278,18 +278,18 @@ proto_register_slarp(void)
   static hf_register_info hf[] = {
     { &hf_slarp_ptype,
       { "Packet type", "slarp.ptype", FT_UINT32, BASE_DEC,
-        VALS(slarp_ptype_vals), 0x0, "" }},
+        VALS(slarp_ptype_vals), 0x0, "", HFILL }},
     { &hf_slarp_address,
       { "Address", "slarp.address", FT_IPv4, BASE_NONE,
-        NULL, 0x0, "" }},
+        NULL, 0x0, "", HFILL }},
     /* XXX - need an FT_ for netmasks, which is like FT_IPV4 but doesn't
        get translated to a host name. */
     { &hf_slarp_mysequence,
       { "Outgoing sequence number", "slarp.mysequence", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "" }},
+        NULL, 0x0, "", HFILL }},
     { &hf_slarp_yoursequence,
       { "Returned sequence number", "slarp.yoursequence", FT_UINT32, BASE_DEC,
-        NULL, 0x0, "" }},
+        NULL, 0x0, "", HFILL }},
   };
   static gint *ett[] = {
     &ett_chdlc,
