@@ -1,13 +1,14 @@
 /* packet-diameter.c
  * Routines for DIAMETER packet disassembly
  *
- * $Id: packet-diameter.c,v 1.21 2001/04/10 21:49:23 guy Exp $
+ * $Id: packet-diameter.c,v 1.23 2001/06/18 02:17:45 guy Exp $
  *
  * Copyright (c) 2001 by David Frascone <dave@frascone.com>
  *
  * Ethereal - Network traffic analyzer
- * By Johan Feyaerts
- * Copyright 1999 Johan Feyaerts
+ * By Gerald Combs <gerald@ethereal.com>
+ * Copyright 1998 Gerald Combs
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -777,76 +778,76 @@ proto_register_diameter(void)
 	static hf_register_info hf[] = {
 		{ &hf_diameter_reserved,
 		  { "Reserved", "diameter.reserved", FT_UINT8, BASE_HEX, NULL, 0x0,
-		    "Should be zero" }},
+		    "Should be zero", HFILL }},
 		{ &hf_diameter_flags,
 		  { "Flags", "diameter.flags", FT_UINT8, BASE_HEX, NULL, 0xf8,
-		    "" }},
+		    "", HFILL }},
 		{ &hf_diameter_version,
 		  { "Version", "diameter.version", FT_UINT8, BASE_HEX, NULL, 0x07,
-		    "" }},
+		    "", HFILL }},
 		{ &hf_diameter_length,
 		  { "Length","diameter.length", FT_UINT16, BASE_DEC, NULL, 0x0,
-		    "" }},
+		    "", HFILL }},
 		{ &hf_diameter_hopbyhopid,
 		  { "Hop-by-Hop Identifier", "diameter.hopbyhopid", FT_UINT32,
-		    BASE_HEX, NULL, 0x0, "" }},
+		    BASE_HEX, NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_endtoendid,
 		  { "End-to-End Identifier", "diameter.endtoendid", FT_UINT32, 
-		    BASE_HEX, NULL, 0x0, "" }},
+		    BASE_HEX, NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_code,
 		  { "Command Code","diameter.code", FT_UINT32, BASE_DEC,
-		    VALS(diameter_command_code_vals), 0x0, "" }},
+		    VALS(diameter_command_code_vals), 0x0, "", HFILL }},
 		{ &hf_diameter_vendor_id,
 		  { "VendorId",	"diameter.vendorId", FT_UINT32, BASE_DEC, NULL, 0x0,
-		    "" }},
+		    "", HFILL }},
 
 		{ &hf_diameter_avp_code,
 		  { "AVP Code","diameter.avp.code", FT_UINT32, BASE_DEC,
-		    VALS(diameter_attrib_type_vals), 0x0, "" }},
+		    VALS(diameter_attrib_type_vals), 0x0, "", HFILL }},
 		{ &hf_diameter_avp_length,
 		  { "AVP length","diameter.avp.length", FT_UINT16, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_avp_reserved,
 		  { "AVP Reserved","diameter.avp.reserved", FT_UINT8, BASE_HEX,
-		    NULL, 0x0, "Should be Zero" }},
+		    NULL, 0x0, "Should be Zero", HFILL }},
 		{ &hf_diameter_avp_flags,
 		  { "AVP Flags","diameter.avp.flags", FT_UINT8, BASE_HEX,
-		    NULL, 0x1f, "" }},
+		    NULL, 0x1f, "", HFILL }},
 		{ &hf_diameter_avp_vendor_id,
 		  { "AVP Vendor Id","diameter.avp.vendorId", FT_UINT32, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_avp_data_uint32,
 		  { "AVP Data","diameter.avp.data.uint32", FT_UINT32, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 #if 0
 		{ &hf_diameter_avp_data_uint64,
 		  { "AVP Data","diameter.avp.data.uint64", FT_UINT64, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 #endif
 		{ &hf_diameter_avp_data_int32,
 		  { "AVP Data","diameter.avp.data.int32", FT_INT32, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 #if 0
 		{ &hf_diameter_avp_data_int64,
 		  { "AVP Data","diameter.avp.data.int64", FT_INT_64, BASE_DEC,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 #endif
 		{ &hf_diameter_avp_data_bytes,
 		  { "AVP Data","diameter.avp.data.bytes", FT_BYTES, BASE_NONE,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 
 		{ &hf_diameter_avp_data_string,
 		  { "AVP Data","diameter.avp.data.string", FT_STRING, BASE_NONE,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_avp_data_v4addr,
 		  { "AVP Data","diameter.avp.data.v4addr", FT_IPv4, BASE_NONE,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_avp_data_v6addr,
 		  { "AVP Data","diameter.avp.data.v6addr", FT_IPv6, BASE_NONE,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 		{ &hf_diameter_avp_data_time,
 		  { "AVP Data","diameter.avp.data.time", FT_ABSOLUTE_TIME, BASE_NONE,
-		    NULL, 0x0, "" }},
+		    NULL, 0x0, "", HFILL }},
 
 	};
 	static gint *ett[] = {
