@@ -3,10 +3,10 @@
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  * Copyright 2001, Juan Toledo <toledo@users.sourceforge.net> (Passive FTP)
  * 
- * $Id: packet-ftp.c,v 1.28 2001/05/11 23:24:08 guy Exp $
+ * $Id: packet-ftp.c,v 1.30 2001/06/18 02:17:46 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-pop.c
@@ -136,13 +136,13 @@ dissect_ftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * and dissector
 	 */
 	if (passive_port && !find_conversation(&pinfo->src, &pinfo->dst, PT_TCP,
-					       passive_port, 0, NO_DST_PORT))
+					       passive_port, 0, NO_PORT_B))
 	  {
 		conversation_t 	*conversation;
 		  
 		conversation = conversation_new(&pinfo->src, &pinfo->dst, PT_TCP,
 						  passive_port, 0, NULL,
-						  NO_DST_PORT);
+						  NO_PORT2);
 		conversation_set_dissector(conversation, dissect_ftpdata);
 
 	  }
@@ -264,32 +264,32 @@ proto_register_ftp(void)
     { &hf_ftp_response,
       { "Response",           "ftp.response",
       	FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-      	"TRUE if FTP response" }},
+      	"TRUE if FTP response", HFILL }},
 
     { &hf_ftp_request,
       { "Request",            "ftp.request",
       	FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-      	"TRUE if FTP request" }},
+      	"TRUE if FTP request", HFILL }},
 
     { &hf_ftp_request_command,
       { "Request command",    "ftp.request.command",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
 
     { &hf_ftp_request_data,
       { "Request data",	      "ftp.request.data",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
 
     { &hf_ftp_response_code,
       { "Response code",      "ftp.response.code",
       	FT_UINT8,   BASE_DEC, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
 
     { &hf_ftp_response_data,
       { "Response data",      "ftp.reponse.data",
       	FT_STRING,  BASE_NONE, NULL, 0x0,
-      	"" }}
+      	"", HFILL }}
   };
   static gint *ett[] = {
     &ett_ftp,
