@@ -2,10 +2,10 @@
  * Routines for hclnfsd (Hummingbird NFS Daemon) dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id: packet-hclnfsd.c,v 1.4 2001/04/11 18:55:34 guy Exp $
+ * $Id: packet-hclnfsd.c,v 1.7 2001/06/18 02:17:46 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-ypserv.c
@@ -124,7 +124,7 @@ dissect_hclnfsd_gids(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *
 static int
 dissect_hclnfsd_spool_inquire_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_status, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_status, offset);
 
 	offset = dissect_nfs_fh3(tvb, offset, pinfo, tree, "spool filehandle");
 
@@ -135,11 +135,11 @@ dissect_hclnfsd_spool_inquire_call(tvbuff_t *tvb, int offset, packet_info *pinfo
 static int
 dissect_hclnfsd_spool_file_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_printername, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_printername, offset, NULL);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_filename, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_filename, offset, NULL);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_fileext, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_fileext, offset);
 
 	return offset;
 }
@@ -171,9 +171,9 @@ dissect_hclnfsd_authorize_call(tvbuff_t *tvb, int offset, packet_info *pinfo, pr
 			4, request_type);
 	offset += 4;
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_device, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_device, offset, NULL);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_login, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_login, offset, NULL);
 
 	return offset;
 }
@@ -194,9 +194,9 @@ dissect_hclnfsd_authorize_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, p
 
 	proto_tree_add_uint(tree, hf_hclnfsd_status, tvb, offset, 4, status);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_uid, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_uid, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_gid, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_gid, offset);
 
 	offset = dissect_hclnfsd_gids(tvb, offset, pinfo, tree);
 
@@ -206,7 +206,7 @@ dissect_hclnfsd_authorize_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, p
 static int
 dissect_hclnfsd_grp_name_to_numb_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_grpname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_grpname, offset, NULL);
 
 	return offset;
 }
@@ -214,7 +214,7 @@ dissect_hclnfsd_grp_name_to_numb_call(tvbuff_t *tvb, int offset, packet_info *pi
 static int
 dissect_hclnfsd_grp_name_to_numb_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_gid, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_gid, offset);
 	
 	return offset;
 }
@@ -252,7 +252,7 @@ dissect_hclnfsd_grp_to_number_reply(tvbuff_t *tvb, int offset, packet_info *pinf
 		return offset;
 
 	for (ngrpnames_i = 0; ngrpnames_i < ngrpnames ; ngrpnames_i++)
-		offset = dissect_rpc_string_tvb(tvb, pinfo, grptree, 
+		offset = dissect_rpc_string(tvb, pinfo, grptree, 
 			hf_hclnfsd_grpname, offset, NULL);
 	
 	return offset;
@@ -276,7 +276,7 @@ dissect_hclnfsd_return_host_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 static int
 dissect_hclnfsd_return_host_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_hostname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_hostname, offset, NULL);
 
 	return offset;
 }
@@ -304,7 +304,7 @@ dissect_hclnfsd_uid_to_name_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		return offset;
 
 	for (nuids_i = 0; nuids_i < nuids; nuids_i++)
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, uidtree, hf_hclnfsd_uid, offset);
+		offset = dissect_rpc_uint32(tvb, pinfo, uidtree, hf_hclnfsd_uid, offset);
 
 	return offset;
 }
@@ -332,7 +332,7 @@ dissect_hclnfsd_uid_to_name_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		return offset;
 
 	for (nusers_i = 0; nusers_i < nusers; nusers_i++)
-		offset = dissect_rpc_string_tvb(tvb, pinfo, usertree, 
+		offset = dissect_rpc_string(tvb, pinfo, usertree, 
 			hf_hclnfsd_username, offset, NULL);
 
 	return offset;
@@ -342,7 +342,7 @@ dissect_hclnfsd_uid_to_name_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 static int
 dissect_hclnfsd_name_to_uid_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_username, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_username, offset, NULL);
 
 	return offset;
 }
@@ -351,7 +351,7 @@ dissect_hclnfsd_name_to_uid_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 static int
 dissect_hclnfsd_name_to_uid_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_uid, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_uid, offset);
 
 	return offset;
 }
@@ -368,17 +368,17 @@ dissect_hclnfsd_share_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_
 			4, request_type);
 	offset += 4;
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
 
 	offset = dissect_nfs_fh3(tvb, offset, pinfo, tree, "Filehandle");
 
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_hclnfsd_unknown_data, offset);
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_hclnfsd_unknown_data, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_mode, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_mode, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_access, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_access, offset);
 
 	offset += 4;	/* skip last 4 UNUSED bytes */
 
@@ -397,9 +397,9 @@ dissect_hclnfsd_share_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto
 			4, request_type);
 	offset += 4;
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_status, offset);
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_sequence, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_status, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_sequence, offset);
 
 	return offset;
 }
@@ -422,23 +422,23 @@ dissect_hclnfsd_unshare_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, pro
 static int
 dissect_hclnfsd_lock_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_status, offset);
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_status, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
 	offset += 4; /* skip unused uint */
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_exclusive, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_exclusive, offset);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
 
 	offset = dissect_nfs_fh3(tvb, offset, pinfo, tree, "Filehandle");
 
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_hclnfsd_lockowner, offset);
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_hclnfsd_lockowner, offset);
 
 	offset += 4;  /* unused, skip */
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_offset, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_offset, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_length, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_length, offset);
 
 	return offset;
 }
@@ -455,8 +455,8 @@ dissect_hclnfsd_lock_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_
 			4, request_type);
 	offset += 4;
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_status, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_status, offset);
 
 	return offset;
 }
@@ -465,7 +465,7 @@ dissect_hclnfsd_lock_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_
 static int
 dissect_hclnfsd_remove_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
 
 	offset += 4;  /* skip unused */
 
@@ -478,18 +478,18 @@ dissect_hclnfsd_unlock_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto
 {
 	offset += 4;  /* skip unused */
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_cookie, offset);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_lockname, offset, NULL);
 
 	offset = dissect_nfs_fh3(tvb, offset, pinfo, tree, "Filehandle");
 
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_hclnfsd_unknown_data, offset);
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_hclnfsd_unknown_data, offset);
 
 	offset += 4;  /* skip unused */
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_offset, offset);
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_length, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_offset, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_length, offset);
 	
 	return offset;
 }
@@ -527,11 +527,11 @@ dissect_hclnfsd_get_printers_reply(tvbuff_t *tvb, int offset, packet_info *pinfo
 	for (nqueues_i = 0; nqueues_i < nqueues; nqueues_i++)
 	{
 		/* create new item for print queue */
-		offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_hclnfsd_queuename, offset, NULL);
 
 		/* create subtree on new item with print queue comment */
-		offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_hclnfsd_queuecomment, offset, NULL);
 	}
 
@@ -542,9 +542,9 @@ dissect_hclnfsd_get_printers_reply(tvbuff_t *tvb, int offset, packet_info *pinfo
 static int
 dissect_hclnfsd_get_printq_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_queuename, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_queuename, offset, NULL);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_username, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_username, offset, NULL);
 
 	return offset;
 }
@@ -559,13 +559,13 @@ dissect_hclnfsd_get_printq_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_item *jobitem;
 	proto_tree *jobtree;
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_printqueuenumber, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_printqueuenumber, offset);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, hf_hclnfsd_queuecomment, offset, NULL);
+	offset = dissect_rpc_string(tvb, pinfo, tree, hf_hclnfsd_queuecomment, offset, NULL);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_queuestatus, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_queuestatus, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_numphysicalprinters, offset);
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_numphysicalprinters, offset);
 
 	datafollows = tvb_get_ntohl(tvb, offset);
 	if (tree)
@@ -589,19 +589,19 @@ dissect_hclnfsd_get_printq_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 		jobtree = proto_item_add_subtree(jobitem, ett_hclnfsd_printjob);
 			
-		offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_hclnfsd_username, offset, NULL);
 
-		offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_hclnfsd_printparams, offset, NULL);
 
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_queuestatus, offset);
+		offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_queuestatus, offset);
 
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_jobstatus, offset);
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_timesubmitted, offset);
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_size, offset);
-		offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_hclnfsd_copies, offset);
-		offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+		offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_jobstatus, offset);
+		offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_timesubmitted, offset);
+		offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_size, offset);
+		offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_hclnfsd_copies, offset);
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_hclnfsd_queuecomment, offset, NULL);
 
 		datafollows = tvb_get_ntohl(tvb, offset);
@@ -668,139 +668,139 @@ proto_register_hclnfsd(void)
 	static hf_register_info hf[] = {
 		{ &hf_hclnfsd_request_type, {
 			"Request Type", "hclnfsd.request_type", FT_UINT32, BASE_DEC,
-			VALS(names_request_type), 0, "Request Type" }},
+			VALS(names_request_type), 0, "Request Type", HFILL }},
 
 		{ &hf_hclnfsd_device, {
 			"Device", "hclnfsd.device", FT_STRING, BASE_DEC,
-			NULL, 0, "Device" }},
+			NULL, 0, "Device", HFILL }},
 
 		{ &hf_hclnfsd_login, {
 			"Login Text", "hclnfsd.logintext", FT_STRING, BASE_DEC,
-			NULL, 0, "Login Text" }},
+			NULL, 0, "Login Text", HFILL }},
 
 		{ &hf_hclnfsd_lockname, {
 			"Lockname", "hclnfsd.lockname", FT_STRING, BASE_DEC,
-			NULL, 0, "Lockname" }},
+			NULL, 0, "Lockname", HFILL }},
 
 		{ &hf_hclnfsd_unknown_data, {
-			"Unknown", "hclnfsd.unknown_data", FT_STRING, BASE_DEC,
-			NULL, 0, "Data" }},
+			"Unknown", "hclnfsd.unknown_data", FT_BYTES, BASE_DEC,
+			NULL, 0, "Data", HFILL }},
 
 		{ &hf_hclnfsd_lockowner, {
-			"Lockowner", "hclnfsd.lockowner", FT_STRING, BASE_DEC,
-			NULL, 0, "Lockowner" }},
+			"Lockowner", "hclnfsd.lockowner", FT_BYTES, BASE_DEC,
+			NULL, 0, "Lockowner", HFILL }},
 
 		{ &hf_hclnfsd_printername, {
 			"Printer Name", "hclnfsd.printername", FT_STRING, BASE_DEC,
-			NULL, 0, "Printer name" }},
+			NULL, 0, "Printer name", HFILL }},
 
 		{ &hf_hclnfsd_filename, {
 			"Filename", "hclnfsd.filename", FT_STRING, BASE_DEC,
-			NULL, 0, "Filename" }},
+			NULL, 0, "Filename", HFILL }},
 
 		{ &hf_hclnfsd_fileext, {
 			"File Extension", "hclnfsd.fileext", FT_UINT32, BASE_DEC,
-			NULL, 0, "File Extension" }},
+			NULL, 0, "File Extension", HFILL }},
 
 		{ &hf_hclnfsd_grpname, {
 			"Group", "hclnfsd.group", FT_STRING, BASE_DEC,
-			NULL, 0, "Group" }},
+			NULL, 0, "Group", HFILL }},
 
 		{ &hf_hclnfsd_hostname, {
 			"Hostname", "hclnfsd.hostname", FT_STRING, BASE_DEC,
-			NULL, 0, "Hostname" }},
+			NULL, 0, "Hostname", HFILL }},
 
 		{ &hf_hclnfsd_username, {
 			"Username", "hclnfsd.username", FT_STRING, BASE_DEC,
-			NULL, 0, "Username" }},
+			NULL, 0, "Username", HFILL }},
 
 		{ &hf_hclnfsd_queuename, {
 			"Name", "hclnfsd.printqueuename", FT_STRING, BASE_DEC,
-			NULL, 0, "Print Queue Name" }},
+			NULL, 0, "Print Queue Name", HFILL }},
 
 		{ &hf_hclnfsd_queuecomment, {
 			"Comment", "hclnfsd.printqueuecomment", FT_STRING, BASE_DEC,
-			NULL, 0, "Print Queue Comment" }},
+			NULL, 0, "Print Queue Comment", HFILL }},
 
 		{ &hf_hclnfsd_printparams, {
 			"Print Parameters", "hclnfsd.printparameters", FT_STRING, BASE_DEC,
-			NULL, 0, "Print Parameters" }},
+			NULL, 0, "Print Parameters", HFILL }},
 
 		{ &hf_hclnfsd_status, {
 			"Status", "hclnfsd.status", FT_UINT32, BASE_DEC,
-			NULL, 0, "Status" }},
+			NULL, 0, "Status", HFILL }},
 
 		{ &hf_hclnfsd_uid, {
 			"UID", "hclnfsd.uid", FT_UINT32, BASE_DEC,
-			NULL, 0, "User ID" }},
+			NULL, 0, "User ID", HFILL }},
 
 		{ &hf_hclnfsd_sequence, {
 			"Sequence", "hclnfsd.sequence", FT_UINT32, BASE_HEX,
-			NULL, 0, "Sequence" }},
+			NULL, 0, "Sequence", HFILL }},
 
 		{ &hf_hclnfsd_cookie, {
 			"Cookie", "hclnfsd.cookie", FT_UINT32, BASE_HEX,
-			NULL, 0, "Cookie" }},
+			NULL, 0, "Cookie", HFILL }},
 
 		{ &hf_hclnfsd_mode, {
 			"Mode", "hclnfsd.mode", FT_UINT32, BASE_DEC,
-			NULL, 0, "Mode" }},
+			NULL, 0, "Mode", HFILL }},
 
 		{ &hf_hclnfsd_access, {
 			"Access", "hclnfsd.access", FT_UINT32, BASE_DEC,
-			NULL, 0, "Access" }},
+			NULL, 0, "Access", HFILL }},
 
 		{ &hf_hclnfsd_exclusive, {
 			"Exclusive", "hclnfsd.exclusive", FT_UINT32, BASE_DEC,
-			NULL, 0, "Exclusive" }},
+			NULL, 0, "Exclusive", HFILL }},
 
 		{ &hf_hclnfsd_offset, {
 			"Offset", "hclnfsd.offset", FT_UINT32, BASE_DEC,
-			NULL, 0, "Offset" }},
+			NULL, 0, "Offset", HFILL }},
 
 		{ &hf_hclnfsd_length, {
 			"Length", "hclnfsd.length", FT_UINT32, BASE_DEC,
-			NULL, 0, "Length" }},
+			NULL, 0, "Length", HFILL }},
 
 		{ &hf_hclnfsd_queuestatus, {
 			"Queue Status", "hclnfsd.queuestatus", FT_UINT32, BASE_DEC,
-			NULL, 0, "Queue Status" }},
+			NULL, 0, "Queue Status", HFILL }},
 
 		{ &hf_hclnfsd_printqueuenumber, {
 			"Print Queue Number", "hclnfsd.pqn", FT_UINT32, BASE_DEC,
-			NULL, 0, "Print Queue Number" }},
+			NULL, 0, "Print Queue Number", HFILL }},
 
 		{ &hf_hclnfsd_numphysicalprinters, {
 			"Number of Physical Printers", "hclnfsd.npp", FT_UINT32, BASE_DEC,
-			NULL, 0, "Number of Physical Printers" }},
+			NULL, 0, "Number of Physical Printers", HFILL }},
 
 		{ &hf_hclnfsd_jobstatus, {
 			"Job Status", "hclnfsd.jobstatus", FT_UINT32, BASE_DEC,
-			NULL, 0, "Job Status" }},
+			NULL, 0, "Job Status", HFILL }},
 
 		{ &hf_hclnfsd_timesubmitted, {
 			"Time Submitted", "hclnfsd.timesubmitted", FT_UINT32, BASE_DEC,
-			NULL, 0, "Time Submitted" }},
+			NULL, 0, "Time Submitted", HFILL }},
 
 		{ &hf_hclnfsd_size, {
 			"Size", "hclnfsd.size", FT_UINT32, BASE_DEC,
-			NULL, 0, "Size" }},
+			NULL, 0, "Size", HFILL }},
 
 		{ &hf_hclnfsd_copies, {
 			"Copies", "hclnfsd.copies", FT_UINT32, BASE_DEC,
-			NULL, 0, "Copies" }},
+			NULL, 0, "Copies", HFILL }},
 
 		{ &hf_hclnfsd_gid, {
 			"GID", "hclnfsd.gid", FT_UINT32, BASE_DEC,
-			NULL, 0, "Group ID" }},
+			NULL, 0, "Group ID", HFILL }},
 
 		{ &hf_hclnfsd_server_ip, {
 			"Server IP", "hclnfsd.server_ip", FT_IPv4, BASE_DEC,
-			NULL, 0, "Server IP" }},
+			NULL, 0, "Server IP", HFILL }},
 
 		{ &hf_hclnfsd_host_ip, {
 			"Host IP", "hclnfsd.host_ip", FT_IPv4, BASE_DEC,
-			NULL, 0, "Host IP" }},
+			NULL, 0, "Host IP", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_hclnfsd,
