@@ -1,7 +1,7 @@
 /* packet-icmpv6.c
  * Routines for ICMPv6 packet disassembly
  *
- * $Id: packet-icmpv6.c,v 1.42 2001/04/27 01:27:37 guy Exp $
+ * $Id: packet-icmpv6.c,v 1.48 2001/07/02 07:11:39 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -97,6 +97,60 @@ static const value_string names_rrenum_matchcode[] = {
     { 0,			NULL }
 };
 
+static const value_string names_router_pref[] = {
+        { ND_RA_FLAG_RTPREF_HIGH,	"High" }, 
+        { ND_RA_FLAG_RTPREF_MEDIUM,	"Meidum" }, 
+        { ND_RA_FLAG_RTPREF_LOW,	"Low" }, 
+        { ND_RA_FLAG_RTPREF_RSV,	"Reserved" }, 
+};
+
+static void
+dissect_contained_icmpv6(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
+{
+    tvbuff_t *next_tvb;
+    address save_dl_src;
+    address save_dl_dst;
+    address save_net_src;
+    address save_net_dst;
+    address save_src;
+    address save_dst;
+
+    next_tvb = tvb_new_subset(tvb, offset, -1, -1);
+
+    /* tiny sanity check */
+    if ((tvb_get_guint8(tvb, offset) & 0xf0) == 0x60) {
+	/* The contained packet is an IPv6 datagram; dissect it.
+
+	   Set the columns non-writable, so that the packet list
+	   shows this as an ICMPv6 packet, not as the type of packet
+	   for which the ICMPv6 packet was generated. */
+	col_set_writable(pinfo->fd, FALSE);
+
+	/* Also, save the current values of the addresses, and restore
+	   them when we're finished dissecting the contained packet, so
+	   that the address columns in the summary don't reflect the
+	   contained packet, but reflect this packet instead. */
+	save_dl_src = pinfo->dl_src;
+	save_dl_dst = pinfo->dl_dst;
+	save_net_src = pinfo->net_src;
+	save_net_dst = pinfo->net_dst;
+	save_src = pinfo->src;
+	save_dst = pinfo->dst;
+
+	/* Dissect the contained packet. */
+	call_dissector(ipv6_handle, next_tvb, pinfo, tree);
+
+	/* Restore the addresses. */
+	pinfo->dl_src = save_dl_src;
+	pinfo->dl_dst = save_dl_dst;
+	pinfo->net_src = save_net_src;
+	pinfo->net_dst = save_net_dst;
+	pinfo->src = save_src;
+	pinfo->dst = save_dst;
+    } else
+	dissect_data(next_tvb, 0, pinfo, tree);
+}
+
 static void
 dissect_icmpv6opt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
@@ -111,7 +165,7 @@ dissect_icmpv6opt(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tre
 
 again:
     if ((int)tvb_reported_length(tvb) <= offset)
-            return; /* No more options left */
+	return; /* No more options left */
 
     opt = &nd_opt_hdr;
     tvb_memcpy(tvb, (guint8 *)opt, offset, sizeof *opt);
@@ -121,6 +175,14 @@ again:
     ti = proto_tree_add_text(tree, tvb, offset, len, "ICMPv6 options");
     icmp6opt_tree = proto_item_add_subtree(ti, ett_icmpv6opt);
 
+    if (len == 0) {
+	proto_tree_add_text(icmp6opt_tree, tvb,
+			    offset + offsetof(struct nd_opt_hdr, nd_opt_len), 1,
+			    "Invalid option length: %u",
+			    opt->nd_opt_len);
+	return; /* we must not try to decode this */
+    }
+
     switch (opt->nd_opt_type) {
     case ND_OPT_SOURCE_LINKADDR:
 	typename = "Source link-layer address";
@@ -137,14 +199,13 @@ again:
     case ND_OPT_MTU:
 	typename = "MTU";
 	break;
-    case ND_OPT_ADVERTISEMENT_INTERVAL:
+    case ND_OPT_ADVINTERVAL:
 	typename = "Advertisement Interval";
 	break;
-    case ND_OPT_HOME_AGENT_INFORMATION:
+    case ND_OPT_HOMEAGENT_INFO:
 	typename = "Home Agent Information";
 	break;
     default:
-
 	typename = "Unknown";
 	break;
     }
@@ -174,6 +235,7 @@ again:
 	}
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + sizeof(*opt), len, "Link-layer address: %s", t);
+	free(t);
 	break;
       }
     case ND_OPT_PREFIX_INFORMATION:
@@ -193,15 +255,18 @@ again:
 	field_tree = proto_item_add_subtree(tf, ett_icmpv6flag);
 	proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 	    decode_boolean_bitfield(pi->nd_opt_pi_flags_reserved,
-		    0x80, 8, "Onlink", "Not onlink"));
+		    ND_OPT_PI_FLAG_ONLINK, 8, "Onlink", "Not onlink"));
 	proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 	    decode_boolean_bitfield(pi->nd_opt_pi_flags_reserved,
-		    0x40, 8, "Auto", "Not auto"));
-  /* BT INSERT BEGIN */
+		    ND_OPT_PI_FLAG_AUTO, 8, "Auto", "Not auto"));
 	proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 	    decode_boolean_bitfield(pi->nd_opt_pi_flags_reserved,
-		    0x20, 8, "Router Address", "Not router address"));
-  /* BT INSERT END */
+		    ND_OPT_PI_FLAG_ROUTER, 8,
+		    "Router Address", "Not router address"));
+	proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
+	    decode_boolean_bitfield(pi->nd_opt_pi_flags_reserved,
+		    ND_OPT_PI_FLAG_SITEPREF, 8,
+		    "Site prefix", "Not site prefix"));
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + offsetof(struct nd_opt_prefix_info, nd_opt_pi_valid_time),
 	    4, "Valid lifetime: 0x%08x",
@@ -218,35 +283,25 @@ again:
     case ND_OPT_REDIRECTED_HEADER:
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + 8, (opt->nd_opt_len << 3) - 8, "Redirected packet");
-	/* tiny sanity check */
-	if ((tvb_get_guint8(tvb, offset + 8) & 0xf0) == 0x60) {
-	    /* The redirected packet is an IPv6 datagram; dissect it.
-
-	       Set the columns non-writable, so that the packet list
-	       shows this as an ICMPv6 packet, not as the type of packet
-	       for which the ICMPv6 packet was generated. */
-	    col_set_writable(pinfo->fd, FALSE);
-
-	    call_dissector(ipv6_handle, tvb_new_subset(tvb, offset + 8, -1, -1),
-		pinfo, icmp6opt_tree);
-	} else
-	    dissect_data(tvb_new_subset(tvb, offset + 8, -1, -1), 0, pinfo, icmp6opt_tree);
+	dissect_contained_icmpv6(tvb, offset + 8, pinfo, icmp6opt_tree);
 	break;
     case ND_OPT_MTU:
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + offsetof(struct nd_opt_mtu, nd_opt_mtu_mtu), 4,
 	    "MTU: %u", tvb_get_ntohl(tvb, offset + offsetof(struct nd_opt_mtu, nd_opt_mtu_mtu)));
 	break;
-	/* BT INSERT BEGIN */
-    case ND_OPT_ADVERTISEMENT_INTERVAL:
+    case ND_OPT_ADVINTERVAL:
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + offsetof(struct nd_opt_adv_int, nd_opt_adv_int_advint), 4,
 	    "Advertisement Interval: %d",
 	    tvb_get_ntohl(tvb, offset + offsetof(struct nd_opt_adv_int, nd_opt_adv_int_advint)));
 	break;
-    case ND_OPT_HOME_AGENT_INFORMATION:
+    case ND_OPT_HOMEAGENT_INFO:
       {
-	struct nd_opt_ha_info *pi = (struct nd_opt_ha_info *)opt;
+	struct nd_opt_ha_info pibuf, *pi;
+
+	pi = &pibuf;
+	tvb_memcpy(tvb, (guint8 *)pi, offset, sizeof *pi);
 	proto_tree_add_text(icmp6opt_tree, tvb,
 	    offset + offsetof(struct nd_opt_ha_info, nd_opt_ha_info_ha_pref),
 	    2, "Home Agent Preference: %d",
@@ -257,15 +312,62 @@ again:
 	    pntohs(&pi->nd_opt_ha_info_ha_life));
 	break;
       }
-	/* BT INSERT END */
-    }
+    case ND_OPT_ROUTE_INFO:
+      {
+	struct nd_opt_route_info ribuf, *ri;
+	struct e_in6_addr in6;
+	int l;
+	guint32 lifetime;
 
-    if (opt->nd_opt_len == 0) {
-        proto_tree_add_text(icmp6opt_tree, tvb,
-                            offset + offsetof(struct nd_opt_hdr, nd_opt_len), 1,
-                            "Invalid option length: %u",
-                            opt->nd_opt_len);
-        return;
+	ri = &ribuf;
+	tvb_memcpy(tvb, (guint8 *)ri, offset, sizeof *ri);
+	memset(&in6, 0, sizeof(in6));
+	switch (ri->nd_opt_rti_len) {
+	case 1:
+	    l = 0;
+	    break;
+	case 2:
+	    tvb_memcpy(tvb, (guint8 *)&in6, offset + sizeof(*ri), l = 8);
+	    break;
+	case 3:
+	    tvb_memcpy(tvb, (guint8 *)&in6, offset + sizeof(*ri), l = 16);
+	    break;
+	default:
+	    l = -1;
+	    break;
+	}
+	if (l >= 0) {
+	    proto_tree_add_text(icmp6opt_tree, tvb,
+		offset + offsetof(struct nd_opt_route_info, nd_opt_rti_prefixlen),
+		1, "Prefix length: %u", ri->nd_opt_rti_prefixlen);
+	    tf = proto_tree_add_text(icmp6opt_tree, tvb,
+		offset + offsetof(struct nd_opt_route_info, nd_opt_rti_flags),
+		1, "Flags: 0x%02x", ri->nd_opt_rti_flags);
+	    field_tree = proto_item_add_subtree(tf, ett_icmpv6flag);
+	    proto_tree_add_text(field_tree, tvb,
+		offset + offsetof(struct nd_opt_route_info, nd_opt_rti_flags),
+		1, "%s",
+		decode_enumerated_bitfield(ri->nd_opt_rti_flags,
+		    ND_RA_FLAG_RTPREF_MASK, 8, names_router_pref,
+		    "Router preference: %s"));
+	    lifetime = pntohl(&ri->nd_opt_rti_lifetime);
+	    if (lifetime == 0xffffffff)
+		proto_tree_add_text(icmp6opt_tree, tvb,
+		    offset + offsetof(struct nd_opt_route_info, nd_opt_rti_lifetime),
+		    sizeof(ri->nd_opt_rti_lifetime), "Lifetime: infinity");
+	    else
+		proto_tree_add_text(icmp6opt_tree, tvb,
+		    offset + offsetof(struct nd_opt_route_info, nd_opt_rti_lifetime),
+		    sizeof(ri->nd_opt_rti_lifetime), "Lifetime: %u", lifetime);
+	    proto_tree_add_text(icmp6opt_tree, tvb,
+		offset + sizeof(*ri), l, "Prefix: %s", ip6_to_str(&in6));
+	} else {
+	    proto_tree_add_text(icmp6opt_tree, tvb,
+		offset + offsetof(struct nd_opt_hdr, nd_opt_len), 1,
+		"Invalid option length: %u", opt->nd_opt_len);
+	}
+	break;
+      }
     }
 
     offset += (opt->nd_opt_len << 3);
@@ -370,8 +472,6 @@ dissect_nodeinfo(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree
     guint16 flags;
     char dname[MAXDNAME];
     guint8 ipaddr[4];
-    const u_char *pd;
-    int top_level_offset;
 
     ni = &icmp6_nodeinfo;
     tvb_memcpy(tvb, (guint8 *)ni, offset, sizeof *ni);
@@ -480,11 +580,8 @@ dissect_nodeinfo(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree
 	    off = tvb_length_remaining(tvb, offset);
 	    break;
 	case ICMP6_NI_SUBJ_FQDN:
-	    /* XXXX - clean this up when packet-dns.c has been tvbuffified */
-	    tvb_compat(tvb, &pd, &top_level_offset);
-	    l = get_dns_name(pd, top_level_offset + offset + sizeof(*ni),
-	    	top_level_offset + offset + sizeof(*ni),
-		dname, sizeof(dname));
+	    l = get_dns_name(tvb, offset + sizeof(*ni),
+	    	offset + sizeof(*ni), dname, sizeof(dname));
 	    if (tvb_bytes_exist(tvb, offset + sizeof(*ni) + l, 1) &&
 	        tvb_get_guint8(tvb, offset + sizeof(*ni) + l) == 0) {
 		l++;
@@ -561,15 +658,13 @@ dissect_nodeinfo(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree
 		tvb_length_remaining(tvb, offset),
 		"DNS labels");
 	    field_tree = proto_item_add_subtree(tf, ett_nodeinfo_nodedns);
-	    /* XXXX - clean this up when packet-dns.c has been tvbuffified */
-	    tvb_compat(tvb, &pd, &top_level_offset);
 	    j = offset + sizeof (*ni) + sizeof(guint32);
 	    while (j < tvb_length(tvb)) {
-		l = get_dns_name(pd, top_level_offset + j,
-		   top_level_offset + offset + sizeof (*ni) + sizeof(guint32),
+		l = get_dns_name(tvb, j,
+		   offset + sizeof (*ni) + sizeof(guint32),
 		   dname,sizeof(dname));
-		if (tvb_bytes_exist(tvb, top_level_offset + j + l, 1) &&
-		    tvb_get_guint8(tvb, top_level_offset + j + l) == 0) {
+		if (tvb_bytes_exist(tvb, j + l, 1) &&
+		    tvb_get_guint8(tvb, j + l) == 0) {
 		    l++;
 		    proto_tree_add_text(field_tree, tvb, j, l,
 			"DNS label: %s (truncated)", dname);
@@ -803,6 +898,11 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     int offset;
     tvbuff_t *next_tvb;
 
+    if (check_col(pinfo->fd, COL_PROTOCOL))
+	col_set_str(pinfo->fd, COL_PROTOCOL, "ICMPv6");
+    if (check_col(pinfo->fd, COL_INFO))
+	col_clear(pinfo->fd, COL_INFO);
+
     offset = 0;
     tvb_memcpy(tvb, (guint8 *)&icmp6_hdr, offset, sizeof icmp6_hdr);
     dp = &icmp6_hdr;
@@ -957,8 +1057,6 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	break;
     }
 
-    if (check_col(pinfo->fd, COL_PROTOCOL))
-	col_set_str(pinfo->fd, COL_PROTOCOL, "ICMPv6");
     if (check_col(pinfo->fd, COL_INFO)) {
 	char typebuf[256], codebuf[256];
 
@@ -1043,59 +1141,25 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	/* decode... */
-	next_tvb = tvb_new_subset(tvb, offset + sizeof(*dp), -1, -1);
 	switch (dp->icmp6_type) {
 	case ICMP6_DST_UNREACH:
 	case ICMP6_TIME_EXCEEDED:
-	    /* tiny sanity check */
-	    if ((tvb_get_guint8(tvb, offset + sizeof(*dp)) & 0xf0) == 0x60) {
-		/* The invoking packet is an IPv6 datagram; dissect it.
-
-		   Set the columns non-writable, so that the packet list
-		   shows this as an ICMPv6 packet, not as the type of packet
-		   for which the ICMPv6 packet was generated. */
-		col_set_writable(pinfo->fd, FALSE);
-
-		call_dissector(ipv6_handle, next_tvb, pinfo, icmp6_tree);
-	    } else {
-		dissect_data(next_tvb, 0, pinfo, icmp6_tree);
-	    }
+	    dissect_contained_icmpv6(tvb, offset + sizeof(*dp), pinfo,
+		icmp6_tree);
 	    break;
 	case ICMP6_PACKET_TOO_BIG:
 	    proto_tree_add_text(icmp6_tree, tvb,
 		offset + offsetof(struct icmp6_hdr, icmp6_mtu), 4,
 		"MTU: %u", pntohl(&dp->icmp6_mtu));
-	    /* tiny sanity check */
-	    if ((tvb_get_guint8(tvb, offset + sizeof(*dp)) & 0xf0) == 0x60) {
-		/* The invoking packet is an IPv6 datagram; dissect it.
-
-		   Set the columns non-writable, so that the packet list
-		   shows this as an ICMPv6 packet, not as the type of packet
-		   for which the ICMPv6 packet was generated. */
-		col_set_writable(pinfo->fd, FALSE);
-
-		call_dissector(ipv6_handle, next_tvb, pinfo, icmp6_tree);
-	    } else {
-		dissect_data(next_tvb, 0, pinfo, icmp6_tree);
-	    }
+	    dissect_contained_icmpv6(tvb, offset + sizeof(*dp), pinfo,
+		icmp6_tree);
 	    break;
 	case ICMP6_PARAM_PROB:
 	    proto_tree_add_text(icmp6_tree, tvb,
 		offset + offsetof(struct icmp6_hdr, icmp6_pptr), 4,
 		"Problem pointer: 0x%04x", pntohl(&dp->icmp6_pptr));
-	    /* tiny sanity check */
-	    if ((tvb_get_guint8(tvb, offset + sizeof(*dp)) & 0xf0) == 0x60) {
-		/* The invoking packet is an IPv6 datagram; dissect it.
-
-		   Set the columns non-writable, so that the packet list
-		   shows this as an ICMPv6 packet, not as the type of packet
-		   for which the ICMPv6 packet was generated. */
-		col_set_writable(pinfo->fd, FALSE);
-
-		call_dissector(ipv6_handle, next_tvb, pinfo, icmp6_tree);
-	    } else {
-		dissect_data(next_tvb, 0, pinfo, icmp6_tree);
-	    }
+	    dissect_contained_icmpv6(tvb, offset + sizeof(*dp), pinfo,
+		icmp6_tree);
 	    break;
 	case ICMP6_ECHO_REQUEST:
 	case ICMP6_ECHO_REPLY:
@@ -1105,6 +1169,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    proto_tree_add_text(icmp6_tree, tvb,
 		offset + offsetof(struct icmp6_hdr, icmp6_seq), 2,
 		"Sequence: 0x%04x", (guint16)ntohs(dp->icmp6_seq));
+	    next_tvb = tvb_new_subset(tvb, offset + sizeof(*dp), -1, -1);
 	    dissect_data(next_tvb, 0, pinfo, icmp6_tree);
 	    break;
 	case ICMP6_MEMBERSHIP_QUERY:
@@ -1139,15 +1204,17 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    field_tree = proto_item_add_subtree(tf, ett_icmpv6flag);
 	    proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 		decode_boolean_bitfield(ra_flags,
-			0x80, 8, "Managed", "Not managed"));
+			ND_RA_FLAG_MANAGED, 8, "Managed", "Not managed"));
 	    proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 		decode_boolean_bitfield(ra_flags,
-			0x40, 8, "Other", "Not other"));
-    /* BT INSERT BEGIN */
+			ND_RA_FLAG_OTHER, 8, "Other", "Not other"));
 	    proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
 		decode_boolean_bitfield(ra_flags,
-			0x20, 8, "Home Agent", "Not Home Agent"));		
-    /* BT INSERT END */
+			ND_RA_FLAG_HOME_AGENT, 8,
+			"Home Agent", "Not Home Agent"));		
+	    proto_tree_add_text(field_tree, tvb, flagoff, 1, "%s",
+		decode_enumerated_bitfield(ra_flags, ND_RA_FLAG_RTPREF_MASK, 8,
+		names_router_pref, "Router preference: %s"));
 	    proto_tree_add_text(icmp6_tree, tvb,
 		offset + offsetof(struct nd_router_advert, nd_ra_router_lifetime),
 		2, "Router lifetime: %u",
@@ -1259,6 +1326,7 @@ dissect_icmpv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    dissect_nodeinfo(tvb, offset, pinfo, icmp6_tree);
 	    break;
 	default:
+	    next_tvb = tvb_new_subset(tvb, offset + sizeof(*dp), -1, -1);
 	    dissect_data(next_tvb, 0, pinfo, tree);
 	    break;
 	}
@@ -1271,16 +1339,16 @@ proto_register_icmpv6(void)
   static hf_register_info hf[] = {
     { &hf_icmpv6_type,
       { "Type",           "icmpv6.type",	FT_UINT8,  BASE_DEC, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_icmpv6_code,
       { "Code",           "icmpv6.code",	FT_UINT8,  BASE_DEC, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_icmpv6_checksum,
       { "Checksum",       "icmpv6.checksum",	FT_UINT16, BASE_HEX, NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
     { &hf_icmpv6_checksum_bad,
       { "Bad Checksum",   "icmpv6.checksum_bad", FT_BOOLEAN, BASE_NONE,	NULL, 0x0,
-	"" }},
+	"", HFILL }},
   };
   static gint *ett[] = {
     &ett_icmpv6,
