@@ -1,12 +1,11 @@
 /* packet-ip.c
  * Routines for IP and miscellaneous IP protocol packet disassembly
  *
- * $Id: packet-ip.c,v 1.131 2001/04/18 04:53:51 guy Exp $
+ * $Id: packet-ip.c,v 1.139 2001/06/29 09:46:52 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -47,6 +46,7 @@
 #include "resolv.h"
 #include "ipproto.h"
 #include "prefs.h"
+#include "reassemble.h"
 #include "etypes.h"
 #include "greproto.h"
 #include "ppptypes.h"
@@ -58,7 +58,6 @@
 #include "nlpid.h"
 
 static void dissect_icmp(tvbuff_t *, packet_info *, proto_tree *);
-static void dissect_igmp(tvbuff_t *, packet_info *, proto_tree *);
 
 /* Decode the old IPv4 TOS field as the DiffServ DS Field */
 static gboolean g_ip_dscp_actif = TRUE;
@@ -66,6 +65,9 @@ static gboolean g_ip_dscp_actif = TRUE;
 /* Defragment fragmented IP datagrams */
 static gboolean ip_defragment = FALSE;
 
+/* Place IP summary in proto tree */
+static gboolean ip_summary_in_tree = TRUE;
+
 static int proto_ip = -1;
 static int hf_ip_version = -1;
 static int hf_ip_hdr_len = -1;
@@ -114,15 +116,6 @@ static gint ett_ip_fragment  = -1;
 /* Used by IPv6 as well, so not static */
 dissector_table_t ip_dissector_table;
 
-static int proto_igmp = -1;
-static int hf_igmp_version = -1;
-static int hf_igmp_type = -1;
-static int hf_igmp_unused = -1;
-static int hf_igmp_checksum = -1;
-static int hf_igmp_group = -1;
-
-static gint ett_igmp = -1;
-
 static int proto_icmp = -1;
 static int hf_icmp_type = -1;
 static int hf_icmp_code = -1;
@@ -169,23 +162,6 @@ static gint ett_icmp = -1;
 #define ICMP_PREC_CUTOFF        15      /* Precedence cut off */
 
 
-/* IGMP structs and definitions */
-typedef struct _e_igmp {
-  guint8  igmp_v_t; /* combines igmp_v and igmp_t */
-  guint8  igmp_unused;
-  guint16 igmp_cksum;
-  guint32 igmp_gaddr;
-} e_igmp;
-
-#define IGMP_M_QRY     0x01
-#define IGMP_V1_M_RPT  0x02
-#define IGMP_V2_LV_GRP 0x07
-#define IGMP_DVMRP     0x03
-#define IGMP_PIM       0x04
-#define IGMP_V2_M_RPT  0x06
-#define IGMP_MTRC_RESP 0x1e
-#define IGMP_MTRC      0x1f
-
 /* IP structs and definitions */
 
 typedef struct _e_ip 
@@ -325,319 +301,14 @@ typedef struct _e_ip
 /*
  * defragmentation of IPv4
  */
-static GHashTable *ip_fragment_table=NULL;
-
-typedef struct _ip_fragment_key {
-	guint32	srcip;
-	guint32	dstip;
-	guint32	id;
-} ip_fragment_key;
-
-/* make sure that all flags that are set in a fragment entry is also set for
- * the flags field of ipfd_head !!!
- */
-/* only in ipfd_head: packet is defragmented */
-#define IPD_DEFRAGMENTED	0x0001
-/* there are overlapping fragments */
-#define IPD_OVERLAP		0x0002
-/* overlapping fragments contain different data */ 
-#define IPD_OVERLAPCONFLICT	0x0004  
-/* more than one fragment which indicates end-of data */
-#define IPD_MULTIPLETAILS	0x0008
-/* fragment contains data past the end of the datagram */
-#define IPD_TOOLONGFRAGMENT	0x0010
-typedef struct _ip_fragment_data {
-	struct _ip_fragment_data *next;
-	guint32 frame;
-	guint32	offset;
-	guint32	len;
-	guint32 datalen; /*Only valid in first item of list */
-	guint32 flags;
-	unsigned char *data;
-} ip_fragment_data;
-
-#define LINK_FRAG(ipfd_head,ipfd)					\
-	{ 	ip_fragment_data *ipfd_i;				\
-		/* add fragment to list, keep list sorted */		\
-		for(ipfd_i=ipfd_head;ipfd_i->next;ipfd_i=ipfd_i->next){	\
-			if( (ipfd->offset) < (ipfd_i->next->offset) )	\
-				break;					\
-		}							\
-		ipfd->next=ipfd_i->next;				\
-		ipfd_i->next=ipfd;					\
-	}
-
-
-static gint
-ip_fragment_equal(gconstpointer k1, gconstpointer k2)
-{
-	ip_fragment_key* key1 = (ip_fragment_key*) k1;
-	ip_fragment_key* key2 = (ip_fragment_key*) k2;
-
-	return ( ( (key1->srcip == key2->srcip) &&
-		   (key1->dstip == key2->dstip) &&
-		   (key1->id    == key2->id) 
-		 ) ?
-		 TRUE : FALSE);
-}
-
-static guint
-ip_fragment_hash(gconstpointer k)
-{
-	ip_fragment_key* key = (ip_fragment_key*) k;
-
-	return (key->srcip ^ key->dstip ^ key->id);
-}
-
-static gboolean
-free_all_fragments(gpointer key, gpointer value, gpointer user_data)
-{
-	ip_fragment_data *ipfd_head;
-	ip_fragment_data *ipfd_i;
-
-	ipfd_head=value;
-	while(ipfd_head){
-		ipfd_i=ipfd_head->next;
-		if(ipfd_head->data){
-			g_free(ipfd_head->data);
-		}
-		g_free(ipfd_head);
-		ipfd_head=ipfd_i;
-	}
-
-	g_free(key);
-	return TRUE;
-}
+static GHashTable *ip_fragment_table = NULL;
 
 static void
 ip_defragment_init(void)
 {
-	if( ip_fragment_table != NULL ){
-		/* The fragment hash table exists.
-		 * 
-		 * Remove all entries and free all memory.
-		 */
-		g_hash_table_foreach_remove(ip_fragment_table,free_all_fragments,NULL);
-	} else {
-		/* The fragment table does not exist. Create it */
-		ip_fragment_table = g_hash_table_new(ip_fragment_hash,
-				ip_fragment_equal);
-	}
+  fragment_table_init(&ip_fragment_table);
 }
 
-/* This function adds a new fragment to the fragment hash table
- * If this is the first fragment seen in for this ip packet,
- * a new entry is created in the hash table, otherwise
- * This fragment is just added to the linked list of 
- * fragments for this packet.
- * The list of fragments for a specific ip-packet is kept sorted for
- * easier handling.
- * tvb had better contain an IPv4 packet, or BAD things will probably happen.
- *
- * Returns a pointer to the head of the fragment data list if we have all the
- * fragments, NULL otherwise.
- */
-static ip_fragment_data *
-ip_fragment_add(tvbuff_t *tvb, int offset, packet_info *pinfo, guint32 id,
-		guint32 floff)
-{
-	ip_fragment_key *ipfk;
-	ip_fragment_data *ipfd_head;
-	ip_fragment_data *ipfd;
-	ip_fragment_data *ipfd_i;
-	guint32 frag_offset;
-	guint32 max,dfpos;
-
-
-	/* create key to search hash with */
-	ipfk=g_malloc(sizeof(ip_fragment_key));
-	memcpy(&ipfk->srcip, pinfo->src.data, sizeof(ipfk->srcip));
-	memcpy(&ipfk->dstip, pinfo->dst.data, sizeof(ipfk->dstip));
-	ipfk->id    = id;
-
-	ipfd_head=g_hash_table_lookup(ip_fragment_table, ipfk);
-
-
-	/* have we already seen this frame ?*/
-	if( pinfo->fd->flags.visited ){
-		g_free(ipfk);
-		if (ipfd_head != NULL && ipfd_head->flags & IPD_DEFRAGMENTED) {
-			return ipfd_head;
-		} else {
-			return NULL;
-		}
-	}
-
-
-
-	frag_offset = (floff & IP_OFFSET)*8;
-
-	if (ipfd_head==NULL){
-		/* not found, this must be the first snooped fragment for this
-                 * ip packet. Create list-head.
-		 */
-		ipfd_head=g_malloc(sizeof(ip_fragment_data));
-		/* head/first structure in list only holds no other data than
-                 * 'datalen' then we dont have to change the head of the list
-                 * even if we want to keep it sorted
-                 */
-		ipfd_head->next=NULL;
-		ipfd_head->datalen=0;
-		ipfd_head->offset=0;
-		ipfd_head->len=0;
-		ipfd_head->flags=0;
-		ipfd_head->data=NULL;
-		g_hash_table_insert(ip_fragment_table, ipfk, ipfd_head);
-	} else {
-		/* this was not the first fragment, so we can throw ipfk 
-		 * away, only used for the first fragment, 3 lines up
-		 */
-		g_free(ipfk);
-	}
-
-
-	/* create new ipfd describing this fragment */
-	ipfd = g_malloc(sizeof(ip_fragment_data));
-	ipfd->next = NULL;
-	ipfd->flags = 0;
-	ipfd->frame = pinfo->fd->num;
-	ipfd->offset = frag_offset;
-	ipfd->len  = pinfo->iplen;
-	ipfd->len  -= (pinfo->iphdrlen*4);
-	ipfd->data = NULL;
-
-
-
-	if( !(floff&IP_MF) ){  
-		/* this is a tail fragment */
-		if (ipfd_head->datalen) {
-			/* ok we have already seen other tails for this packet
-			 * it might be a duplicate.
-			 */
-			if (ipfd_head->datalen != (ipfd->offset + ipfd->len) ){
-				/* Oops, this tail indicates a different packet
-				 * len than the previous ones. Somethings wrong
-				 */
-				ipfd->flags      |= IPD_MULTIPLETAILS;
-				ipfd_head->flags |= IPD_MULTIPLETAILS;
-			}
-		} else {
-			/* this was the first tail fragment, now we know the
-			 * length of the packet
-			 */
-			ipfd_head->datalen = ipfd->offset + ipfd->len;
-		}
-	}
-
-
-
-
-	/* If the packet is already defragmented, this MUST be an overlap.
-         * The entire defragmented packet is in ipfd_head->data
-	 * Even if we have previously defragmented this packet, we still check
-	 * check it. Someone might play overlap and TTL games.
-         */
-	if (ipfd_head->flags & IPD_DEFRAGMENTED) {
-		ipfd->flags      |= IPD_OVERLAP;
-		ipfd_head->flags |= IPD_OVERLAP;
-		/* make sure its not too long */
-		if (ipfd->offset + ipfd->len > ipfd_head->datalen) {
-			ipfd->flags      |= IPD_TOOLONGFRAGMENT;
-			ipfd_head->flags |= IPD_TOOLONGFRAGMENT;
-			LINK_FRAG(ipfd_head,ipfd);
-			return (ipfd_head);
-		}
-		/* make sure it doesnt conflict with previous data */
-		if ( memcmp(ipfd_head->data+ipfd->offset,
-			tvb_get_ptr(tvb,offset,ipfd->len),ipfd->len) ){
-			ipfd->flags      |= IPD_OVERLAPCONFLICT;
-			ipfd_head->flags |= IPD_OVERLAPCONFLICT;
-			LINK_FRAG(ipfd_head,ipfd);
-			return (ipfd_head);
-		}
-		/* it was just an overlap, link it and return */
-		LINK_FRAG(ipfd_head,ipfd);
-		return (ipfd_head);
-	}
-
-
-
-	/* If we have reached this point, the packet is not defragmented yet.
-         * Save all payload in a buffer until we can defragment.
-	 */
-	ipfd->data = g_malloc(ipfd->len);
-	tvb_memcpy(tvb, ipfd->data, offset, ipfd->len);
-	LINK_FRAG(ipfd_head,ipfd);
-
-
-	if( !(ipfd_head->datalen) ){
-		/* if we dont know the datalen, there are still missing
-		 * packets. Cheaper than the check below.
-		 */
-		return NULL;
-	}
-
-
-	/* check if we have received the entire fragment
-	 * this is easy since the list is sorted and the head is faked.
-	 */
-	max = 0;
-	for (ipfd_i=ipfd_head->next;ipfd_i;ipfd_i=ipfd_i->next) {
-		if ( ((ipfd_i->offset)<=max) && 
-		    ((ipfd_i->offset+ipfd_i->len)>max) ){
-			max = ipfd_i->offset+ipfd_i->len;
-		}
-	}
-
-	if (max < (ipfd_head->datalen)) {
-		/* we have not received all packets yet */
-		return NULL;
-	}
-
-
-	if (max > (ipfd_head->datalen)) {
-		/* oops, too long fragment detected */
-		ipfd->flags      |= IPD_TOOLONGFRAGMENT;
-		ipfd_head->flags |= IPD_TOOLONGFRAGMENT;
-	}
-
-
-	/* we have received an entire packet, defragment it and
-         * free all fragments 
-         */
-	ipfd_head->data = g_malloc(max);
-
-	/* add all data fragments */
-	for (dfpos=0,ipfd_i=ipfd_head;ipfd_i;ipfd_i=ipfd_i->next) {
-		if (ipfd_i->len) {
-			if (ipfd_i->offset < dfpos) {
-				ipfd_i->flags    |= IPD_OVERLAP;
-				ipfd_head->flags |= IPD_OVERLAP;
-				if ( memcmp(ipfd_head->data+ipfd_i->offset,
-					ipfd_i->data,
-					MIN(ipfd_i->len,(dfpos-ipfd_i->offset))
-				   	) ){
-					ipfd_i->flags    |= IPD_OVERLAPCONFLICT;
-					ipfd_head->flags |= IPD_OVERLAPCONFLICT;
-				}
-			}
-			memcpy(ipfd_head->data+ipfd_i->offset,ipfd_i->data,ipfd_i->len);
-			g_free(ipfd_i->data);
-			ipfd_i->data=NULL;
-
-			dfpos=MAX(dfpos,(ipfd_i->offset+ipfd_i->len));
-		}
-	}
-
-	/* mark this packet as defragmented.
-           allows us to skip any trailing fragments */
-	ipfd_head->flags |= IPD_DEFRAGMENTED;
-
-	return ipfd_head;
-}
-
-
-
 void
 capture_ip(const u_char *pd, int offset, packet_counts *ld) {
   if (!BYTES_ARE_IN_FRAME(offset, IPH_MIN_LEN)) {
@@ -950,7 +621,7 @@ dissect_ip_tcp_options(tvbuff_t *tvb, int offset, guint length,
   u_char            opt;
   const ip_tcp_opt *optp;
   opt_len_type      len_type;
-  int               optlen;
+  unsigned int      optlen;
   char             *name;
   char              name_str[7+1+1+2+2+1+1];	/* "Unknown (0x%02x)" */
   void            (*dissect)(const struct ip_tcp_opt *, tvbuff_t *,
@@ -1121,11 +792,12 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   proto_tree *ip_tree = NULL, *field_tree;
   proto_item *ti, *tf;
   int        offset = 0;
-  guint      hlen, optlen, len, payload_len, reported_payload_len, padding;
+  guint      hlen, optlen, len;
+  int        padding;
   guint16    flags;
   guint8     nxt;
   guint16    ipsum;
-  ip_fragment_data *ipfd_head;
+  fragment_data *ipfd_head;
   tvbuff_t   *next_tvb;
   packet_info save_pi;
   gboolean must_restore_pi = FALSE;
@@ -1143,38 +815,23 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   iph.ip_off = ntohs(iph.ip_off);
   iph.ip_sum = ntohs(iph.ip_sum);
 
-  /* Length of payload handed to us. */
-  reported_payload_len = tvb_reported_length(tvb);
-  payload_len = tvb_length(tvb);
-
   /* Length of IP datagram. */
   len = iph.ip_len;
 
-  if (len < reported_payload_len) {
-    /* Adjust the length of this tvbuff to include only the IP datagram.
-       Our caller may use that to determine how much of its packet
-       was padding. */
-    tvb_set_reported_length(tvb, len);
-
-    /* Shrink the total payload by the amount of padding. */
-    padding = reported_payload_len - len;
-    if (pinfo->len >= padding)
-      pinfo->len -= padding;
-
-    /* Shrink the captured payload by the amount of padding in the
-       captured payload (which may be less than the amount of padding,
-       as the padding may not have been captured). */
-    if (len < payload_len) {
-      padding = payload_len - len;
-      if (pinfo->captured_len >= padding)
-        pinfo->captured_len -= padding;
-    }
-  }
+  /* Adjust the length of this tvbuff to include only the IP datagram. */
+  set_actual_length(tvb, pinfo, len);
 
   hlen = lo_nibble(iph.ip_v_hl) * 4;	/* IP header length, in bytes */
  
   if (tree) {
-    ti = proto_tree_add_item(tree, proto_ip, tvb, offset, hlen, FALSE);
+    if (ip_summary_in_tree && hlen >= IPH_MIN_LEN) {
+      ti = proto_tree_add_protocol_format(tree, proto_ip, tvb, offset, hlen,
+		"Internet Protocol, Src Addr: %s (%s), Dst Addr: %s (%s)",
+		get_hostname(iph.ip_src), ip_to_str((guint8 *) &iph.ip_src),
+		get_hostname(iph.ip_dst), ip_to_str((guint8 *) &iph.ip_dst));
+    } else {
+      ti = proto_tree_add_item(tree, proto_ip, tvb, offset, hlen, FALSE);
+    }
     ip_tree = proto_item_add_subtree(ti, ett_ip);
   }
 
@@ -1290,13 +947,17 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
        Add the fragment to the hash table if the checksum is ok
        and the frame isn't truncated. */
     if ((ipsum==0) && (tvb_reported_length(tvb) <= tvb_length(tvb))) {
-      ipfd_head = ip_fragment_add(tvb, offset, pinfo, iph.ip_id, iph.ip_off);
+      ipfd_head = fragment_add(tvb, offset, pinfo, iph.ip_id,
+			       ip_fragment_table,
+			       (iph.ip_off & IP_OFFSET)*8,
+			       pinfo->iplen - (pinfo->iphdrlen*4),
+			       iph.ip_off & IP_MF);
     } else {
       ipfd_head=NULL;
     }
 
     if (ipfd_head != NULL) {
-      ip_fragment_data *ipfd;
+      fragment_data *ipfd;
       proto_tree *ft=NULL;
       proto_item *fi=NULL;
 
@@ -1306,8 +967,8 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 tvb, 0, 0, FALSE);
       ft = proto_item_add_subtree(fi, ett_ip_fragments);
       for (ipfd=ipfd_head->next; ipfd; ipfd=ipfd->next){
-        if (ipfd->flags & (IPD_OVERLAP|IPD_OVERLAPCONFLICT
-                          |IPD_MULTIPLETAILS|IPD_TOOLONGFRAGMENT) ) {
+        if (ipfd->flags & (FD_OVERLAP|FD_OVERLAPCONFLICT
+                          |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
           /* this fragment has some flags set, create a subtree 
            * for it and display the flags.
            */
@@ -1315,44 +976,44 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
           proto_item *fei=NULL;
           int hf;
 
-          if (ipfd->flags & (IPD_OVERLAPCONFLICT
-                      |IPD_MULTIPLETAILS|IPD_TOOLONGFRAGMENT) ) {
+          if (ipfd->flags & (FD_OVERLAPCONFLICT
+                      |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
             hf = hf_ip_fragment_error;
           } else {
             hf = hf_ip_fragment;
           }
-          fei = proto_tree_add_string_format(ft, hf, 
-                   tvb, 0, 0, 0,
+          fei = proto_tree_add_none_format(ft, hf, 
+                   tvb, 0, 0,
                    "Frame:%d payload:%d-%d",
                    ipfd->frame,
                    ipfd->offset,
                    ipfd->offset+ipfd->len-1
           );
           fet = proto_item_add_subtree(fei, ett_ip_fragment);
-          if (ipfd->flags&IPD_OVERLAP) {
+          if (ipfd->flags&FD_OVERLAP) {
             proto_tree_add_boolean(fet, 
                  hf_ip_fragment_overlap, tvb, 0, 0, 
                  TRUE);
           }
-          if (ipfd->flags&IPD_OVERLAPCONFLICT) {
+          if (ipfd->flags&FD_OVERLAPCONFLICT) {
             proto_tree_add_boolean(fet, 
                  hf_ip_fragment_overlap_conflict, tvb, 0, 0, 
                  TRUE);
           }
-          if (ipfd->flags&IPD_MULTIPLETAILS) {
+          if (ipfd->flags&FD_MULTIPLETAILS) {
             proto_tree_add_boolean(fet, 
                  hf_ip_fragment_multiple_tails, tvb, 0, 0, 
                  TRUE);
           }
-          if (ipfd->flags&IPD_TOOLONGFRAGMENT) {
+          if (ipfd->flags&FD_TOOLONGFRAGMENT) {
             proto_tree_add_boolean(fet, 
                  hf_ip_fragment_too_long_fragment, tvb, 0, 0, 
                  TRUE);
           }
         } else {
           /* nothing of interest for this fragment */
-          proto_tree_add_string_format(ft, hf_ip_fragment, 
-                   tvb, 0, 0, 0,
+          proto_tree_add_none_format(ft, hf_ip_fragment, 
+                   tvb, 0, 0,
                    "Frame:%d payload:%d-%d",
                    ipfd->frame,
                    ipfd->offset,
@@ -1360,8 +1021,8 @@ dissect_ip(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
           );
         }
       }
-      if (ipfd_head->flags & (IPD_OVERLAPCONFLICT
-                        |IPD_MULTIPLETAILS|IPD_TOOLONGFRAGMENT) ) {
+      if (ipfd_head->flags & (FD_OVERLAPCONFLICT
+                        |FD_MULTIPLETAILS|FD_TOOLONGFRAGMENT) ) {
         if (check_col(pinfo->fd, COL_INFO)) {
           col_set_str(pinfo->fd, COL_INFO, "[Illegal fragments]");
           update_col_info = FALSE;
@@ -1720,109 +1381,6 @@ dissect_icmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   }
 }
 
-static void
-dissect_igmp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
-{
-  e_igmp     ih;
-  proto_tree *igmp_tree;
-  proto_item *ti;
-  gchar      *type_str;
-
-  if (check_col(pinfo->fd, COL_PROTOCOL))
-    col_set_str(pinfo->fd, COL_PROTOCOL, "IGMP");
-  if (check_col(pinfo->fd, COL_INFO))
-    col_clear(pinfo->fd, COL_INFO);
-
-  /* Avoids alignment problems on many architectures. */
-  memcpy(&ih, tvb_get_ptr(tvb, 0, sizeof(e_igmp)), sizeof(e_igmp));
-  
-  switch (lo_nibble(ih.igmp_v_t)) {
-    case IGMP_M_QRY:
-      type_str = "Router query";
-      break;
-    case IGMP_V1_M_RPT:
-      type_str = "Host response (v1)";
-      break;
-    case IGMP_V2_LV_GRP:
-      type_str = "Leave group (v2)";
-      break;
-    case IGMP_DVMRP:
-      type_str = "DVMRP";
-      break;
-    case IGMP_PIM:
-      type_str = "PIM";
-      break;
-    case IGMP_V2_M_RPT:
-      type_str = "Host response (v2)";
-      break;
-    case IGMP_MTRC_RESP:
-      type_str = "Traceroute response";
-      break;
-    case IGMP_MTRC:
-      type_str = "Traceroute message";
-      break;
-    default:
-      type_str = "Unknown IGMP";
-  }
-
-  if (check_col(pinfo->fd, COL_INFO))
-    col_add_str(pinfo->fd, COL_INFO, type_str);
-  if (tree) {
-    ti = proto_tree_add_item(tree, proto_igmp, tvb, 0, 8, FALSE);
-    igmp_tree = proto_item_add_subtree(ti, ett_igmp);
-    proto_tree_add_uint(igmp_tree, hf_igmp_version, tvb, 0,     1, 
-			hi_nibble(ih.igmp_v_t));
-    proto_tree_add_uint_format(igmp_tree, hf_igmp_type, tvb,  0    , 1, 
-			       lo_nibble(ih.igmp_v_t),
-			       "Type: %u (%s)",
-			       lo_nibble(ih.igmp_v_t), type_str);
-    proto_tree_add_item(igmp_tree, hf_igmp_unused, tvb,  1, 1, FALSE);
-    proto_tree_add_item(igmp_tree, hf_igmp_checksum, tvb,  2, 2, FALSE);
-    proto_tree_add_ipv4(igmp_tree, hf_igmp_group, tvb,  4, 4, ih.igmp_gaddr);
-  }
-}
-
-void
-proto_register_igmp(void)
-{
-	static hf_register_info hf[] = {
-
-		{ &hf_igmp_version,
-		{ "Version",		"igmp.version", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
-
-		{ &hf_igmp_type,
-		{ "Type",		"igmp.type", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
-
-		{ &hf_igmp_unused,
-		{ "Unused",		"igmp.unused", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"" }},
-
-		{ &hf_igmp_checksum,
-		{ "Checksum",		"igmp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
-
-		{ &hf_igmp_group,
-		{ "Group address",	"igmp.group", FT_IPv4, BASE_NONE, NULL, 0x0,
-			"" }},
-	};
-	static gint *ett[] = {
-		&ett_igmp,
-	};
-
-	proto_igmp = proto_register_protocol("Internet Group Management Protocol",
-	    "IGMP", "igmp");
-	proto_register_field_array(proto_igmp, hf, array_length(hf));
-	proto_register_subtree_array(ett, array_length(ett));
-}
-
-void
-proto_reg_handoff_igmp(void)
-{
-	dissector_add("ip.proto", IP_PROTO_IGMP, dissect_igmp, proto_igmp);
-}
-
 void
 proto_register_ip(void)
 {
@@ -1830,139 +1388,139 @@ proto_register_ip(void)
 
 		{ &hf_ip_version,
 		{ "Version",		"ip.version", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_hdr_len,
 		{ "Header Length",	"ip.hdr_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_dsfield,
 		{ "Differentiated Services field",	"ip.dsfield", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_dsfield_dscp,
 		{ "Differentiated Services Codepoint",	"ip.dsfield.dscp", FT_UINT8, BASE_HEX,
 			VALS(dscp_vals), IPDSFIELD_DSCP_MASK,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_dsfield_ect,
 		{ "ECN-Capable Transport (ECT)",	"ip.dsfield.ect", FT_UINT8, BASE_DEC, NULL,
 			IPDSFIELD_ECT_MASK,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_dsfield_ce,
 		{ "ECN-CE",	"ip.dsfield.ce", FT_UINT8, BASE_DEC, NULL,
 			IPDSFIELD_CE_MASK,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos,
 		{ "Type of Service",	"ip.tos", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos_precedence,
 		{ "Precedence",		"ip.tos.precedence", FT_UINT8, BASE_DEC, VALS(precedence_vals),
 			IPTOS_PREC_MASK,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos_delay,
 		{ "Delay",		"ip.tos.delay", FT_BOOLEAN, 8, TFS(&tos_set_low),
 			IPTOS_LOWDELAY,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos_throughput,
 		{ "Throughput",		"ip.tos.throughput", FT_BOOLEAN, 8, TFS(&tos_set_high),
 			IPTOS_THROUGHPUT,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos_reliability,
 		{ "Reliability",	"ip.tos.reliability", FT_BOOLEAN, 8, TFS(&tos_set_high),
 			IPTOS_RELIABILITY,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_tos_cost,
 		{ "Cost",		"ip.tos.cost", FT_BOOLEAN, 8, TFS(&tos_set_low),
 			IPTOS_LOWCOST,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_len,
 		{ "Total Length",	"ip.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_id,
 		{ "Identification",	"ip.id", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_dst,
 		{ "Destination",	"ip.dst", FT_IPv4, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_src,
 		{ "Source",		"ip.src", FT_IPv4, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_addr,
 		{ "Source or Destination Address", "ip.addr", FT_IPv4, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_flags,
 		{ "Flags",		"ip.flags", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_flags_df,
 		{ "Don't fragment",	"ip.flags.df", FT_BOOLEAN, 4, TFS(&flags_set_truth), IP_DF>>12,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_flags_mf,
 		{ "More fragments",	"ip.flags.mf", FT_BOOLEAN, 4, TFS(&flags_set_truth), IP_MF>>12,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_frag_offset,
 		{ "Fragment offset",	"ip.frag_offset", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_ttl,
 		{ "Time to live",	"ip.ttl", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_proto,
 		{ "Protocol",		"ip.proto", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_checksum,
 		{ "Header checksum",	"ip.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_checksum_bad,
 		{ "Bad Header checksum",	"ip.checksum_bad", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ip_fragment_overlap,
 		{ "Fragment overlap",	"ip.fragment.overlap", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"Fragment overlaps with other fragments" }},
+			"Fragment overlaps with other fragments", HFILL }},
 
 		{ &hf_ip_fragment_overlap_conflict,
 		{ "Conflicting data in fragment overlap",	"ip.fragment.overlap.conflict", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"Overlapping fragments contained conflicting data" }},
+			"Overlapping fragments contained conflicting data", HFILL }},
 
 		{ &hf_ip_fragment_multiple_tails,
 		{ "Multiple tail fragments found",	"ip.fragment.multipletails", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"Several tails were found when defragmenting the packet" }},
+			"Several tails were found when defragmenting the packet", HFILL }},
 
 		{ &hf_ip_fragment_too_long_fragment,
 		{ "Fragment too long",	"ip.fragment.toolongfragment", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"Fragment contained data past end of packet" }},
+			"Fragment contained data past end of packet", HFILL }},
 
 		{ &hf_ip_fragment_error,
-		{ "Defragmentation error",	"ip.fragment.error", FT_STRING, BASE_DEC, NULL, 0x0,
-			"Defragmentation error due to illegal fragments" }},
+		{ "Defragmentation error", "ip.fragment.error", FT_NONE, BASE_NONE, NULL, 0x0,
+			"Defragmentation error due to illegal fragments", HFILL }},
 
 		{ &hf_ip_fragment,
-		{ "IP Fragment", "ip.fragment", FT_STRING, BASE_DEC, NULL, 0x0,
-			"IP Fragment" }},
+		{ "IP Fragment", "ip.fragment", FT_NONE, BASE_NONE, NULL, 0x0,
+			"IP Fragment", HFILL }},
 
 		{ &hf_ip_fragments,
-		{ "IP Fragments", "ip.fragments", FT_STRING, BASE_DEC, NULL, 0x0,
-			"IP Fragments" }},
+		{ "IP Fragments", "ip.fragments", FT_NONE, BASE_NONE, NULL, 0x0,
+			"IP Fragments", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_ip,
@@ -1985,16 +1543,20 @@ proto_register_ip(void)
 	/* subdissector code */
 	ip_dissector_table = register_dissector_table("ip.proto");
 
-	/* Register a configuration option for decoding TOS as DSCP */
+	/* Register configuration options */
 	ip_module = prefs_register_protocol(proto_ip, NULL);
 	prefs_register_bool_preference(ip_module, "decode_tos_as_diffserv",
 	    "Decode IPv4 TOS field as DiffServ field",
-"Whether the IPv4 type-of-service field should be decoded as a Differentiated Services field",
+	    "Whether the IPv4 type-of-service field should be decoded as a Differentiated Services field",
 	    &g_ip_dscp_actif);
 	prefs_register_bool_preference(ip_module, "defragment",
 		"Reassemble fragmented IP datagrams",
 		"Whether fragmented IP datagrams should be reassembled",
 		&ip_defragment);
+	prefs_register_bool_preference(ip_module, "ip_summary_in_tree",
+	    "Show IP summary in protocol tree",
+	    "Whether the IP summary line should be shown in the protocol tree",
+	    &ip_summary_in_tree);
 
 	register_dissector("ip", dissect_ip, proto_ip);
 	register_init_routine(ip_defragment_init);
@@ -2022,19 +1584,19 @@ proto_register_icmp(void)
     
     { &hf_icmp_type,
       { "Type",		"icmp.type",		FT_UINT8, BASE_DEC,	NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
 
     { &hf_icmp_code,
       { "Code",		"icmp.code",		FT_UINT8, BASE_HEX,	NULL, 0x0,
-      	"" }},    
+      	"", HFILL }},    
 
     { &hf_icmp_checksum,
       { "Checksum",	"icmp.checksum",	FT_UINT16, BASE_HEX,	NULL, 0x0,
-      	"" }},
+      	"", HFILL }},
 
     { &hf_icmp_checksum_bad,
       { "Bad Checksum",	"icmp.checksum_bad",	FT_BOOLEAN, BASE_NONE,	NULL, 0x0,
-	"" }},
+	"", HFILL }},
   };
   static gint *ett[] = {
     &ett_icmp,
