@@ -3,7 +3,7 @@
  *
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-ipp.c,v 1.17 2000/11/19 08:53:58 guy Exp $
+ * $Id: packet-ipp.c,v 1.22 2001/01/11 06:30:54 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -556,29 +556,17 @@ proto_register_ipp(void)
 		&ett_ipp_attr,
 	};
 
-        proto_ipp = proto_register_protocol("Internet Printing Protocol", "ipp");
+        proto_ipp = proto_register_protocol("Internet Printing Protocol",
+	    "IPP", "ipp");
  /*       proto_register_field_array(proto_ipp, hf, array_length(hf));*/
 	proto_register_subtree_array(ett, array_length(ett));
-
-	/*
-	 * Register the dissector by name, so other dissectors can
-	 * grab it by name rather than just referring to it directly
-	 * (you can't refer to it directly from a plugin dissector
-	 * on Windows without stuffing it into the Big Transfer Vector).
-	 */
-	register_dissector("ipp", dissect_ipp);
 }
 
 void
 proto_reg_handoff_ipp(void)
 {
-	/* XXX - should we just register ourselves as a dissector,
-	   and call the HTTP dissector?
-
-	   Should we pass to it a pointer to our dissector, so that
-	   it knows to call us?
-
-	   Or should the HTTP dissector decide that the payload is
-	   IPP based on the MIME headers? */
-	dissector_add("tcp.port", 631, dissect_http);
+	/*
+	 * Register ourselves as running atop HTTP and using port 631.
+	 */
+	http_dissector_add(631, dissect_ipp, proto_ipp);
 }
