@@ -2,12 +2,11 @@
  * Routines for NetWare's IPX
  * Gilbert Ramirez <gram@xiexie.org>
  *
- * $Id: packet-ipx.c,v 1.85 2001/05/03 22:50:33 guy Exp $
+ * $Id: packet-ipx.c,v 1.88 2001/07/03 04:56:45 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -202,8 +201,6 @@ static void
 dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	tvbuff_t	*next_tvb;
-	const guint8	*this_pd;
-	int		this_offset, len;
 
 	proto_tree	*ipx_tree;
 	proto_item	*ti;
@@ -212,7 +209,6 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 	guint8		ipx_type, ipx_hops;
 	guint16		ipx_length;
-	int		reported_length, available_length;
 
 	guint16		ipx_dsocket, ipx_ssocket;
 
@@ -227,23 +223,16 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	ipx_type	= tvb_get_guint8(tvb, 5);
 	ipx_length	= tvb_get_ntohs(tvb, 2);
 
-	/* Set the payload and captured-payload lengths to the minima of
-	   (the IPX length plus the length of the headers above it) and
-	   the frame lengths. XXX - remove once all dissectors use tvbuffs */
-	tvb_compat(tvb, &this_pd, &this_offset);
-	len = ipx_length + this_offset;
-	if (pi.len > len)
-		pi.len = len;
-	if (pi.captured_len > len)
-		pi.captured_len = len;
+	/* Adjust the tvbuff length to include only the IPX datagram. */
+	set_actual_length(tvb, pinfo, ipx_length);
 
 	src_net_node = tvb_get_ptr(tvb, 18, 10);
 	dst_net_node = tvb_get_ptr(tvb, 6,  10);
 
-	SET_ADDRESS(&pi.net_src,	AT_IPX, 10, src_net_node);
-	SET_ADDRESS(&pi.src,		AT_IPX, 10, src_net_node);
-	SET_ADDRESS(&pi.net_dst,	AT_IPX, 10, dst_net_node);
-	SET_ADDRESS(&pi.dst,		AT_IPX, 10, dst_net_node);
+	SET_ADDRESS(&pinfo->net_src,	AT_IPX, 10, src_net_node);
+	SET_ADDRESS(&pinfo->src,	AT_IPX, 10, src_net_node);
+	SET_ADDRESS(&pinfo->net_dst,	AT_IPX, 10, dst_net_node);
+	SET_ADDRESS(&pinfo->dst,	AT_IPX, 10, dst_net_node);
 
 	if (check_col(pinfo->fd, COL_INFO))
 		col_add_fstr(pinfo->fd, COL_INFO, "%s (0x%04X)",
@@ -278,11 +267,7 @@ dissect_ipx(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 
 	/* Make the next tvbuff */
-	reported_length = ipx_length - IPX_HEADER_LEN;
-	available_length = tvb_length(tvb) - IPX_HEADER_LEN;
-	next_tvb = tvb_new_subset(tvb, IPX_HEADER_LEN,
-			MIN(available_length, reported_length),
-			reported_length);
+	next_tvb = tvb_new_subset(tvb, IPX_HEADER_LEN, -1, -1);
 
 	if (dissector_try_port(ipx_type_dissector_table, ipx_type, next_tvb,
 	    pinfo, tree))
@@ -662,117 +647,117 @@ proto_register_ipx(void)
 	static hf_register_info hf_ipx[] = {
 		{ &hf_ipx_checksum,
 		{ "Checksum",		"ipx.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_len,
 		{ "Length",		"ipx.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_hops,
 		{ "Transport Control (Hops)", "ipx.hops", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_packet_type,
 		{ "Packet Type",	"ipx.packet_type", FT_UINT8, BASE_HEX, VALS(ipx_packet_type_vals),
 			0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_dnet,
 		{ "Destination Network","ipx.dst.net", FT_IPXNET, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_dnode,
 		{ "Destination Node",	"ipx.dst.node", FT_ETHER, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_dsocket,
 		{ "Destination Socket",	"ipx.dst.socket", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_snet,
 		{ "Source Network","ipx.src.net", FT_IPXNET, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_snode,
 		{ "Source Node",	"ipx.src.node", FT_ETHER, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_ipx_ssocket,
 		{ "Source Socket",	"ipx.src.socket", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 	};
 
 	static hf_register_info hf_spx[] = {
 		{ &hf_spx_connection_control,
 		{ "Connection Control",		"spx.ctl", 
 		  FT_UINT8,	BASE_HEX,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_datastream_type,
 		{ "Datastream type",	       	"spx.type", 
 		  FT_UINT8,	BASE_HEX,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_src_id,
 		{ "Source Connection ID",	"spx.src", 
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_dst_id,
 		{ "Destination Connection ID",	"spx.dst", 
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_seq_nr,
 		{ "Sequence Number",		"spx.seq", 
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_ack_nr,
 		{ "Acknowledgment Number",	"spx.ack", 
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "" }},
+		  "", HFILL }},
 
 		{ &hf_spx_all_nr,
 		{ "Allocation Number",		"spx.alloc", 
 		  FT_UINT16,	BASE_DEC,	NULL,	0x0,
-		  "" }}
+		  "", HFILL }}
 	};
 
 	static hf_register_info hf_ipxrip[] = {
 		{ &hf_ipxrip_request,
 		{ "Request",			"ipxrip.request", 
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if IPX RIP request" }},
+		  "TRUE if IPX RIP request", HFILL }},
 
 		{ &hf_ipxrip_response,
 		{ "Response",			"ipxrip.response", 
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if IPX RIP response" }}
+		  "TRUE if IPX RIP response", HFILL }}
 	};
 
 	static hf_register_info hf_sap[] = {
 		{ &hf_sap_request,
 		{ "Request",			"ipxsap.request", 
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if SAP request" }},
+		  "TRUE if SAP request", HFILL }},
 
 		{ &hf_sap_response,
 		{ "Response",			"ipxsap.response", 
 		  FT_BOOLEAN,	BASE_NONE,	NULL,	0x0,
-		  "TRUE if SAP response" }}
+		  "TRUE if SAP response", HFILL }}
 	};
 
 	static hf_register_info hf_ipxmsg[] = {
 		{ &hf_msg_conn,
 		{ "Connection Number",			"ipxmsg.conn", 
 		  FT_UINT8,	BASE_DEC,	NULL,	0x0,
-		  "Connection Number" }},
+		  "Connection Number", HFILL }},
 
 		{ &hf_msg_sigchar,
 		{ "Signature Char",			"ipxmsg.sigchar", 
 		  FT_UINT8,	BASE_DEC,	VALS(ipxmsg_sigchar_vals),	0x0,
-		  "Signature Char" }}
+		  "Signature Char", HFILL }}
 	};
 
 	static gint *ett[] = {
