@@ -1,13 +1,12 @@
 /* packet-isis-hello.c
  * Routines for decoding isis hello packets and their CLVs
  *
- * $Id: packet-isis-hello.c,v 1.14 2001/05/14 18:40:15 guy Exp $
+ * $Id: packet-isis-hello.c,v 1.20 2001/07/02 01:41:25 guy Exp $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +53,8 @@ static int hf_isis_hello_lan_id              = -1;
 static int hf_isis_hello_local_circuit_id    = -1;
 static int hf_isis_hello_clv_ipv4_int_addr   = -1;
 static int hf_isis_hello_clv_ipv6_int_addr   = -1;
+static int hf_isis_hello_clv_ptp_adj         = -1;
+static int hf_isis_hello_clv_mt              = -1;
 
 static gint ett_isis_hello                   = -1;
 static gint ett_isis_hello_clv_area_addr     = -1;
@@ -64,6 +65,8 @@ static gint ett_isis_hello_clv_nlpid         = -1;
 static gint ett_isis_hello_clv_auth          = -1;
 static gint ett_isis_hello_clv_ipv4_int_addr = -1;
 static gint ett_isis_hello_clv_ipv6_int_addr = -1;
+static gint ett_isis_hello_clv_ptp_adj       = -1;
+static gint ett_isis_hello_clv_mt            = -1;
 
 static const value_string isis_hello_circuit_type_vals[] = {
 	{ ISIS_HELLO_TYPE_RESERVED,	"Reserved 0 (discard PDU)"},
@@ -75,20 +78,34 @@ static const value_string isis_hello_circuit_type_vals[] = {
 /* 
  * Predclare dissectors for use in clv dissection.
  */
-static void dissect_hello_area_address_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_is_neighbors_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_padding_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_nlpid_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_ip_int_addr_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_ipv6_int_addr_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
-static void dissect_hello_auth_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree);
+static void dissect_hello_padding_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_is_neighbors_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_ptp_adj_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_area_address_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_auth_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_ipv6_int_addr_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_ip_int_addr_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_mt_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+static void dissect_hello_nlpid_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length);
+
 
 static const isis_clv_handle_t clv_l1_hello_opts[] = {
 	{
@@ -139,6 +156,12 @@ static const isis_clv_handle_t clv_l1_hello_opts[] = {
 		&ett_isis_hello_clv_auth,
 		dissect_hello_auth_clv
 	},
+	{
+		ISIS_CLV_L1H_MT,
+		"Multi Topology",
+		&ett_isis_hello_clv_mt,
+		dissect_hello_mt_clv
+	},
 	{
 		0,
 		"",
@@ -196,6 +219,12 @@ static const isis_clv_handle_t clv_l2_hello_opts[] = {
 		&ett_isis_hello_clv_auth,
 		dissect_hello_auth_clv
 	},
+	{
+		ISIS_CLV_L2H_MT,
+		"Multi Topology",
+		&ett_isis_hello_clv_mt,
+		dissect_hello_mt_clv
+	},
 	{
 		0,
 		"",
@@ -247,6 +276,18 @@ static const isis_clv_handle_t clv_ptp_hello_opts[] = {
 		&ett_isis_hello_clv_auth,
 		dissect_hello_auth_clv
 	},
+	{
+		ISIS_CLV_PTP_ADJ,
+		"point-to-point Adjacency State",
+		&ett_isis_hello_clv_ptp_adj,
+		dissect_hello_ptp_adj_clv
+	},
+	{
+		ISIS_CLV_PTP_MT,
+		"Multi Topology",
+		&ett_isis_hello_clv_mt,
+		dissect_hello_mt_clv
+	},
 	{
 		0,
 		"",
@@ -263,20 +304,50 @@ static const isis_clv_handle_t clv_ptp_hello_opts[] = {
  *	clv common one.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void, will modify proto_tree if not null.
  */
 static void 
-dissect_hello_nlpid_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree) {
-	isis_dissect_nlpid_clv(pd, offset, length, fd, tree );
+dissect_hello_nlpid_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_nlpid_clv(tvb, pinfo, tree, offset, length);
+}
+
+/*
+ * Name: dissect_hello_mt_clv()
+ *
+ * Description:
+ *	Decode for a hello packets Multi Topology clv.  Calls into the
+ *	clv common one.
+ *
+ * Input:
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
+ *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
+ *
+ * Output:
+ *	void, will modify proto_tree if not null.
+ */
+
+static void 
+dissect_hello_mt_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_mt_clv(tvb, pinfo, tree, offset, length,
+		hf_isis_hello_clv_mt );
 }
 
 /*
@@ -287,20 +358,22 @@ dissect_hello_nlpid_clv(const u_char *pd, int offset,
  *	clv common one.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void, will modify proto_tree if not null.
  */
 static void 
-dissect_hello_ip_int_addr_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree) {
-	isis_dissect_ip_int_clv(pd, offset, length, fd, tree, 
+dissect_hello_ip_int_addr_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_ip_int_clv(tvb, pinfo, tree, offset, length,
 		hf_isis_hello_clv_ipv4_int_addr );
 }
 
@@ -312,20 +385,22 @@ dissect_hello_ip_int_addr_clv(const u_char *pd, int offset,
  *	clv common one.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void, will modify proto_tree if not null.
  */
 static void 
-dissect_hello_ipv6_int_addr_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree) {
-	isis_dissect_ipv6_int_clv(pd, offset, length, fd, tree, 
+dissect_hello_ipv6_int_addr_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_ipv6_int_clv(tvb, pinfo, tree, offset, length,
 		hf_isis_hello_clv_ipv6_int_addr );
 }
 
@@ -338,21 +413,23 @@ dissect_hello_ipv6_int_addr_clv(const u_char *pd, int offset,
  *	password.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void, will modify proto_tree if not null.
  */
 static void 
-dissect_hello_auth_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree) {
-	isis_dissect_authentication_clv(pd, offset, length, fd, tree, 
-		"Per Link authentication" );
+dissect_hello_auth_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_authentication_clv(tvb, pinfo, tree, offset,
+		length, "authentication" );
 }
 
 /*
@@ -363,20 +440,81 @@ dissect_hello_auth_clv(const u_char *pd, int offset,
  *	clv common one.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void, will modify proto_tree if not null.
  */
 static void 
-dissect_hello_area_address_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree) {
-	isis_dissect_area_address_clv(pd, offset, length, fd, tree );
+dissect_hello_area_address_clv(tvbuff_t *tvb, 
+	packet_info *pinfo, proto_tree *tree, int offset, 
+	int id_length, int length)
+{
+	isis_dissect_area_address_clv(tvb, pinfo, tree, offset, length);
+}
+
+
+
+static void 
+dissect_hello_ptp_adj_clv(tvbuff_t *tvb, 
+		packet_info *pinfo, proto_tree *tree, int offset, 
+		int id_length, int length)
+{
+        char adj_state[20];
+
+	switch(tvb_get_guint8(tvb, offset)) {
+	  case 0:
+	    strcpy(adj_state,"Up");
+	    break;
+	  case 1:
+	    strcpy(adj_state,"Initializing");
+	    break;
+	  case 2:
+	    strcpy(adj_state,"Down");
+	    break;
+	  default:
+	    strcpy(adj_state,"<illegal value !!!>");
+	    }
+
+	switch(length) {
+	  case 1:
+	    proto_tree_add_text ( tree, tvb, offset, 1,
+				  "Adjacency State: %s", adj_state );
+	    break;
+	  case 5:
+	    proto_tree_add_text ( tree, tvb, offset, 1,        
+                                  "Adjacency State: %s", adj_state ); 
+	    proto_tree_add_text ( tree, tvb, offset+1, 4,        
+                                  "Extended Local Circuit ID: %u", tvb_get_ntohl(tvb, offset+1) ); 
+	    break;
+	  case 11:
+            proto_tree_add_text ( tree, tvb, offset, 1,
+                                  "Adjacency State: %s", adj_state );
+            proto_tree_add_text ( tree, tvb, offset+1, 4,
+                                  "Extended Local Circuit ID: %u", tvb_get_ntohl(tvb, offset+1) );
+            proto_tree_add_text ( tree, tvb, offset+5, 6,
+                                  "Neighbor System ID: %s", print_system_id( tvb_get_ptr(tvb, offset+5, 6), 6 ) );
+	    break;
+	  case 15:
+	    proto_tree_add_text ( tree, tvb, offset, 1,
+                                  "Adjacency State: %s", adj_state );
+            proto_tree_add_text ( tree, tvb, offset+1, 4,
+                                  "Extended Local Circuit ID: %u", tvb_get_ntohl(tvb, offset+1) );
+            proto_tree_add_text ( tree, tvb, offset+5, 6,
+                                  "Neighbor System ID: %s", print_system_id( tvb_get_ptr(tvb, offset+5, 6), 6 ) );  
+            proto_tree_add_text ( tree, tvb, offset+11, 4,
+                                  "Neighbor Extended Local Circuit ID: %u", tvb_get_ntohl(tvb, offset+11) );
+	    break;
+	  default:
+	    isis_dissect_unknown(tvb, pinfo, tree, offset,
+				 "malformed TLV (%d vs 1,5,11,15)", length );
+	    return;
+	}
 }
 
 /*
@@ -387,23 +525,23 @@ dissect_hello_area_address_clv(const u_char *pd, int offset,
  *	(they tend to be an 802.3 MAC address, but its not required).
  *
  * Input:
- *	u_char * : packet data
- *	int : offset into packet data where we are.
- *	guint : length of clv we are decoding
- *	int : length of IDs in packet.
- *	frame_data * : frame data (complete frame)
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : protocol display tree to fill out.  May be NULL
- *	gint : tree id to use for proto tree.
+ *	int : offset into packet data where we are.
+ *	int : length of IDs in packet.
+ *	int : length of clv we are decoding
  * 
  * Output:
  *	void, but we will add to proto tree if !NULL.
  */
-void 
-dissect_hello_is_neighbors_clv(const u_char *pd, int offset, 
-		guint length, int id_length, frame_data *fd, proto_tree *tree ) {
+static void 
+dissect_hello_is_neighbors_clv(tvbuff_t *tvb, packet_info *pinfo,
+		proto_tree *tree, int offset, int id_length, int length)
+{
 	while ( length > 0 ) {
 		if (length<6) {
-			isis_dissect_unknown(offset, length, tree, fd, 
+			isis_dissect_unknown(tvb, pinfo, tree, offset,
 				"short is neighbor (%d vs 6)", length );
 			return;
 		}
@@ -412,15 +550,14 @@ dissect_hello_is_neighbors_clv(const u_char *pd, int offset,
 		 * format string.  
 		 */
 		if ( tree ) {
-			proto_tree_add_text ( tree, NullTVB, offset, 6, 
-				"IS Neighbor: %s", print_system_id( pd + offset, 6 ) ); 
+			proto_tree_add_text ( tree, tvb, offset, 6, 
+				"IS Neighbor: %s", print_system_id( tvb_get_ptr(tvb, offset, 6), 6 ) ); 
 		}
 		offset += 6;
 		length -= 6;
 	}
 }
 
-
 /*
  * Name: dissect_hello_padding_clv()
  *
@@ -429,22 +566,24 @@ dissect_hello_is_neighbors_clv(const u_char *pd, int offset,
  *	so we just return.
  *
  * Input:
- *	u_char * : packet data
- *	int : current offset into packet data
- *	guint : length of this clv
- *	int : length of IDs in packet.
- *	frame_data * : frame data
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
  *	proto_tree * : proto tree to build on (may be null)
+ *	int : current offset into packet data
+ *	int : length of IDs in packet.
+ *	int : length of this clv
  *
  * Output:
  *	void
  */
 static void 
-dissect_hello_padding_clv(const u_char *pd, int offset, guint length, 
-		int id_length, frame_data *fd, proto_tree *tree) {
+dissect_hello_padding_clv(tvbuff_t *tvb, packet_info *pinfo,
+	proto_tree *tree, int offset, int id_length, int length)
+{
 	/* nothing to do here! */
 }
 
+
 /*
  * Name: isis_dissect_isis_hello()
  * 
@@ -454,100 +593,97 @@ dissect_hello_padding_clv(const u_char *pd, int offset, guint length,
  *	a shorter header.
  *
  * Input:
+ *	tvbuff_t * : tvbuffer for packet data
+ *	packet_info * : info for current packet
+ *	proto_tree * : protocol display tree to add to.  May be NULL.
+ *	int offset : our offset into packet data.
  *	int : hello type, a la packet-isis.h ISIS_TYPE_* values
  *	int : header length of packet.
  *	int : length of IDs in packet.
- *	u_char * : packet data
- *	int offset : our offset into packet data.
- *	frame_data * : frame data
- *	proto_tree * : protocol display tree to add to.  May be NULL.
  *
  * Output:
  *	void, will modify proto_tree if not NULL.
  */	
 void 
-isis_dissect_isis_hello(int hello_type, int header_length, int id_length,
-		const u_char *pd, int offset, frame_data *fd, proto_tree *tree){
+isis_dissect_isis_hello(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+	int offset, int hello_type, int header_length, int id_length)
+{
 	proto_item	*ti;
 	proto_tree	*hello_tree = NULL;
 	int 		len;
-	int		hlen;
+	guint8		octet;
+	const guint8	*source_id;
 	guint16		pdu_length;
+	const guint8	*lan_id;
 
-	OLD_CHECK_DISPLAY_AS_DATA(proto_isis_hello, pd, offset, fd, tree);
-
-	if (hello_type == ISIS_TYPE_PTP_HELLO) {
-		hlen = 1+id_length+2+2+1;
-	} else {
-		hlen = 1+id_length+2+2+1+id_length+1;
-	}
-
-	if (!BYTES_ARE_IN_FRAME(offset, hlen)) {
-		isis_dissect_unknown(offset, hlen, tree, fd,
-			"not enough capture data for header (%d vs %d)",
-			hlen, END_OF_FRAME);
+	if (!proto_is_protocol_enabled(proto_isis_hello)) {
+		dissect_data(tvb, offset, pinfo, tree);
 		return;
 	}
 
 	if (tree) {
-		ti = proto_tree_add_item(tree, proto_isis_hello, NullTVB,
-			offset, END_OF_FRAME, FALSE);
+		ti = proto_tree_add_item(tree, proto_isis_hello, tvb,
+			offset, tvb_length_remaining(tvb, offset), FALSE);
 		hello_tree = proto_item_add_subtree(ti, ett_isis_hello);
+		octet = tvb_get_guint8(tvb, offset);
 		proto_tree_add_uint_format(hello_tree,
 			hf_isis_hello_circuit_reserved,
-			NullTVB, offset, 1, pd[offset],
+			tvb, offset, 1, octet,
 			"Circuit type              : %s, reserved(0x%02x == 0)",
-				val_to_str(pd[offset]&ISIS_HELLO_CTYPE_MASK,
+				val_to_str(octet&ISIS_HELLO_CTYPE_MASK,
 					isis_hello_circuit_type_vals,
 					"Unknown (0x%x)"),
-				pd[offset]&ISIS_HELLO_CT_RESERVED_MASK
+				octet&ISIS_HELLO_CT_RESERVED_MASK
 			);
 	}
 	offset += 1;
 
 	if (tree) {
-		proto_tree_add_bytes_format(hello_tree, hf_isis_hello_source_id, NullTVB,
-			            offset, id_length, &pd[offset],
+		source_id = tvb_get_ptr(tvb, offset, id_length);
+		proto_tree_add_bytes_format(hello_tree, hf_isis_hello_source_id, tvb,
+			            offset, id_length, source_id,
 			            "SystemID{ Sender of PDU } : %s", 
-                     print_system_id( pd + offset, id_length ) );
+			            print_system_id( source_id, id_length ) );
         }
 	offset += id_length;
 
 	if (tree) {
-		proto_tree_add_uint(hello_tree, hf_isis_hello_holding_timer, NullTVB,
-			            offset, 2, pntohs(&pd[offset]));
+		proto_tree_add_item(hello_tree, hf_isis_hello_holding_timer, tvb,
+			            offset, 2, FALSE);
 	}
 	offset += 2;
 
-	pdu_length = pntohs(&pd[offset]);
+	pdu_length = tvb_get_ntohs(tvb, offset);
 	if (tree) {
-		proto_tree_add_uint(hello_tree, hf_isis_hello_pdu_length, NullTVB,
+		proto_tree_add_uint(hello_tree, hf_isis_hello_pdu_length, tvb,
 			            offset, 2, pdu_length);
 	}
 	offset += 2;
 
 	if (hello_type == ISIS_TYPE_PTP_HELLO) {
 		if (tree) {
-			proto_tree_add_uint(hello_tree, hf_isis_hello_local_circuit_id, NullTVB,
-				         offset, 1, pd[offset] );
+			proto_tree_add_item(hello_tree, hf_isis_hello_local_circuit_id, tvb,
+				         offset, 1, FALSE );
 		}
 		offset += 1;
 	} else { 
 
                 if (tree) {
-                        proto_tree_add_uint_format(hello_tree, hf_isis_hello_priority_reserved, NullTVB,
-                                    offset, 1, pd[offset],
+                        octet = tvb_get_guint8(tvb, offset);
+                        proto_tree_add_uint_format(hello_tree, hf_isis_hello_priority_reserved, tvb,
+                                    offset, 1, octet,
                                     "Priority                  : %d, reserved(0x%02x == 0)",
-                                        pd[offset]&ISIS_HELLO_PRIORITY_MASK,
-                                        pd[offset]&ISIS_HELLO_P_RESERVED_MASK );
+                                        octet&ISIS_HELLO_PRIORITY_MASK,
+                                        octet&ISIS_HELLO_P_RESERVED_MASK );
                 }
                 offset += 1;
 
 		if (tree) {
-			proto_tree_add_bytes_format(hello_tree, hf_isis_hello_lan_id, NullTVB, 
-		                     offset, id_length + 1, &pd[offset],
+			lan_id = tvb_get_ptr(tvb, offset, id_length+1);
+			proto_tree_add_bytes_format(hello_tree, hf_isis_hello_lan_id, tvb, 
+		                     offset, id_length + 1, lan_id,
 				         "SystemID{ Designated IS } : %s",
-					      print_system_id( pd + offset, id_length + 1 ) );
+					      print_system_id( lan_id, id_length + 1 ) );
 		}
 		offset += id_length + 1;
 	}
@@ -555,8 +691,8 @@ isis_dissect_isis_hello(int hello_type, int header_length, int id_length,
 	len = pdu_length;
 	len -= header_length;
 	if (len < 0) {
-		isis_dissect_unknown(offset, header_length, tree, fd, 
-			"packet header length %d went beyond packet", 
+		isis_dissect_unknown(tvb, pinfo, tree, offset,
+			"Packet header length %d went beyond packet", 
 			header_length );
 		return;
 	}
@@ -565,14 +701,17 @@ isis_dissect_isis_hello(int hello_type, int header_length, int id_length,
 	 * our list of valid ones!
 	 */
 	if (hello_type == ISIS_TYPE_L1_HELLO){
-		isis_dissect_clvs ( clv_l1_hello_opts, len, id_length, pd,
-			offset, fd, hello_tree, ett_isis_hello_clv_unknown );
+		isis_dissect_clvs(tvb, pinfo, hello_tree, offset,
+			clv_l1_hello_opts, len, id_length,
+			ett_isis_hello_clv_unknown);
 	} else if (hello_type == ISIS_TYPE_L2_HELLO) {
-		isis_dissect_clvs ( clv_l2_hello_opts, len, id_length, pd,
-			offset, fd, hello_tree, ett_isis_hello_clv_unknown );
+		isis_dissect_clvs(tvb, pinfo, hello_tree, offset,
+			clv_l2_hello_opts, len, id_length,
+			ett_isis_hello_clv_unknown);
 	} else {
-		isis_dissect_clvs ( clv_ptp_hello_opts, len, id_length, pd,
-			offset, fd, hello_tree, ett_isis_hello_clv_unknown );
+		isis_dissect_clvs(tvb, pinfo, hello_tree, offset,
+			clv_ptp_hello_opts, len, id_length,
+			ett_isis_hello_clv_unknown);
 	}
 }
 
@@ -595,39 +734,43 @@ proto_register_isis_hello(void) {
 	static hf_register_info hf[] = {
 		{ &hf_isis_hello_circuit_reserved,
 		{ "Circuit type              ", "isis_hello.circuite_type",
-			FT_UINT8, BASE_HEX, NULL, 0x0, "" }},
+			FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_source_id,
 		{ "SystemID{ Sender of PDU } ", "isis_hello.source_id",
-			FT_BYTES, BASE_HEX, NULL, 0x0, "" }},
+			FT_BYTES, BASE_HEX, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_holding_timer,
 		{ "Holding timer             ", "isis_hello.holding_timer", 
-			FT_UINT16, BASE_DEC, NULL, 0x0, "" }},
+			FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_pdu_length,
 		{ "PDU length                ", "isis_hello.pdu_length",
-			FT_UINT16, BASE_DEC, NULL, 0x0, "" }},
+			FT_UINT16, BASE_DEC, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_priority_reserved,
 		 { "Priority                 ", "isis_hello.priority",
-			FT_UINT8, BASE_DEC, NULL, ISIS_HELLO_P_RESERVED_MASK, "" }},
+			FT_UINT8, BASE_DEC, NULL, ISIS_HELLO_P_RESERVED_MASK, "", HFILL }},
 
 		{ &hf_isis_hello_lan_id,
 		{ "SystemID{ Designated IS } ", "isis_hello.lan_id",
-			FT_BYTES, BASE_DEC, NULL, 0x0, "" }},
+			FT_BYTES, BASE_DEC, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_local_circuit_id,
 		{ "Local circuit ID          ", "isis_hello.local_circuit_id",
-			FT_UINT8, BASE_DEC, NULL, 0x0, "" }},
+			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_clv_ipv4_int_addr,
 		{ "IPv4 interface address    ", "isis_hello.clv_ipv4_int_addr",
-			FT_IPv4, BASE_NONE, NULL, 0x0, "" }},
+			FT_IPv4, BASE_NONE, NULL, 0x0, "", HFILL }},
 
 		{ &hf_isis_hello_clv_ipv6_int_addr,
 		{ "IPv6 interface address    ", "isis_hello.clv_ipv6_int_addr",
-			FT_IPv6, BASE_NONE, NULL, 0x0, "" }},
+			FT_IPv6, BASE_NONE, NULL, 0x0, "", HFILL }},
+
+		{ &hf_isis_hello_clv_ptp_adj,
+		{ "point-to-point Adjacency  ", "isis_hello.clv_ptp_adj",
+			FT_UINT8, BASE_DEC, NULL, 0x0, "", HFILL }},
 
 	};
 	static gint *ett[] = {
@@ -639,7 +782,9 @@ proto_register_isis_hello(void) {
 		&ett_isis_hello_clv_nlpid,
 		&ett_isis_hello_clv_auth,
 		&ett_isis_hello_clv_ipv4_int_addr,
-		&ett_isis_hello_clv_ipv6_int_addr
+		&ett_isis_hello_clv_ipv6_int_addr,
+		&ett_isis_hello_clv_ptp_adj,
+		&ett_isis_hello_clv_mt
 	};
 
 	proto_isis_hello = proto_register_protocol("ISIS HELLO",
