@@ -1,13 +1,12 @@
 /* packet-isis-lsp.h
  * Defines and such for LSP and their CLV decodes
  *
- * $Id: packet-isis-lsp.h,v 1.5 2001/05/14 18:40:15 guy Exp $
+ * $Id: packet-isis-lsp.h,v 1.9 2001/07/02 00:19:34 guy Exp $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,7 +49,9 @@
 #define ISIS_LSP_TYPE_LEVEL_2		3
 
 #define ISIS_LSP_CLV_METRIC_SUPPORTED(x)	((x)&0xf0)
+#define ISIS_LSP_CLV_METRIC_IE(x)               ((x)&0x20)
 #define ISIS_LSP_CLV_METRIC_RESERVED(x)		((x)&0x40)
+#define ISIS_LSP_CLV_METRIC_UPDOWN(x)           ((x)&0x40)
 #define ISIS_LSP_CLV_METRIC_VALUE(x)		((x)&0x3f)
 
 /*
@@ -59,15 +60,18 @@
 #define ISIS_CLV_L1_LSP_AREA_ADDRESS		1
 #define ISIS_CLV_L1_LSP_IS_NEIGHBORS		2
 #define ISIS_CLV_L1_LSP_ES_NEIGHBORS		3
-#define ISIS_CLV_L1_LSP_EXT_IS_REACHABLE    22
+#define ISIS_CLV_L1_LSP_EXT_IS_REACHABLE        22
 #define ISIS_CLV_L1_LSP_IP_INT_REACHABLE	128
 #define ISIS_CLV_L1_LSP_NLPID			129
+#define ISIS_CLV_L1_LSP_IP_EXT_REACHABLE        130
 #define ISIS_CLV_L1_LSP_IP_INTERFACE_ADDR	132
 #define ISIS_CLV_L1_LSP_TE_ROUTER_ID            134 
-#define ISIS_CLV_L1_LSP_EXT_IP_REACHABLE    135
+#define ISIS_CLV_L1_LSP_EXT_IP_REACHABLE        135
 #define ISIS_CLV_L1_LSP_HOSTNAME                137
-#define ISIS_CLV_L1_LSP_IPv6_INTERFACE_ADDR 232
-#define ISIS_CLV_L1_LSP_IPv6_REACHABLE      236
+#define ISIS_CLV_L1_LSP_MT_IS_REACHABLE         222
+#define ISIS_CLV_L1_LSP_MT                      229
+#define ISIS_CLV_L1_LSP_IPv6_INTERFACE_ADDR     232
+#define ISIS_CLV_L1_LSP_IPv6_REACHABLE          236
 /* 
  * Note, the spec say 133, but everyone seems to use 10. Any clue on why
  * this is would be appreciated!
@@ -82,17 +86,19 @@
 #define ISIS_CLV_L2_LSP_IS_NEIGHBORS		2
 #define ISIS_CLV_L2_LSP_PARTITION_DIS		4
 #define ISIS_CLV_L2_LSP_PREFIX_NEIGHBORS	5
-#define ISIS_CLV_L2_LSP_EXT_IS_REACHABLE    22
+#define ISIS_CLV_L2_LSP_EXT_IS_REACHABLE        22
 #define ISIS_CLV_L2_LSP_IP_INT_REACHABLE	128
 #define ISIS_CLV_L2_LSP_NLPID			129
 #define ISIS_CLV_L2_LSP_IP_EXT_REACHABLE	130
 #define ISIS_CLV_L2_LSP_IDRP_INFO		131
 #define ISIS_CLV_L2_LSP_IP_INTERFACE_ADDR	132
 #define ISIS_CLV_L2_LSP_TE_ROUTER_ID            134 
-#define ISIS_CLV_L2_LSP_EXT_IP_REACHABLE    135
+#define ISIS_CLV_L2_LSP_EXT_IP_REACHABLE        135
 #define ISIS_CLV_L2_LSP_HOSTNAME                137
-#define ISIS_CLV_L2_LSP_IPv6_INTERFACE_ADDR 232
-#define ISIS_CLV_L2_LSP_IPv6_REACHABLE      236
+#define ISIS_CLV_L2_LSP_MT_IS_REACHABLE         222
+#define ISIS_CLV_L2_LSP_MT                      229
+#define ISIS_CLV_L2_LSP_IPv6_INTERFACE_ADDR     232
+#define ISIS_CLV_L2_LSP_IPv6_REACHABLE          236
 /* 
  * Note, the spec say 133, but everyone seems to use 10. Any clue on why
  * this is would be appreciated!
@@ -104,10 +110,10 @@
  * Published API functions.  NOTE, this are "local" API functions and
  * are only valid from with isis decodes.
  */
-extern void isis_dissect_isis_lsp(int hello_type, int header_length,
-	int id_length, const u_char *pd, int offset, frame_data *fd,
-	proto_tree *tree);
-extern void isis_lsp_decode_lsp_id(char *tstr, proto_tree *tree,
-	const u_char *pd, int offset, int id_length);
+extern void isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo,
+	proto_tree *tree, int offset,
+	int hello_type, int header_length, int id_length);
+extern void isis_lsp_decode_lsp_id(tvbuff_t *tvb, packet_info *pinfo, 
+	proto_tree *tree, int offset, char *tstr, int id_length);
 
 #endif /* _PACKET_ISIS_LSP_H */
