@@ -1,7 +1,7 @@
 /* packet-isl.c
  * Routines for Cisco ISL Ethernet header disassembly
  *
- * $Id: packet-isl.c,v 1.24 2001/04/19 23:02:44 guy Exp $
+ * $Id: packet-isl.c,v 1.25 2001/06/18 02:17:48 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -282,60 +282,60 @@ proto_register_isl(void)
   static hf_register_info hf[] = {
 	{ &hf_isl_dst,
 	{ "Destination",	"isl.dst", FT_ETHER, BASE_NONE, NULL, 0x0,
-		"Destination Address" }},
+		"Destination Address", HFILL }},
 	{ &hf_isl_type,
 	{ "Type",		"isl.type", FT_UINT8, BASE_DEC,
-		VALS(type_vals), 0xF0, "Type" }},
+		VALS(type_vals), 0xF0, "Type", HFILL }},
 	{ &hf_isl_user_eth,
 	{ "User",		"isl.user_eth", FT_UINT8, BASE_DEC,
-		VALS(ether_user_vals), 0x0F, "Priority (for Ethernet)" }},
+		VALS(ether_user_vals), 0x0F, "Priority (for Ethernet)", HFILL }},
 	{ &hf_isl_user,
 	{ "User",		"isl.user", FT_UINT8, BASE_HEX, NULL, 0x0F,
-		"User-defined bits" }},
+		"User-defined bits", HFILL }},
 	{ &hf_isl_src,
 	{ "Source",		"isl.src", FT_ETHER, BASE_NONE, NULL, 0x0,
-		"Source Hardware Address" }},
+		"Source Hardware Address", HFILL }},
 	{ &hf_isl_addr,
 	{ "Source or Destination Address", "isl.addr", FT_ETHER, BASE_NONE, NULL, 0x0,
-		"Source or Destination Hardware Address" }},
+		"Source or Destination Hardware Address", HFILL }},
 	{ &hf_isl_len,
 	{ "Length",		"isl.len", FT_UINT16, BASE_DEC, NULL, 0x0,
-		"" }},
+		"", HFILL }},
 	{ &hf_isl_hsa,
 	{ "HSA",		"isl.hsa", FT_UINT24, BASE_HEX, NULL, 0x0,
-		"High bits of source address" }},
+		"High bits of source address", HFILL }},
 	{ &hf_isl_vlan_id,
 	{ "VLAN ID",		"isl.vlan_id", FT_UINT16, BASE_HEX, NULL,
-		0xFFFE, "Virtual LAN ID" }},
+		0xFFFE, "Virtual LAN ID", HFILL }},
 	{ &hf_isl_bpdu,
 	{ "BPDU",		"isl.bpdu", FT_BOOLEAN, 16,
-		TFS(&bpdu_tfs), 0x0001, "BPDU indicator" }},
+		TFS(&bpdu_tfs), 0x0001, "BPDU indicator", HFILL }},
 	{ &hf_isl_index,
 	{ "Index",		"isl.index", FT_UINT16, BASE_DEC, NULL, 0x0,
-		"Port index of packet source" }},
+		"Port index of packet source", HFILL }},
 	{ &hf_isl_crc,
 	{ "CRC",		"isl.crc", FT_UINT32, BASE_HEX, NULL, 0x0,
-		"CRC field of encapsulated frame" }},
+		"CRC field of encapsulated frame", HFILL }},
 	{ &hf_isl_src_vlan_id,
 	{ "Source VLAN ID",	"isl.src_vlan_id", FT_UINT16, BASE_HEX, NULL,
-		0xFFFE, "Source Virtual LAN ID" }},
+		0xFFFE, "Source Virtual LAN ID", HFILL }},
 	{ &hf_isl_explorer,
 	{ "Explorer",		"isl.explorer", FT_BOOLEAN, 16,
-		TFS(&explorer_tfs), 0x0001, "Explorer" }},
+		TFS(&explorer_tfs), 0x0001, "Explorer", HFILL }},
 	{ &hf_isl_dst_route_descriptor,
 	{ "Destination route descriptor",	"isl.dst_route_desc",
 		FT_UINT16, BASE_HEX, NULL, 0x0,
-		"Route descriptor to be used for forwarding" }},
+		"Route descriptor to be used for forwarding", HFILL }},
 	{ &hf_isl_src_route_descriptor,
 	{ "Source-route descriptor",	"isl.src_route_desc",
 		FT_UINT16, BASE_HEX, NULL, 0x0,
-		"Route descriptor to be used for source learning" }},
+		"Route descriptor to be used for source learning", HFILL }},
 	{ &hf_isl_fcs_not_incl,
 	{ "FCS Not Included",	"isl.fcs_not_incl", FT_BOOLEAN, 9,
-		NULL, 0x40, "FCS not included" }},
+		NULL, 0x40, "FCS not included", HFILL }},
 	{ &hf_isl_esize,
 	{ "Esize",	"isl.esize", FT_UINT8, BASE_DEC, NULL,
-		0x3F, "Frame size for frames less than 64 bytes" }},
+		0x3F, "Frame size for frames less than 64 bytes", HFILL }},
   };
   static gint *ett[] = {
 	&ett_isl,
