@@ -1,8 +1,10 @@
 /* packet-klm.c    2001 Ronnie Sahlberg <rsahlber@bigpond.net.au>
  * Routines for klm dissection
  *
+ * $Id: packet-klm.c,v 1.4 2001/06/18 02:17:48 guy Exp $
+ *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * This program is free software; you can redistribute it and/or
@@ -72,16 +74,16 @@ dissect_holder(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 
 	lock_tree = proto_item_add_subtree(lock_item, ett_klm_holder);
 
-	offset = dissect_rpc_bool_tvb( tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_bool( tvb, pinfo, lock_tree, 
 			hf_klm_exclusive, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_pid, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_offset, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_len, offset);
 
 	return offset;
@@ -98,18 +100,18 @@ dissect_lock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 
 	lock_tree = proto_item_add_subtree(lock_item, ett_klm_lock);
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, lock_tree,
+	offset = dissect_rpc_string(tvb, pinfo, lock_tree,
 			hf_klm_servername, offset, NULL);
 
 	offset = dissect_nfs_fh3(tvb, offset, pinfo, lock_tree,"fh");
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_pid, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_offset, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_klm_len, offset);
 
 	return offset;
@@ -127,7 +129,7 @@ static int
 dissect_klm_stat_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, 
 			hf_klm_stats, offset);
 
 	return offset;
@@ -136,10 +138,10 @@ dissect_klm_stat_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
 static int
 dissect_klm_lock_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_bool_tvb( tvb, pinfo, tree, 
+	offset = dissect_rpc_bool( tvb, pinfo, tree, 
 			hf_klm_block, offset);
 
-	offset = dissect_rpc_bool_tvb( tvb, pinfo, tree, 
+	offset = dissect_rpc_bool( tvb, pinfo, tree, 
 			hf_klm_exclusive, offset);
 
 	offset = dissect_lock(tvb, pinfo, tree, offset);
@@ -154,7 +156,7 @@ dissect_klm_test_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
 
 	stats = tvb_get_ntohl(tvb, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, 
 			hf_klm_stats, offset);
 
 	if (stats == KLM_DENIED) {
@@ -167,7 +169,7 @@ dissect_klm_test_reply(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree
 static int
 dissect_klm_test_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_bool_tvb( tvb, pinfo, tree, 
+	offset = dissect_rpc_bool( tvb, pinfo, tree, 
 			hf_klm_exclusive, offset);
 
 	offset = dissect_lock(tvb, pinfo, tree, offset);
@@ -199,39 +201,39 @@ proto_register_klm(void)
 	static hf_register_info hf[] = {
 		{ &hf_klm_exclusive, {
 			"exclusive", "klm.exclusive", FT_BOOLEAN, BASE_NONE,
-			&tfs_exclusive, 0, "Exclusive lock" }},
+			&tfs_exclusive, 0, "Exclusive lock", HFILL }},
 
 		{ &hf_klm_lock, {
 			"lock", "klm.lock", FT_NONE, BASE_NONE,
-			NULL, 0, "KLM lock structure" }},
+			NULL, 0, "KLM lock structure", HFILL }},
 
 		{ &hf_klm_servername, {
 			"server name", "klm.servername", FT_STRING, BASE_NONE,
-			NULL, 0, "Server name" }},
+			NULL, 0, "Server name", HFILL }},
 
 		{ &hf_klm_pid, {
 			"pid", "klm.pid", FT_UINT32, BASE_DEC,
-			NULL, 0, "ProcessID" }},
+			NULL, 0, "ProcessID", HFILL }},
 
 		{ &hf_klm_offset, {
 			"offset", "klm.offset", FT_UINT32, BASE_DEC,
-			NULL, 0, "File offset" }},
+			NULL, 0, "File offset", HFILL }},
 
 		{ &hf_klm_len, {
 			"length", "klm.len", FT_UINT32, BASE_DEC,
-			NULL, 0, "Length of lock region" }},
+			NULL, 0, "Length of lock region", HFILL }},
 
 		{ &hf_klm_stats, {
 			"stats", "klm.stats", FT_UINT32, BASE_DEC,
-			VALS(names_klm_stats), 0, "stats" }},
+			VALS(names_klm_stats), 0, "stats", HFILL }},
 
 		{ &hf_klm_holder, {
 			"holder", "klm.holder", FT_NONE, BASE_NONE,
-			NULL, 0, "KLM lock holder" }},
+			NULL, 0, "KLM lock holder", HFILL }},
 
 		{ &hf_klm_block, {
 			"block", "klm.block", FT_BOOLEAN, BASE_NONE,
-			&tfs_block, 0, "Block" }},
+			&tfs_block, 0, "Block", HFILL }},
 
 	};
 
