@@ -2,10 +2,10 @@
  * Routines for LAPD frame disassembly
  * Gilbert Ramirez <gram@xiexie.org>
  *
- * $Id: packet-lapd.c,v 1.20 2001/01/22 00:20:29 guy Exp $
+ * $Id: packet-lapd.c,v 1.23 2001/06/18 02:17:48 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998
  *
  * 
@@ -36,7 +36,6 @@
 #include <glib.h>
 #include <string.h>
 #include "packet.h"
-#include "packet-q931.h"
 #include "xdlc.h"
 
 /* ISDN/LAPD references:
@@ -59,6 +58,8 @@ static gint ett_lapd = -1;
 static gint ett_lapd_address = -1;
 static gint ett_lapd_control = -1;
 
+static dissector_handle_t q931_handle;
+
 /*
  * Bits in the address field.
  */
@@ -145,7 +146,7 @@ dissect_lapd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		switch (sapi) {
 
 		case LAPD_SAPI_Q931:
-			dissect_q931(next_tvb, pinfo, tree);
+			call_dissector(q931_handle, next_tvb, pinfo, tree);
 			break;
 
 		default:
@@ -162,31 +163,31 @@ proto_register_lapd(void)
     static hf_register_info hf[] = {
 	{ &hf_lapd_address,
 	  { "Address Field", "lapd.address", FT_UINT16, BASE_HEX, NULL, 0x0, 
-	  	"Address" }},
+	  	"Address", HFILL }},
 
 	{ &hf_lapd_sapi,
 	  { "SAPI", "lapd.sapi", FT_UINT16, BASE_DEC, VALS(lapd_sapi_vals), LAPD_SAPI,
-	  	"Service Access Point Identifier" }},
+	  	"Service Access Point Identifier", HFILL }},
 
 	{ &hf_lapd_cr,
 	  { "C/R", "lapd.cr", FT_UINT16, BASE_DEC, NULL, LAPD_CR,
-	  	"Command/Response bit" }},
+	  	"Command/Response bit", HFILL }},
 
 	{ &hf_lapd_ea1,
 	  { "EA1", "lapd.ea1", FT_UINT16, BASE_DEC, NULL, LAPD_EA1,
-	  	"First Address Extension bit" }},
+	  	"First Address Extension bit", HFILL }},
 
 	{ &hf_lapd_tei,
 	  { "TEI", "lapd.tei", FT_UINT16, BASE_DEC, NULL, LAPD_TEI,
-	  	"Terminal Endpoint Identifier" }},
+	  	"Terminal Endpoint Identifier", HFILL }},
 
 	{ &hf_lapd_ea2,
 	  { "EA2", "lapd.ea2", FT_UINT16, BASE_DEC, NULL, LAPD_EA2,
-	  	"Second Address Extension bit" }},
+	  	"Second Address Extension bit", HFILL }},
 
 	{ &hf_lapd_control,
 	  { "Control Field", "lapd.control", FT_UINT16, BASE_HEX, NULL, 0x0,
-	  	"Control field" }},
+	  	"Control field", HFILL }},
     };
     static gint *ett[] = {
         &ett_lapd,
@@ -203,5 +204,10 @@ proto_register_lapd(void)
 void
 proto_reg_handoff_lapd(void)
 {
+	/*
+	 * Get handle for the Q.931 dissector.
+	 */
+	q931_handle = find_dissector("q931");
+
 	dissector_add("wtap_encap", WTAP_ENCAP_LAPD, dissect_lapd, proto_lapd);
 }
