@@ -1,7 +1,7 @@
 /* packet-ldap.c
  * Routines for ldap packet dissection
  *
- * $Id: packet-ldap.c,v 1.26 2001/05/08 19:50:29 guy Exp $
+ * $Id: packet-ldap.c,v 1.27 2001/06/18 02:17:48 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -1074,131 +1074,131 @@ proto_register_ldap(void)
     { &hf_ldap_length,
       { "Length",		"ldap.length",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Length" }},
+	"LDAP Length", HFILL }},
 	  
     { &hf_ldap_message_id,
       { "Message Id",		"ldap.message_id",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Message Id" }},
+	"LDAP Message Id", HFILL }},
     { &hf_ldap_message_type,
       { "Message Type",		"ldap.message_type",
 	FT_UINT8, BASE_HEX, &msgTypes, 0x0,
-	"LDAP Message Type" }},
+	"LDAP Message Type", HFILL }},
     { &hf_ldap_message_length,
       { "Message Length",		"ldap.message_length",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Message Length" }},
+	"LDAP Message Length", HFILL }},
 
     { &hf_ldap_message_result,
       { "Result Code",		"ldap.result.code",
 	FT_UINT8, BASE_HEX, result_codes, 0x0,
-	"LDAP Result Code" }},
+	"LDAP Result Code", HFILL }},
     { &hf_ldap_message_result_matcheddn,
       { "Matched DN",		"ldap.result.matcheddn",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Result Matched DN" }},
+	"LDAP Result Matched DN", HFILL }},
     { &hf_ldap_message_result_errormsg,
       { "Error Message",		"ldap.result.errormsg",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Result Error Message" }},
+	"LDAP Result Error Message", HFILL }},
     { &hf_ldap_message_result_referral,
       { "Referral",		"ldap.result.referral",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Result Referral URL" }},
+	"LDAP Result Referral URL", HFILL }},
 
     { &hf_ldap_message_bind_version,
       { "Version",		"ldap.bind.version",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Bind Version" }},
+	"LDAP Bind Version", HFILL }},
     { &hf_ldap_message_bind_dn,
       { "DN",			"ldap.bind.dn",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Bind Distinguished Name" }},
+	"LDAP Bind Distinguished Name", HFILL }},
     { &hf_ldap_message_bind_auth,
       { "Auth Type",		"ldap.bind.auth_type",
 	FT_UINT8, BASE_HEX, auth_types, 0x0,
-	"LDAP Bind Auth Type" }},
+	"LDAP Bind Auth Type", HFILL }},
     { &hf_ldap_message_bind_auth_password,
       { "Password",		"ldap.bind.password",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Bind Password" }},
+	"LDAP Bind Password", HFILL }},
 
     { &hf_ldap_message_search_base,
       { "Base DN",		"ldap.search.basedn",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Search Base Distinguished Name" }},
+	"LDAP Search Base Distinguished Name", HFILL }},
     { &hf_ldap_message_search_scope,
       { "Scope",			"ldap.search.scope",
 	FT_UINT8, BASE_HEX, search_scope, 0x0,
-	"LDAP Search Scope" }},
+	"LDAP Search Scope", HFILL }},
     { &hf_ldap_message_search_deref,
       { "Dereference",		"ldap.search.dereference",
 	FT_UINT8, BASE_HEX, search_dereference, 0x0,
-	"LDAP Search Dereference" }},
+	"LDAP Search Dereference", HFILL }},
     { &hf_ldap_message_search_sizeLimit,
       { "Size Limit",		"ldap.search.sizelimit",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Search Size Limit" }},
+	"LDAP Search Size Limit", HFILL }},
     { &hf_ldap_message_search_timeLimit,
       { "Time Limit",		"ldap.search.timelimit",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Search Time Limit" }},
+	"LDAP Search Time Limit", HFILL }},
     { &hf_ldap_message_search_typesOnly,
       { "Attributes Only",	"ldap.search.typesonly",
 	FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-	"LDAP Search Attributes Only" }},
+	"LDAP Search Attributes Only", HFILL }},
     { &hf_ldap_message_search_filter,
       { "Filter",		"ldap.search.filter",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Search Filter" }},
+	"LDAP Search Filter", HFILL }},
     { &hf_ldap_message_dn,
       { "Distinguished Name",	"ldap.dn",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Distinguished Name" }},
+	"LDAP Distinguished Name", HFILL }},
     { &hf_ldap_message_attribute,
       { "Attribute",		"ldap.attribute",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Attribute" }},
+	"LDAP Attribute", HFILL }},
     { &hf_ldap_message_value,
       { "Value",		"ldap.value",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Value" }},
+	"LDAP Value", HFILL }},
 
     { &hf_ldap_message_modrdn_name,
       { "New Name",		"ldap.modrdn.name",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP New Name" }},
+	"LDAP New Name", HFILL }},
     { &hf_ldap_message_modrdn_delete,
       { "Delete Values",	"ldap.modrdn.delete",
 	FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-	"LDAP Modify RDN - Delete original values" }},
+	"LDAP Modify RDN - Delete original values", HFILL }},
     { &hf_ldap_message_modrdn_superior,
       { "New Location",		"ldap.modrdn.superior",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Modify RDN - New Location" }},
+	"LDAP Modify RDN - New Location", HFILL }},
 
     { &hf_ldap_message_compare,
       { "Test",		"ldap.compare.test",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Compare Test" }},
+	"LDAP Compare Test", HFILL }},
 
     { &hf_ldap_message_modify_add,
       { "Add",			"ldap.modify.add",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Add" }},
+	"LDAP Add", HFILL }},
     { &hf_ldap_message_modify_replace,
       { "Replace",		"ldap.modify.replace",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Replace" }},
+	"LDAP Replace", HFILL }},
     { &hf_ldap_message_modify_delete,
       { "Delete",		"ldap.modify.delete",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"LDAP Delete" }},
+	"LDAP Delete", HFILL }},
 
     { &hf_ldap_message_abandon_msgid,
       { "Abandon Msg Id",	"ldap.abandon.msgid",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"LDAP Abandon Msg Id" }},
+	"LDAP Abandon Msg Id", HFILL }},
   };
 
   static gint *ett[] = {
