@@ -2,7 +2,7 @@
  * Routines for OSPF packet disassembly
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-ospf.c,v 1.40 2001/05/14 18:25:34 guy Exp $
+ * $Id: packet-ospf.c,v 1.42 2001/07/08 22:59:50 guy Exp $
  *
  * At this time, this module is able to analyze OSPF
  * packets as specified in RFC2328. MOSPF (RFC1584) and other
@@ -15,7 +15,6 @@
  * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  * 
- * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -86,6 +85,7 @@ static const value_string auth_vals[] = {
 #define OSPF_OPTIONS_EA		0x10
 #define OSPF_OPTIONS_DC		0x20
 #define OSPF_OPTIONS_O		0x40
+#define OSPF_OPTIONS_DN         0x01
 
 #define OSPF_DBD_FLAG_MS	1
 #define OSPF_DBD_FLAG_M		2
@@ -221,7 +221,7 @@ dissect_ospf(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	length = tvb_length(tvb);
 	/* XXX - include only the length from the OSPF header? */
 	reported_length = tvb_reported_length(tvb);
-	if (!pi.fragmented && length >= reported_length
+	if (!pinfo->fragmented && length >= reported_length
 		&& length >= OSPF_HEADER_LENGTH) {
 	    /* The packet isn't part of a fragmented datagram and isn't
 	       truncated, so we can checksum it. */
@@ -1033,6 +1033,11 @@ dissect_ospf_options(tvbuff_t *tvb, int offset, proto_tree *tree)
 	    strcat(options_string, "/");
 	strcat(options_string, "O");
     }
+    if (options & OSPF_OPTIONS_DN) {
+    	if (options_string[0] != '\0')
+	    strcat(options_string, "/");
+	strcat(options_string, "DN");  
+    }
 
     proto_tree_add_text(tree, tvb, offset, 1, "Options: 0x%x (%s)",
 			options, options_string);
