@@ -1,10 +1,10 @@
 /* packet-portmap.c
  * Routines for portmap dissection
  *
- * $Id: packet-portmap.c,v 1.29 2001/04/17 06:29:12 guy Exp $
+ * $Id: packet-portmap.c,v 1.31 2001/06/18 02:17:50 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-smb.c
@@ -97,7 +97,7 @@ int dissect_getport_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int dissect_getport_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, hf_portmap_port,
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, hf_portmap_port,
 	    offset);
 	return offset;
 }
@@ -159,7 +159,7 @@ int dissect_unset_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int dissect_set_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
-	offset = dissect_rpc_bool_tvb(tvb, pinfo, tree, hf_portmap_answer,
+	offset = dissect_rpc_bool(tvb, pinfo, tree, hf_portmap_answer,
 	    offset);
 	return offset;
 }
@@ -200,7 +200,7 @@ dissect_dump_entry(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int dissect_dump_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
-	offset = dissect_rpc_list_tvb(tvb, pinfo, tree, offset,
+	offset = dissect_rpc_list(tvb, pinfo, tree, offset,
 		dissect_dump_entry);
 	return offset;
 }
@@ -322,13 +322,13 @@ dissect_rpcb(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 			"Program: %s (%u)", rpc_prog_name(prog), prog);
 	offset += 4;
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, rpcb_tree,
+	offset = dissect_rpc_uint32(tvb, pinfo, rpcb_tree,
 	    hf_portmap_rpcb_version, offset);
-	offset = dissect_rpc_string_tvb(tvb, pinfo, rpcb_tree,
+	offset = dissect_rpc_string(tvb, pinfo, rpcb_tree,
 	    hf_portmap_rpcb_netid, offset, NULL);
-	offset = dissect_rpc_string_tvb(tvb, pinfo, rpcb_tree,
+	offset = dissect_rpc_string(tvb, pinfo, rpcb_tree,
 	    hf_portmap_rpcb_addr, offset, NULL);
-	offset = dissect_rpc_string_tvb(tvb, pinfo, rpcb_tree,
+	offset = dissect_rpc_string(tvb, pinfo, rpcb_tree,
 	    hf_portmap_rpcb_owner, offset, NULL);
 
 	/* now we know, that rpcb is shorter */
@@ -355,7 +355,7 @@ int dissect_rpcb3_getaddr_call(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int dissect_rpcb3_getaddr_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree,
+	offset = dissect_rpc_string(tvb, pinfo, tree,
 	    hf_portmap_uaddr, offset, NULL);
 
 	return offset;
@@ -366,7 +366,7 @@ int dissect_rpcb3_getaddr_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 int dissect_rpcb3_dump_reply(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
-	offset = dissect_rpc_list_tvb(tvb, pinfo, tree, offset, dissect_rpcb);
+	offset = dissect_rpc_list(tvb, pinfo, tree, offset, dissect_rpcb);
 	return offset;
 }
 
@@ -375,7 +375,7 @@ int dissect_rpcb_rmtcallres(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	proto_tree *tree)
 {
 	/* Dissect the remote universal address. */
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree,
+	offset = dissect_rpc_string(tvb, pinfo, tree,
 	    hf_portmap_rpcb_addr, offset, NULL);
 
 	/* Dissect the result of this procedure.
@@ -453,49 +453,49 @@ proto_register_portmap(void)
 	static hf_register_info hf[] = {
 		{ &hf_portmap_prog, {
 			"Program", "portmap.prog", FT_UINT32, BASE_DEC,
-			NULL, 0, "Program" }},
+			NULL, 0, "Program", HFILL }},
 		{ &hf_portmap_port, {
 			"Port", "portmap.port", FT_UINT32, BASE_DEC,
-			NULL, 0, "Port" }},
+			NULL, 0, "Port", HFILL }},
 		{ &hf_portmap_proc, {
 			"Procedure", "portmap.proc", FT_UINT32, BASE_DEC,
-			NULL, 0, "Procedure" }},
+			NULL, 0, "Procedure", HFILL }},
 		{ &hf_portmap_proto, {
 			"Protocol", "portmap.proto", FT_UINT32, BASE_DEC,
-			NULL, 0, "Protocol" }},
+			NULL, 0, "Protocol", HFILL }},
 		{ &hf_portmap_version, {
 			"Version", "portmap.version", FT_UINT32, BASE_DEC,
-			NULL, 0, "Version" }},
+			NULL, 0, "Version", HFILL }},
 		{ &hf_portmap_answer, {
 			"Answer", "portmap.answer", FT_BOOLEAN, BASE_DEC,
-			NULL, 0, "Answer" }},
+			NULL, 0, "Answer", HFILL }},
 		{ &hf_portmap_args, {
 			"Arguments", "portmap.args", FT_BYTES, BASE_HEX,
-			NULL, 0, "Arguments" }},
+			NULL, 0, "Arguments", HFILL }},
 		{ &hf_portmap_result, {
 			"Result", "portmap.result", FT_BYTES, BASE_HEX,
-			NULL, 0, "Result" }},
+			NULL, 0, "Result", HFILL }},
 		{ &hf_portmap_rpcb, {
 			"RPCB", "portmap.rpcb", FT_NONE, 0,
-			NULL, 0, "RPCB" }},
+			NULL, 0, "RPCB", HFILL }},
 		{ &hf_portmap_rpcb_prog, {
 			"Program", "portmap.rpcb.prog", FT_UINT32, BASE_DEC,
-			NULL, 0, "Program" }},
+			NULL, 0, "Program", HFILL }},
 		{ &hf_portmap_rpcb_version, {
 			"Version", "portmap.rpcb.version", FT_UINT32, BASE_DEC,
-			NULL, 0, "Version" }},
+			NULL, 0, "Version", HFILL }},
 		{ &hf_portmap_rpcb_netid, {
 			"Network Id", "portmap.rpcb.netid", FT_STRING, BASE_DEC,
-			NULL, 0, "Network Id" }},
+			NULL, 0, "Network Id", HFILL }},
 		{ &hf_portmap_rpcb_addr, {	/* address in rpcb structure in request */
 			"Universal Address", "portmap.rpcb.addr", FT_STRING, BASE_DEC,
-			NULL, 0, "Universal Address" }},
+			NULL, 0, "Universal Address", HFILL }},
 		{ &hf_portmap_rpcb_owner, {
 			"Owner of this Service", "portmap.rpcb.owner", FT_STRING, BASE_DEC,
-			NULL, 0, "Owner of this Service" }},
+			NULL, 0, "Owner of this Service", HFILL }},
 		{ &hf_portmap_uaddr, {	/* address in RPCBPROC_GETADDR reply */
 			"Universal Address", "portmap.uaddr", FT_STRING, BASE_DEC,
-			NULL, 0, "Universal Address" }},
+			NULL, 0, "Universal Address", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_portmap,
