@@ -2,10 +2,10 @@
  * Routines for Q.2931 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q2931.c,v 1.15 2001/04/17 06:43:19 guy Exp $
+ * $Id: packet-q2931.c,v 1.18 2001/06/18 02:17:50 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998
  *
  * 
@@ -1970,7 +1970,7 @@ dissect_q2931_ie(tvbuff_t *tvb, int offset, int len, proto_tree *tree,
 	}
 }
 
-void
+static void
 dissect_q2931(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	int		offset = 0;
@@ -1989,10 +1989,6 @@ dissect_q2931(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int		codeset;
 	gboolean	non_locking_shift;
 
-	CHECK_DISPLAY_AS_DATA(proto_q2931, tvb, pinfo, tree);
-
-	pinfo->current_proto = "Q.2931";
-
 	if (check_col(pinfo->fd, COL_PROTOCOL))
 		col_set_str(pinfo->fd, COL_PROTOCOL, "Q.2931");
 
@@ -2090,35 +2086,35 @@ proto_register_q2931(void)
 	static hf_register_info hf[] = {
 		{ &hf_q2931_discriminator,
 		  { "Protocol discriminator", "q2931.disc", FT_UINT8, BASE_HEX, NULL, 0x0, 
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_call_ref_len,
 		  { "Call reference value length", "q2931.call_ref_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_call_ref,
 		  { "Call reference value", "q2931.call_ref", FT_BYTES, BASE_HEX, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_message_type,
 		  { "Message type", "q2931.message_type", FT_UINT8, BASE_HEX, VALS(q2931_message_type_vals), 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_message_type_ext,
 		  { "Message type extension", "q2931.message_type_ext", FT_UINT8, BASE_HEX, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_message_flag,
 		  { "Flag", "q2931.message_flag", FT_BOOLEAN, 8, TFS(&tos_msg_flag), Q2931_MSG_TYPE_EXT_FOLLOW_INST,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_message_action_indicator,
 		  { "Action indicator", "q2931.message_action_indicator", FT_UINT8, BASE_DEC, VALS(msg_action_ind_vals), Q2931_MSG_TYPE_EXT_ACTION_IND,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q2931_message_len,
 		  { "Message length", "q2931.message_len", FT_UINT16, BASE_DEC, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 	};
 	static gint *ett[] = {
@@ -2132,4 +2128,6 @@ proto_register_q2931(void)
 	proto_q2931 = proto_register_protocol("Q.2931", "Q.2931", "q2931");
 	proto_register_field_array (proto_q2931, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	register_dissector("q2931", dissect_q2931, proto_q2931);
 }
