@@ -2,14 +2,13 @@
  * Routines for Q.931 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q931.c,v 1.28 2001/03/30 07:57:38 guy Exp $
+ * $Id: packet-q931.c,v 1.31 2001/07/03 04:56:45 guy Exp $
  *
  * Modified by Andreas Sikkema for possible use with H.323
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2365,7 +2364,7 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 		if ( ( tvb_get_guint8( tvb, offset ) == 0x7E ) && 
 		   ( tvb_get_guint8( tvb, offset + 3 ) == 0x05 ) && 
-		   /* ( ( pi.srcport == 1720 ) || ( pi.destport == 1720 ) ) && */
+		   /* ( ( pinfo->srcport == 1720 ) || ( pinfo->destport == 1720 ) ) && */
 		   ( protocol_discriminator == NLPID_Q_931 ) )  {
 			info_element_len = tvb_get_ntohs( tvb, offset + 1 );
 			is_h323_h225 = TRUE;
@@ -2606,10 +2605,9 @@ dissect_q931_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	return q931_dissector(tvb, pinfo, tree, TRUE);
 }
 
-void
+static void
 dissect_q931(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
-	pinfo->current_proto = "Q.931";
 	q931_dissector(tvb, pinfo, tree, FALSE);
 }
 
@@ -2619,19 +2617,19 @@ proto_register_q931(void)
 	static hf_register_info hf[] = {
 		{ &hf_q931_discriminator,
 		  { "Protocol discriminator", "q931.disc", FT_UINT8, BASE_HEX, NULL, 0x0, 
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q931_call_ref_len,
 		  { "Call reference value length", "q931.call_ref_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q931_call_ref,
 		  { "Call reference value", "q931.call_ref", FT_BYTES, BASE_HEX, NULL, 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 		{ &hf_q931_message_type,
 		  { "Message type", "q931.message_type", FT_UINT8, BASE_HEX, VALS(q931_message_type_vals), 0x0,
-		  	"" }},
+		  	"", HFILL }},
 
 	    };
 	static gint *ett[] = {
@@ -2643,6 +2641,7 @@ proto_register_q931(void)
 	proto_register_field_array (proto_q931, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
+	register_dissector("q931", dissect_q931, proto_q931);
 }
 
 void
