@@ -1,13 +1,13 @@
 /* packet-quake.c
- * Routines for quake packet dissection
+ * Routines for Quake packet dissection
  *
  * Uwe Girlich <uwe@planetquake.com>
  *	http://www.idsoftware.com/q1source/q1source.zip
  *
- * $Id: packet-quake.c,v 1.14 2001/04/15 09:05:17 guy Exp $
+ * $Id: packet-quake.c,v 1.17 2001/07/03 04:56:45 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-tftp.c
@@ -42,6 +42,7 @@
 #include <glib.h>
 #include "packet.h"
 #include "conversation.h"
+#include "prefs.h"
 
 static int proto_quake = -1;
 static int hf_quake_header_flags = -1; 
@@ -84,6 +85,7 @@ static gint ett_quake_flags = -1;
 #define NETFLAG_LENGTH_MASK 0x0000ffff
 #define NET_HEADERSIZE 8
 #define DEFAULTnet_hostport 26000
+static unsigned int gbl_quakeServerPort=DEFAULTnet_hostport;
 
 #define NETFLAG_LENGTH_MASK     0x0000ffff
 #define NETFLAG_DATA            0x00010000
@@ -238,8 +240,8 @@ dissect_quake_CCREP_ACCEPT
 	conversation_t *c;
 
 	port = tvb_get_letohl(tvb, 0);
-	c = conversation_new( &pi.src, &pi.dst, PT_UDP, port, pi.destport,
-	    NULL, 0);
+	c = conversation_new( &pinfo->src, &pinfo->dst, PT_UDP, port,
+	    pinfo->destport, NULL, 0);
 	if (c) {
 		conversation_set_dissector(c, dissect_quake);
 	}
@@ -285,7 +287,7 @@ dissect_quake_CCREP_SERVER_INFO
 
 	offset = 0;
 
-	maxbufsize = MIN(sizeof(address), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(address), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, address);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_SERVER_INFO_address,
@@ -293,7 +295,7 @@ dissect_quake_CCREP_SERVER_INFO
 	}
 	offset += len + 1;
 
-	maxbufsize = MIN(sizeof(server), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(server), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, server);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_SERVER_INFO_server,
@@ -301,7 +303,7 @@ dissect_quake_CCREP_SERVER_INFO
 	}
 	offset += len + 1;
 	
-	maxbufsize = MIN(sizeof(map), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(map), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, map);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_SERVER_INFO_map,
@@ -349,7 +351,7 @@ dissect_quake_CCREP_PLAYER_INFO
 	}
 	offset += 1;
 	
-	maxbufsize = MIN(sizeof(name), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(name), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, name);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_PLAYER_INFO_name,
@@ -386,7 +388,7 @@ dissect_quake_CCREP_PLAYER_INFO
 	}
 	offset += 3*4;
 
-	maxbufsize = MIN(sizeof(address), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(address), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, address);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_PLAYER_INFO_address,
@@ -410,7 +412,7 @@ dissect_quake_CCREP_RULE_INFO
 
 	offset = 0;
 
-	maxbufsize = MIN(sizeof(rule), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(rule), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, rule);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_RULE_INFO_rule,
@@ -418,7 +420,7 @@ dissect_quake_CCREP_RULE_INFO
 	}
 	offset += len + 1;
 
-	maxbufsize = MIN(sizeof(value), tvb_length_remaining(tvb, offset));
+	maxbufsize = MIN((int)sizeof(value), tvb_length_remaining(tvb, offset));
 	len = tvb_get_nstringz0(tvb, offset, maxbufsize, value);
 	if (tree) {
 		proto_tree_add_string(tree, hf_quake_CCREP_RULE_INFO_value,
@@ -596,132 +598,156 @@ dissect_quake(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	dissect_data(next_tvb, 0, pinfo, quake_tree);
 }
 
-void
-proto_register_quake(void)
-{
-
-  static hf_register_info hf[] = {
-    { &hf_quake_header_flags,
-      { "Flags", "quake.header.flags",
-	FT_UINT16, BASE_HEX, NULL, 0x0,
-	"Flags" }},
-    { &hf_quake_header_length,
-      { "Length", "quake.header.length",
-	FT_UINT16, BASE_DEC, NULL, 0x0,
-	"full data length" }},
-    { &hf_quake_header_sequence,
-      { "Sequence", "quake.header.sequence",
-	FT_UINT32, BASE_HEX, NULL, 0x0,
-	"Sequence Number" }},
-    { &hf_quake_control_command,
-      { "Command", "quake.control.command",
-	FT_UINT8, BASE_HEX, VALS(names_control_command), 0x0,
-	"Control Command" }},
-    { &hf_quake_CCREQ_CONNECT_game,
-      { "Game", "quake.control.connect.game",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Game Name" }},
-    { &hf_quake_CCREQ_CONNECT_version,
-      { "Version", "quake.control.connect.version",
-	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Game Protocol Version Number" }},
-    { &hf_quake_CCREQ_SERVER_INFO_game,
-      { "Game", "quake.control.server_info.game",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Game Name" }},
-    { &hf_quake_CCREQ_SERVER_INFO_version,
-      { "Version", "quake.control.server_info.version",
-	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Game Protocol Version Number" }},
-    { &hf_quake_CCREQ_PLAYER_INFO_player,
-      { "Player", "quake.control.player_info.player",
-	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Player" }},
-    { &hf_quake_CCREQ_RULE_INFO_lastrule,
-      { "Last Rule", "quake.control.rule_info.lastrule",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Last Rule Name" }},
-    { &hf_quake_CCREP_ACCEPT_port,
-      { "Port", "quake.control.accept.port",
-	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Game Data Port" }},
-    { &hf_quake_CCREP_REJECT_reason,
-      { "Reason", "quake.control.reject.reason",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Reject Reason" }},
-    { &hf_quake_CCREP_SERVER_INFO_address,
-      { "Address", "quake.control.server_info.address",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Server Address" }},
-    { &hf_quake_CCREP_SERVER_INFO_server,
-      { "Server", "quake.control.server_info.server",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Server Name" }},
-    { &hf_quake_CCREP_SERVER_INFO_map,
-      { "Map", "quake.control.server_info.map",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Map Name" }},
-    { &hf_quake_CCREP_SERVER_INFO_num_player,
-      { "Number of Players", "quake.control.server_info.num_player",
-	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Current Number of Players" }},
-    { &hf_quake_CCREP_SERVER_INFO_max_player,
-      { "Maximal Number of Players", "quake.control.server_info.max_player",
-	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Maximal Number of Players" }},
-    { &hf_quake_CCREP_PLAYER_INFO_name,
-      { "Name", "quake.control.player_info.name",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Player Name" }},
-    { &hf_quake_CCREP_PLAYER_INFO_colors,
-      { "Colors", "quake.control.player_info.colors",
-	FT_UINT32, BASE_HEX, NULL, 0x0,
-	"Player Colors" }},
-    { &hf_quake_CCREP_PLAYER_INFO_colors_shirt,
-      { "Shirt", "quake.control.player_info.colors.shirt",
-	FT_UINT8, BASE_DEC, VALS(names_colors), 0x0,
-	"Shirt Color" }},
-    { &hf_quake_CCREP_PLAYER_INFO_colors_pants,
-      { "Pants", "quake.control.player_info.colors.pants",
-	FT_UINT8, BASE_DEC, VALS(names_colors), 0x0,
-	"Pants Color" }},
-    { &hf_quake_CCREP_PLAYER_INFO_frags,
-      { "Frags", "quake.control.player_info.frags",
-	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Player Frags" }},
-    { &hf_quake_CCREP_PLAYER_INFO_connect_time,
-      { "Connect Time", "quake.control.player_info.connect_time",
-	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Player Connect Time" }},
-    { &hf_quake_CCREP_PLAYER_INFO_address,
-      { "Address", "quake.control.player_info.address",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Player Address" }},
-    { &hf_quake_CCREP_RULE_INFO_rule,
-      { "Rule", "quake.control.rule_info.rule",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Rule Name" }},
-    { &hf_quake_CCREP_RULE_INFO_value,
-      { "Value", "quake.control.rule_info.value",
-	FT_STRING, BASE_DEC, NULL, 0x0,
-	"Rule Value" }},
-  };
-  static gint *ett[] = {
-    &ett_quake,
-    &ett_quake_control,
-    &ett_quake_control_colors,
-    &ett_quake_flags,
-  };
-
-  proto_quake = proto_register_protocol("Quake Network Protocol",
-					"QUAKE", "quake");
-  proto_register_field_array(proto_quake, hf, array_length(hf));
-  proto_register_subtree_array(ett, array_length(ett));
-}
-
 
 void
 proto_reg_handoff_quake(void)
 {
-  dissector_add("udp.port", DEFAULTnet_hostport, dissect_quake, proto_quake);
+	static int Initialized=FALSE;
+	static int ServerPort=0;
+ 
+	if (Initialized) {
+		dissector_delete("udp.port", ServerPort, dissect_quake);
+	} else {
+		Initialized=TRUE;
+	}
+ 
+	/* set port for future deletes */
+	ServerPort=gbl_quakeServerPort;
+ 
+	dissector_add("udp.port", gbl_quakeServerPort,
+                        dissect_quake, proto_quake);
 }
+
+
+void
+proto_register_quake(void)
+{
+  static hf_register_info hf[] = {
+    { &hf_quake_header_flags,
+      { "Flags", "quake.header.flags",
+	FT_UINT16, BASE_HEX, NULL, 0x0,
+	"Flags", HFILL }},
+    { &hf_quake_header_length,
+      { "Length", "quake.header.length",
+	FT_UINT16, BASE_DEC, NULL, 0x0,
+	"full data length", HFILL }},
+    { &hf_quake_header_sequence,
+      { "Sequence", "quake.header.sequence",
+	FT_UINT32, BASE_HEX, NULL, 0x0,
+	"Sequence Number", HFILL }},
+    { &hf_quake_control_command,
+      { "Command", "quake.control.command",
+	FT_UINT8, BASE_HEX, VALS(names_control_command), 0x0,
+	"Control Command", HFILL }},
+    { &hf_quake_CCREQ_CONNECT_game,
+      { "Game", "quake.control.connect.game",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Game Name", HFILL }},
+    { &hf_quake_CCREQ_CONNECT_version,
+      { "Version", "quake.control.connect.version",
+	FT_UINT8, BASE_DEC, NULL, 0x0,
+	"Game Protocol Version Number", HFILL }},
+    { &hf_quake_CCREQ_SERVER_INFO_game,
+      { "Game", "quake.control.server_info.game",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Game Name", HFILL }},
+    { &hf_quake_CCREQ_SERVER_INFO_version,
+      { "Version", "quake.control.server_info.version",
+	FT_UINT8, BASE_DEC, NULL, 0x0,
+	"Game Protocol Version Number", HFILL }},
+    { &hf_quake_CCREQ_PLAYER_INFO_player,
+      { "Player", "quake.control.player_info.player",
+	FT_UINT8, BASE_DEC, NULL, 0x0,
+	"Player", HFILL }},
+    { &hf_quake_CCREQ_RULE_INFO_lastrule,
+      { "Last Rule", "quake.control.rule_info.lastrule",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Last Rule Name", HFILL }},
+    { &hf_quake_CCREP_ACCEPT_port,
+      { "Port", "quake.control.accept.port",
+	FT_UINT32, BASE_DEC, NULL, 0x0,
+	"Game Data Port", HFILL }},
+    { &hf_quake_CCREP_REJECT_reason,
+      { "Reason", "quake.control.reject.reason",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Reject Reason", HFILL }},
+    { &hf_quake_CCREP_SERVER_INFO_address,
+      { "Address", "quake.control.server_info.address",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Server Address", HFILL }},
+    { &hf_quake_CCREP_SERVER_INFO_server,
+      { "Server", "quake.control.server_info.server",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Server Name", HFILL }},
+    { &hf_quake_CCREP_SERVER_INFO_map,
+      { "Map", "quake.control.server_info.map",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Map Name", HFILL }},
+    { &hf_quake_CCREP_SERVER_INFO_num_player,
+      { "Number of Players", "quake.control.server_info.num_player",
+	FT_UINT8, BASE_DEC, NULL, 0x0,
+	"Current Number of Players", HFILL }},
+    { &hf_quake_CCREP_SERVER_INFO_max_player,
+      { "Maximal Number of Players", "quake.control.server_info.max_player",
+	FT_UINT8, BASE_DEC, NULL, 0x0,
+	"Maximal Number of Players", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_name,
+      { "Name", "quake.control.player_info.name",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Player Name", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_colors,
+      { "Colors", "quake.control.player_info.colors",
+	FT_UINT32, BASE_HEX, NULL, 0x0,
+	"Player Colors", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_colors_shirt,
+      { "Shirt", "quake.control.player_info.colors.shirt",
+	FT_UINT8, BASE_DEC, VALS(names_colors), 0x0,
+	"Shirt Color", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_colors_pants,
+      { "Pants", "quake.control.player_info.colors.pants",
+	FT_UINT8, BASE_DEC, VALS(names_colors), 0x0,
+	"Pants Color", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_frags,
+      { "Frags", "quake.control.player_info.frags",
+	FT_UINT32, BASE_DEC, NULL, 0x0,
+	"Player Frags", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_connect_time,
+      { "Connect Time", "quake.control.player_info.connect_time",
+	FT_UINT32, BASE_DEC, NULL, 0x0,
+	"Player Connect Time", HFILL }},
+    { &hf_quake_CCREP_PLAYER_INFO_address,
+      { "Address", "quake.control.player_info.address",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Player Address", HFILL }},
+    { &hf_quake_CCREP_RULE_INFO_rule,
+      { "Rule", "quake.control.rule_info.rule",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Rule Name", HFILL }},
+    { &hf_quake_CCREP_RULE_INFO_value,
+      { "Value", "quake.control.rule_info.value",
+	FT_STRING, BASE_DEC, NULL, 0x0,
+	"Rule Value", HFILL }},
+  };
+	static gint *ett[] = {
+		&ett_quake,
+		&ett_quake_control,
+		&ett_quake_control_colors,
+		&ett_quake_flags,
+	};
+	module_t *quake_module;
+
+	proto_quake = proto_register_protocol("Quake Network Protocol",
+					"QUAKE", "quake");
+	proto_register_field_array(proto_quake, hf, array_length(hf));
+	proto_register_subtree_array(ett, array_length(ett));
+
+	/* Register a configuration option for port */
+	quake_module = prefs_register_protocol(proto_quake,
+		proto_reg_handoff_quake);
+	prefs_register_uint_preference(quake_module, "udp.port",
+					"Quake Server UDP Port",
+					"Set the UDP port for the Quake Server",
+					10, &gbl_quakeServerPort);
+}
+
+
