@@ -2,7 +2,7 @@
  * Routines for RADIUS packet disassembly
  * Copyright 1999 Johan Feyaerts
  *
- * $Id: packet-radius.c,v 1.28 2001/03/13 21:34:23 gram Exp $
+ * $Id: packet-radius.c,v 1.32 2001/06/18 09:31:15 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -210,6 +210,7 @@ static value_string radius_vendor_specific_vendors[]=
 {429,"3Com"},
 {529,"Ascend"},
 {1584,"Bay Networks"},
+{2636,"Juniper Networks"},
 {0,NULL}};
 
 static value_string radius_framed_protocol_vals[]=
@@ -254,6 +255,7 @@ static value_string radius_terminating_action_vals[]=
 static value_string radius_accounting_status_type_vals[]=
 {{1, "Start"},
 {2, "Stop"},
+{3, "Interim-Update"},
 {7,"Accounting-On"},
 {8,"Accounting-Off"},
 {0,NULL}};
@@ -725,17 +727,19 @@ static void dissect_radius(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	hdrlength=RD_HDR_LENGTH+AUTHENTICATOR_LENGTH;
         avplength= rhlength -hdrlength;
 
-        /* list the attribute value pairs */
+        if (avplength > 0) {
+                /* list the attribute value pairs */
 
-        avptf = proto_tree_add_text(radius_tree,
-                        tvb,hdrlength,avplength,
-                        "Attribute value pairs");
-        avptree = proto_item_add_subtree(avptf, ett_radius_avp);
+                avptf = proto_tree_add_text(radius_tree,
+                                tvb,hdrlength,avplength,
+                                "Attribute value pairs");
+                avptree = proto_item_add_subtree(avptf, ett_radius_avp);
 
-        if (avptree !=NULL)
-        {
-                dissect_attribute_value_pairs(tvb, hdrlength,
+                if (avptree !=NULL)
+                {
+                        dissect_attribute_value_pairs(tvb, hdrlength,
                                 avptree,avplength);
+                }
         }
   }
 }
@@ -746,15 +750,15 @@ proto_register_radius(void)
 	static hf_register_info hf[] = {
 		{ &hf_radius_code,
 		{ "Code","radius.code", FT_UINT8, BASE_DEC, VALS(radius_vals), 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_radius_id,
 		{ "Identifier",	"radius.id", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_radius_length,
 		{ "Length","radius.length", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }}
+			"", HFILL }}
 	};
 	static gint *ett[] = {
 		&ett_radius,
