@@ -2,10 +2,10 @@
  * Routines for rpc dissection
  * Copyright 1999, Uwe Girlich <Uwe.Girlich@philosys.de>
  * 
- * $Id: packet-rpc.c,v 1.57 2001/05/07 20:36:38 guy Exp $
+ * $Id: packet-rpc.c,v 1.64 2001/07/03 02:05:47 guy Exp $
  * 
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  * 
  * Copied from packet-smb.c
@@ -125,6 +125,11 @@ static const value_string rpc_auth_state[] = {
 	{ 0, NULL }
 };
 
+static const value_string rpc_authdes_namekind[] = {
+	{ AUTHDES_NAMEKIND_FULLNAME, "ADN_FULLNAME" },
+	{ AUTHDES_NAMEKIND_NICKNAME, "ADN_NICKNAME" },
+	{ 0, NULL }
+};
 
 /* the protocol number */
 static int proto_rpc = -1;
@@ -158,6 +163,14 @@ static int hf_rpc_authgss_token = -1;
 static int hf_rpc_authgss_data_length = -1;
 static int hf_rpc_authgss_data = -1;
 static int hf_rpc_authgss_checksum = -1;
+static int hf_rpc_authdes_namekind = -1;
+static int hf_rpc_authdes_netname = -1;
+static int hf_rpc_authdes_convkey = -1;
+static int hf_rpc_authdes_window = -1;
+static int hf_rpc_authdes_nickname = -1;
+static int hf_rpc_authdes_timestamp = -1;
+static int hf_rpc_authdes_windowverf = -1;
+static int hf_rpc_authdes_timeverf = -1;
 static int hf_rpc_state_accept = -1;
 static int hf_rpc_state_reply = -1;
 static int hf_rpc_state_reject = -1;
@@ -190,15 +203,8 @@ typedef struct _rpc_proc_info_key {
 
 typedef struct _rpc_proc_info_value {
 	gchar		*name;
-	gboolean	is_old_dissector;
-	union {
-		old_dissect_function_t *old;
-		dissect_function_t *new;
-	} dissect_call;
-	union {
-		old_dissect_function_t *old;
-		dissect_function_t *new;
-	} dissect_reply;
+	dissect_function_t *dissect_call;
+	dissect_function_t *dissect_reply;
 } rpc_proc_info_value;
 
 typedef struct _rpc_prog_info_key {
@@ -240,30 +246,6 @@ rpc_proc_hash(gconstpointer k)
 
 
 /* insert some entries */
-void
-old_rpc_init_proc_table(guint prog, guint vers, const old_vsff *proc_table)
-{
-	const old_vsff *proc;
-
-	for (proc = proc_table ; proc->strptr!=NULL; proc++) {
-		rpc_proc_info_key *key;
-		rpc_proc_info_value *value;
-
-		key = (rpc_proc_info_key *) g_malloc(sizeof(rpc_proc_info_key));
-		key->prog = prog;
-		key->vers = vers;
-		key->proc = proc->value;
-
-		value = (rpc_proc_info_value *) g_malloc(sizeof(rpc_proc_info_value));
-		value->name = proc->strptr;
-		value->is_old_dissector = TRUE;
-		value->dissect_call.old = proc->dissect_call;
-		value->dissect_reply.old = proc->dissect_reply;
-
-		g_hash_table_insert(rpc_procs,key,value);
-	}
-}
-
 void
 rpc_init_proc_table(guint prog, guint vers, const vsff *proc_table)
 {
@@ -280,9 +262,8 @@ rpc_init_proc_table(guint prog, guint vers, const vsff *proc_table)
 
 		value = (rpc_proc_info_value *) g_malloc(sizeof(rpc_proc_info_value));
 		value->name = proc->strptr;
-		value->is_old_dissector = FALSE;
-		value->dissect_call.new = proc->dissect_call;
-		value->dissect_reply.new = proc->dissect_reply;
+		value->dissect_call = proc->dissect_call;
+		value->dissect_reply = proc->dissect_reply;
 
 		g_hash_table_insert(rpc_procs,key,value);
 	}
@@ -439,23 +420,7 @@ rpc_roundup(unsigned int a)
 
 
 int
-dissect_rpc_bool(const u_char *pd, int offset, frame_data *fd, proto_tree *tree,
-int hfindex)
-{
-	guint32 value;
-
-	if (!BYTES_ARE_IN_FRAME(offset,4)) return offset;
-	value = EXTRACT_UINT(pd, offset+0);
-	if (tree)
-		proto_tree_add_boolean(tree, hfindex, NullTVB, offset, 4, value);
-	offset += 4;
-
-	return offset;
-}
-
-
-int
-dissect_rpc_bool_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_bool(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 int hfindex, int offset)
 {
 	if (tree)
@@ -465,26 +430,7 @@ int hfindex, int offset)
 
 
 int
-dissect_rpc_uint32(const u_char *pd, int offset, frame_data *fd, proto_tree *tree,
-char* name)
-{
-	guint32 value;
-
-	if (!BYTES_ARE_IN_FRAME(offset,4)) return offset;
-	value = EXTRACT_UINT(pd, offset+0);
-
-	if (tree) {
-		proto_tree_add_text(tree, NullTVB, offset, 4,
-		"%s: %u", name, value);
-	}
-
-	offset += 4;
-	return offset;
-}
-
-
-int
-dissect_rpc_uint32_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_uint32(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 int hfindex, int offset)
 {
 	if (tree)
@@ -494,32 +440,7 @@ int hfindex, int offset)
 
 
 int
-dissect_rpc_uint64(const u_char *pd, int offset, frame_data *fd, proto_tree *tree,
-char* name)
-{
-	guint32 value_low;
-	guint32 value_high;
-
-	if (!BYTES_ARE_IN_FRAME(offset,8)) return offset;
-	value_high = EXTRACT_UINT(pd, offset+0);
-	value_low = EXTRACT_UINT(pd, offset+4);
-
-	if (tree) {
-		if (value_high)
-			proto_tree_add_text(tree, NullTVB, offset, 8,
-				"%s: 0x%x%08x", name, value_high, value_low);
-		else
-			proto_tree_add_text(tree, NullTVB, offset, 8,
-				"%s: %u", name, value_low);
-	}
-
-	offset += 8;
-	return offset;
-}
-
-
-int
-dissect_rpc_uint64_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_uint64(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 int hfindex, int offset)
 {
 	guint32 value_low;
@@ -641,7 +562,7 @@ dissect_rpc_opaque_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	}
 
 	if (tree) {
-		string_item = proto_tree_add_text(tree, tvb,offset+0, END_OF_FRAME,
+		string_item = proto_tree_add_text(tree, tvb,offset+0, tvb_length_remaining(tvb, offset),
 			"%s: %s", proto_registrar_get_name(hfindex), string_buffer_print);
 		if (string_data) {
 			proto_tree_add_string_hidden(tree, hfindex, tvb, offset+4,
@@ -654,20 +575,28 @@ dissect_rpc_opaque_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 	if (length_truncated) {
 		if (string_tree)
 			proto_tree_add_text(string_tree, tvb,
-				offset,pi.captured_len-offset,
+				offset, tvb_length_remaining(tvb, offset),
 				"length: <TRUNCATED>");
-		offset = pi.captured_len;
+		offset = tvb_length(tvb);
 	} else {
 		if (string_tree)
 			proto_tree_add_text(string_tree, tvb,offset+0,4,
 				"length: %u", string_length);
 		offset += 4;
 
-		if (string_tree)
-			proto_tree_add_string_format(string_tree, hfindex,
-				tvb, offset, string_length_copy,
-				string_buffer_print, 
-				"contents: %s", string_buffer_print);
+		if (string_tree) {
+			if (string_data) {
+				proto_tree_add_string_format(string_tree,
+				    hfindex, tvb, offset, string_length_copy,
+					string_buffer_print, 
+					"contents: %s", string_buffer_print);
+			} else {
+				proto_tree_add_bytes_format(string_tree,
+				    hfindex, tvb, offset, string_length_copy,
+					string_buffer_print, 
+					"contents: %s", string_buffer_print);
+			}
+		}
 		offset += string_length_copy;
 		if (fill_length) {
 			if (string_tree) {
@@ -702,19 +631,7 @@ dissect_rpc_opaque_data(tvbuff_t *tvb, int offset, packet_info *pinfo,
 
 
 int
-dissect_rpc_string(const u_char *pd, int offset, frame_data *fd,
-    proto_tree *tree, int hfindex, char **string_buffer_ret)
-{
-	tvbuff_t *tvb = tvb_create_from_top(offset);
-
-	offset = dissect_rpc_string_tvb(tvb, &pi, tree, hfindex, 0,
-	    string_buffer_ret);
-	return tvb_raw_offset(tvb) + offset;
-}
-
-
-int
-dissect_rpc_string_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     int hfindex, int offset, char **string_buffer_ret)
 {
 	offset = dissect_rpc_opaque_data(tvb, offset, pinfo, tree,
@@ -724,19 +641,7 @@ dissect_rpc_string_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 
 int
-dissect_rpc_data(const u_char *pd, int offset, frame_data *fd,
-    proto_tree *tree, int hfindex)
-{
-	tvbuff_t *tvb = tvb_create_from_top(offset);
-
-	offset = dissect_rpc_data_tvb(tvb, &pi, tree, hfindex, 0);
-
-	return tvb_raw_offset(tvb) + offset;
-}
-
-
-int
-dissect_rpc_data_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
     int hfindex, int offset)
 {
 	offset = dissect_rpc_opaque_data(tvb, offset, pinfo, tree, hfindex,
@@ -747,30 +652,7 @@ dissect_rpc_data_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 
 int
-dissect_rpc_list(const u_char *pd, int offset, frame_data *fd,
-	proto_tree *tree, old_dissect_function_t *rpc_list_dissector)
-{
-	guint32 value_follows;
-
-	while (1) {
-		if (!BYTES_ARE_IN_FRAME(offset,4)) break;
-		value_follows = EXTRACT_UINT(pd, offset+0);
-		proto_tree_add_boolean(tree,hf_rpc_value_follows, NullTVB,
-			offset+0, 4, value_follows);
-		offset += 4;
-		if (value_follows == 1) {
-			offset = rpc_list_dissector(pd, offset, fd, tree);
-		}
-		else {
-			break;
-		}
-	}
-
-	return offset;
-}
-
-int
-dissect_rpc_list_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_list(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	int offset, dissect_function_t *rpc_list_dissector)
 {
 	guint32 value_follows;
@@ -792,7 +674,7 @@ dissect_rpc_list_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 }
 
 int
-dissect_rpc_array_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+dissect_rpc_array(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	int offset, dissect_function_t *rpc_array_dissector,
 	int hfindex)
 {
@@ -816,7 +698,7 @@ dissect_rpc_array_tvb(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	lock_tree = proto_item_add_subtree(lock_item, ett_rpc_array); 	
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree,
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree,
 			hf_rpc_array_len, offset);
 
 	while (num--) {
@@ -839,31 +721,27 @@ dissect_rpc_authunix_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, i
 	proto_item *gitem;
 	proto_tree *gtree = NULL;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	stamp = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_auth_stamp, tvb,
 			offset+0, 4, stamp);
 	offset += 4;
 
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree,
+	offset = dissect_rpc_string(tvb, pinfo, tree,
 			hf_rpc_auth_machinename, offset, NULL);
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	uid = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_auth_uid, tvb,
 			offset+0, 4, uid);
 	offset += 4;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	gid = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_auth_gid, tvb,
 			offset+0, 4, gid);
 	offset += 4;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	gids_count = tvb_get_ntohl(tvb,offset+0);
 	if (tree) {
 		gitem = proto_tree_add_text(tree, tvb,
@@ -872,7 +750,6 @@ dissect_rpc_authunix_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, i
 	}
 	offset += 4;
 	
-	if (!tvb_bytes_exist(tvb,offset,4*gids_count)) return offset;
 	for (gids_i = 0 ; gids_i < gids_count ; gids_i++) {
 		gids_entry = tvb_get_ntohl(tvb,offset+0);
 		if (gtree)
@@ -894,40 +771,92 @@ dissect_rpc_authgss_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, in
 	guint agc_seq;
 	guint agc_svc;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	agc_v = tvb_get_ntohl(tvb, offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_v,
 				    tvb, offset+0, 4, agc_v);
 	offset += 4;
 	
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	agc_proc = tvb_get_ntohl(tvb, offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_proc,
 				    tvb, offset+0, 4, agc_proc);
 	offset += 4;
 	
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	agc_seq = tvb_get_ntohl(tvb, offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_seq,
 				    tvb, offset+0, 4, agc_seq);
 	offset += 4;
 	
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	agc_svc = tvb_get_ntohl(tvb, offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_svc,
 				    tvb, offset+0, 4, agc_svc);
 	offset += 4;
 	
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_ctx,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_ctx,
 			offset);
 	
 	return offset;
 }
 
+int
+dissect_rpc_authdes_desblock(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
+int hfindex, int offset)
+{
+	guint32 value_low;
+	guint32 value_high;
+
+	value_high = tvb_get_ntohl(tvb, offset + 0);
+	value_low  = tvb_get_ntohl(tvb, offset + 4);
+
+	if (tree) {
+		proto_tree_add_text(tree, tvb, offset, 8,
+			"%s: 0x%x%08x", proto_registrar_get_name(hfindex), value_high, 
+			value_low);
+	}
+
+	return offset + 8;
+}
+
+static int
+dissect_rpc_authdes_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset)
+{
+	guint adc_namekind;
+	guint window = 0;
+	guint nickname = 0;
+
+	adc_namekind = tvb_get_ntohl(tvb, offset+0);
+	if (tree)
+		proto_tree_add_uint(tree, hf_rpc_authdes_namekind,
+				    tvb, offset+0, 4, adc_namekind);
+	offset += 4;
+
+	switch(adc_namekind)
+	{
+	case AUTHDES_NAMEKIND_FULLNAME:
+		offset = dissect_rpc_string(tvb, pinfo, tree, 
+			hf_rpc_authdes_netname, offset, NULL);
+		offset = dissect_rpc_authdes_desblock(tvb, pinfo, tree,
+			hf_rpc_authdes_convkey, offset);
+		window = tvb_get_ntohl(tvb, offset+0);
+		proto_tree_add_uint(tree, hf_rpc_authdes_window, tvb, offset+0, 4,
+			window);
+		offset += 4;
+		break;
+
+	case AUTHDES_NAMEKIND_NICKNAME:
+		nickname = tvb_get_ntohl(tvb, offset+0);
+		proto_tree_add_uint(tree, hf_rpc_authdes_nickname, tvb, offset+0, 4,
+			window);
+		offset += 4;
+		break;
+	}
+
+	return offset;
+}
+
 static int
 dissect_rpc_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset)
 {
@@ -937,11 +866,9 @@ dissect_rpc_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 	proto_item *citem;
 	proto_tree *ctree;
 
-	if (!tvb_bytes_exist(tvb, offset,8)) return offset;
 	flavor = tvb_get_ntohl(tvb,offset+0);
 	length = tvb_get_ntohl(tvb,offset+4);
 	length = rpc_roundup(length);
-	if (!tvb_bytes_exist(tvb,offset+8,length)) return offset;
 
 	if (tree) {
 		citem = proto_tree_add_text(tree, tvb, offset,
@@ -961,13 +888,10 @@ dissect_rpc_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 
 		break;
 		*/
-		/* I have no tcpdump file with such a packet to verify the
-			info from the RFC 1050 */
-		/*
 		case AUTH_DES:
-
-		break;
-		*/
+			dissect_rpc_authdes_cred(tvb, pinfo, ctree, offset+8);
+			break;
+			
 		case RPCSEC_GSS:
 			dissect_rpc_authgss_cred(tvb, pinfo, ctree, offset+8);
 			break;
@@ -983,8 +907,11 @@ dissect_rpc_cred(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 	return offset;
 }
 
+/* AUTH_DES verifiers are asymmetrical, so we need to know what type of
+ * verifier we're decoding (CALL or REPLY).
+ */
 static int
-dissect_rpc_verf(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset)
+dissect_rpc_verf(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset, int msg_type)
 {
 	guint flavor;
 	guint length;
@@ -992,11 +919,9 @@ dissect_rpc_verf(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 	proto_item *vitem;
 	proto_tree *vtree;
 
-	if (!tvb_bytes_exist(tvb,offset,8)) return offset;
 	flavor = tvb_get_ntohl(tvb,offset+0);
 	length = tvb_get_ntohl(tvb,offset+4);
 	length = rpc_roundup(length);
-	if (!tvb_bytes_exist(tvb,offset+8,length)) return offset;
 
 	if (tree) {
 		vitem = proto_tree_add_text(tree, tvb, offset,
@@ -1011,8 +936,34 @@ dissect_rpc_verf(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 					    offset+4, 4, length);
 			dissect_rpc_authunix_cred(tvb, pinfo, vtree, offset+8);
 			break;
+		case AUTH_DES:
+			proto_tree_add_uint(vtree, hf_rpc_auth_length, tvb,
+				offset+4, 4, length);
+
+			if (msg_type == RPC_CALL)
+			{
+				guint window;
+
+				dissect_rpc_authdes_desblock(tvb, pinfo, vtree,
+					hf_rpc_authdes_timestamp, offset+8);
+				window = tvb_get_ntohl(tvb, offset+16);
+				proto_tree_add_uint(vtree, hf_rpc_authdes_windowverf, tvb, 
+					offset+16, 4, window);
+			}
+			else
+			{
+				/* must be an RPC_REPLY */
+				guint nickname;
+
+				dissect_rpc_authdes_desblock(tvb, pinfo, vtree,
+					hf_rpc_authdes_timeverf, offset+8);
+				nickname = tvb_get_ntohl(tvb, offset+16);
+				proto_tree_add_uint(vtree, hf_rpc_authdes_nickname, tvb, 
+				 	offset+16, 4, nickname);
+			}
+			break;
 		case RPCSEC_GSS:
-			dissect_rpc_data_tvb(tvb, pinfo, vtree,
+			dissect_rpc_data(tvb, pinfo, vtree,
 				hf_rpc_authgss_checksum, offset+4);
 			break;
 		default:
@@ -1032,7 +983,7 @@ dissect_rpc_verf(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset
 static int
 dissect_rpc_authgss_initarg(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree, int offset)
 {
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_token,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_token,
 			offset);
 	return offset;
 }
@@ -1042,31 +993,28 @@ dissect_rpc_authgss_initres(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
 {
 	int major, minor, window;
 	
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_ctx,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_ctx,
 			offset);
 	
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	major = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_major, tvb,
 				    offset+0, 4, major);
 	offset += 4;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	minor = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_minor, tvb,
 				    offset+0, 4, minor);
 	offset += 4;
 
-	if (!tvb_bytes_exist(tvb,offset,4)) return offset;
 	window = tvb_get_ntohl(tvb,offset+0);
 	if (tree)
 		proto_tree_add_uint(tree, hf_rpc_authgss_window, tvb,
 				    offset+0, 4, window);
 	offset += 4;
 
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_token,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_token,
 			offset);
 
 	return offset;
@@ -1075,32 +1023,18 @@ dissect_rpc_authgss_initres(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree,
 
 static int
 call_dissect_function(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
-	int offset, old_dissect_function_t *old_dissect_function,
-	dissect_function_t* dissect_function, const char *progname)
+	int offset, dissect_function_t* dissect_function, const char *progname)
 {
 	const char *saved_proto;
 
-	if (old_dissect_function != NULL || dissect_function != NULL) {
+	if (dissect_function != NULL) {
 		/* set the current protocol name */
 		saved_proto = pinfo->current_proto;
 		if (progname != NULL)
 			pinfo->current_proto = progname;
 
 		/* call the dissector for the next level */
-		if (dissect_function == NULL) {
-			const guint8 *tvb_pd;
-			int tvb_offset;
-
-			/*
-			 * It's an old-style dissector.
-			 * Make a pd, offset pair.
-			 */
-			tvb_compat(tvb, &tvb_pd, &tvb_offset);
-
-			offset = old_dissect_function(tvb_pd,
-			    tvb_offset + offset, pinfo->fd, tree) - tvb_offset;
-		} else
-			offset = dissect_function(tvb, offset, pinfo, tree);
+		offset = dissect_function(tvb, offset, pinfo, tree);
 
 		/* restore the protocol name */
 		pinfo->current_proto = saved_proto;
@@ -1113,7 +1047,6 @@ call_dissect_function(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 static int
 dissect_rpc_authgss_integ_data(tvbuff_t *tvb, packet_info *pinfo,
 	proto_tree *tree, int offset,
-	old_dissect_function_t *old_dissect_function,
 	dissect_function_t* dissect_function,
 	const char *progname)
 {
@@ -1122,7 +1055,6 @@ dissect_rpc_authgss_integ_data(tvbuff_t *tvb, packet_info *pinfo,
 	proto_item *gitem;
 	proto_tree *gtree = NULL;
 
-	if (!tvb_bytes_exist(tvb, offset, 8)) return offset;
 	length = tvb_get_ntohl(tvb, offset+0);
 	length = rpc_roundup(length);
 	seq = tvb_get_ntohl(tvb, offset+4);
@@ -1136,14 +1068,13 @@ dissect_rpc_authgss_integ_data(tvbuff_t *tvb, packet_info *pinfo,
 		proto_tree_add_uint(gtree, hf_rpc_authgss_seq,
 				    tvb, offset+4, 4, seq);
 	}
-	if (old_dissect_function != NULL || dissect_function != NULL) {
+	if (dissect_function != NULL) {
 		/* offset = */
 		call_dissect_function(tvb, pinfo, gtree, offset,
-				      old_dissect_function, dissect_function,
-				      progname);
+				      dissect_function, progname);
 	}
 	offset += 8 + length;
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_checksum,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_checksum,
 			offset);
 	return offset;
 }
@@ -1152,7 +1083,7 @@ dissect_rpc_authgss_integ_data(tvbuff_t *tvb, packet_info *pinfo,
 static int
 dissect_rpc_authgss_priv_data(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 {
-	offset = dissect_rpc_data_tvb(tvb, pinfo, tree, hf_rpc_authgss_data,
+	offset = dissect_rpc_data(tvb, pinfo, tree, hf_rpc_authgss_data,
 			offset);
 	return offset;
 }
@@ -1175,17 +1106,13 @@ dissect_rpc_indir_call(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	rpc_call_info_value *rpc_call;
 	rpc_call_info_key rpc_call_key;
 	rpc_call_info_key *new_rpc_call_key;
-	old_dissect_function_t *old_dissect_function = NULL;
 	dissect_function_t *dissect_function = NULL;
 
 	key.prog = prog;
 	key.vers = vers;
 	key.proc = proc;
 	if ((value = g_hash_table_lookup(rpc_procs,&key)) != NULL) {
-		if (value->is_old_dissector)
-			old_dissect_function = value->dissect_call.old;
-		else
-			dissect_function = value->dissect_call.new;
+		dissect_function = value->dissect_call;
 
 		/* Keep track of the address and port whence the call came,
 		   and the port to which the call is being sent, so that
@@ -1246,7 +1173,7 @@ dissect_rpc_indir_call(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		   Happens only with strange program versions or
 		   non-existing dissectors.
 		   Just show the arguments as opaque data. */
-		offset = dissect_rpc_data_tvb(tvb, pinfo, tree, args_id,
+		offset = dissect_rpc_data(tvb, pinfo, tree, args_id,
 		    offset);
 		return offset;
 	}
@@ -1261,7 +1188,7 @@ dissect_rpc_indir_call(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	/* Dissect the arguments */
 	offset = call_dissect_function(tvb, pinfo, tree, offset,
-			old_dissect_function, dissect_function, NULL);
+			dissect_function, NULL);
 	return offset;
 }
 
@@ -1279,7 +1206,6 @@ dissect_rpc_indir_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	rpc_call_info_value *rpc_call;
 	char *procname = NULL;
 	char procname_static[20];
-	old_dissect_function_t *old_dissect_function = NULL;
 	dissect_function_t *dissect_function = NULL;
 
 	/* Look for the matching call in the hash table of indirect
@@ -1296,7 +1222,7 @@ dissect_rpc_indir_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		/* We haven't seen an RPC call for that conversation,
 		   so we can't check for a reply to that call.
 		   Just show the reply stuff as opaque data. */
-		offset = dissect_rpc_data_tvb(tvb, pinfo, tree, result_id,
+		offset = dissect_rpc_data(tvb, pinfo, tree, result_id,
 		    offset);
 		return offset;
 	}
@@ -1309,16 +1235,13 @@ dissect_rpc_indir_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		/* The XID doesn't match a call from that
 		   conversation, so it's probably not an RPC reply.
 		   Just show the reply stuff as opaque data. */
-		offset = dissect_rpc_data_tvb(tvb, pinfo, tree, result_id,
+		offset = dissect_rpc_data(tvb, pinfo, tree, result_id,
 		    offset);
 		return offset;
 	}
 
 	if (rpc_call->proc_info != NULL) {
-		if (rpc_call->proc_info->is_old_dissector)
-			old_dissect_function = rpc_call->proc_info->dissect_reply.old;
-		else
-			dissect_function = rpc_call->proc_info->dissect_reply.new;
+		dissect_function = rpc_call->proc_info->dissect_reply;
 		if (rpc_call->proc_info->name != NULL) {
 			procname = rpc_call->proc_info->name;
 		}
@@ -1347,10 +1270,10 @@ dissect_rpc_indir_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 			procname, rpc_call->proc);
 	}
 
-	if (old_dissect_function == NULL && dissect_function == NULL) {
+	if (dissect_function == NULL) {
 		/* We don't know how to dissect the reply procedure.
 		   Just show the reply stuff as opaque data. */
-		offset = dissect_rpc_data_tvb(tvb, pinfo, tree, result_id,
+		offset = dissect_rpc_data(tvb, pinfo, tree, result_id,
 		    offset);
 		return offset;
 	}
@@ -1365,7 +1288,7 @@ dissect_rpc_indir_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 	/* Dissect the return value */
 	offset = call_dissect_function(tvb, pinfo, tree, offset,
-			old_dissect_function, dissect_function, NULL);
+			dissect_function, NULL);
 	return offset;
 }
 
@@ -1420,7 +1343,6 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	conversation_t* conversation;
 	static address null_address = { AT_NONE, 0, NULL };
 
-	old_dissect_function_t *old_dissect_function = NULL;
 	dissect_function_t *dissect_function = NULL;
 
 	/* TCP uses record marking */
@@ -1567,20 +1489,16 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			col_set_str(pinfo->fd, COL_PROTOCOL, progname);
 		}
 
-		if (!tvb_bytes_exist(tvb, offset+8,4))
-			return TRUE;
 		vers = tvb_get_ntohl(tvb, offset+8);
 		if (rpc_tree) {
 			proto_tree_add_uint(rpc_tree,
 				hf_rpc_programversion, tvb, offset+8, 4, vers);
 		}
 
-		if (!tvb_bytes_exist(tvb, offset+12,4))
-			return TRUE;
 		proc = tvb_get_ntohl(tvb, offset+12);
 
 		/* Check for RPCSEC_GSS */
-		if (proc == 0 && tvb_bytes_exist(tvb, offset+16,28)) {
+		if (proc == 0) {
 			flavor = tvb_get_ntohl(tvb, offset+16);
 			if (flavor == RPCSEC_GSS) {
 				gss_proc = tvb_get_ntohl(tvb, offset+28);
@@ -1592,10 +1510,7 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		key.proc = proc;
 
 		if ((value = g_hash_table_lookup(rpc_procs,&key)) != NULL) {
-			if (value->is_old_dissector)
-				old_dissect_function = value->dissect_call.old;
-			else
-				dissect_function = value->dissect_call.new;
+			dissect_function = value->dissect_call;
 			procname = value->name;
 		}
 		else {
@@ -1690,7 +1605,7 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		offset += 16;
 
 		offset = dissect_rpc_cred(tvb, pinfo, rpc_tree, offset);
-		offset = dissect_rpc_verf(tvb, pinfo, rpc_tree, offset);
+		offset = dissect_rpc_verf(tvb, pinfo, rpc_tree, offset, msg_type);
 
 		/* go to the next dissector */
 
@@ -1708,14 +1623,11 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		/* Indicate the frame to which this is a reply. */
 		proto_tree_add_text(rpc_tree, tvb, 0, 0,
-		    "This is a reply to a request starting in frame %u",
+		    "This is a reply to a request in frame %u",
 		    rpc_call->req_num);
 
 		if (rpc_call->proc_info != NULL) {
-			if (rpc_call->proc_info->is_old_dissector)
-				old_dissect_function = rpc_call->proc_info->dissect_reply.old;
-			else
-				dissect_function = rpc_call->proc_info->dissect_reply.new;
+			dissect_function = rpc_call->proc_info->dissect_reply;
 			if (rpc_call->proc_info->name != NULL) {
 				procname = rpc_call->proc_info->name;
 			}
@@ -1793,8 +1705,6 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			}
 		}
 
-		if (!tvb_bytes_exist(tvb, offset,4))
-			return TRUE;
 		reply_state = tvb_get_ntohl(tvb,offset+0);
 		if (rpc_tree) {
 			proto_tree_add_uint(rpc_tree, hf_rpc_state_reply, tvb,
@@ -1803,9 +1713,7 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		offset += 4;
 
 		if (reply_state == MSG_ACCEPTED) {
-			offset = dissect_rpc_verf(tvb, pinfo, rpc_tree, offset);
-			if (!tvb_bytes_exist(tvb, offset,4))
-				return TRUE;
+			offset = dissect_rpc_verf(tvb, pinfo, rpc_tree, offset, msg_type);
 			accept_state = tvb_get_ntohl(tvb,offset+0);
 			if (rpc_tree) {
 				proto_tree_add_uint(rpc_tree, hf_rpc_state_accept, tvb,
@@ -1813,31 +1721,30 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			}
 			offset += 4;
 			switch (accept_state) {
-				case SUCCESS:
-					/* go to the next dissector */
+
+			case SUCCESS:
+				/* go to the next dissector */
 				break;
-				case PROG_MISMATCH:
-					if (!tvb_bytes_exist(tvb,offset,8))
-						return TRUE;
-					vers_low = tvb_get_ntohl(tvb,offset+0);
-					vers_high = tvb_get_ntohl(tvb,offset+4);
-					if (rpc_tree) {
-						proto_tree_add_uint(rpc_tree,
-							hf_rpc_programversion_min,
-							tvb, offset+0, 4, vers_low);
-						proto_tree_add_uint(rpc_tree,
-							hf_rpc_programversion_max,
-							tvb, offset+4, 4, vers_high);
-					}
-					offset += 8;
+
+			case PROG_MISMATCH:
+				vers_low = tvb_get_ntohl(tvb,offset+0);
+				vers_high = tvb_get_ntohl(tvb,offset+4);
+				if (rpc_tree) {
+					proto_tree_add_uint(rpc_tree,
+						hf_rpc_programversion_min,
+						tvb, offset+0, 4, vers_low);
+					proto_tree_add_uint(rpc_tree,
+						hf_rpc_programversion_max,
+						tvb, offset+4, 4, vers_high);
+				}
+				offset += 8;
 				break;
-				default:
-					/* void */
+
+			default:
+				/* void */
 				break;
 			}
 		} else if (reply_state == MSG_DENIED) {
-			if (!tvb_bytes_exist(tvb,offset,4))
-				return TRUE;
 			reject_state = tvb_get_ntohl(tvb,offset+0);
 			if (rpc_tree) {
 				proto_tree_add_uint(rpc_tree,
@@ -1847,8 +1754,6 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			offset += 4;
 
 			if (reject_state==RPC_MISMATCH) {
-				if (!tvb_bytes_exist(tvb,offset,8))
-					return TRUE;
 				vers_low = tvb_get_ntohl(tvb,offset+0);
 				vers_high = tvb_get_ntohl(tvb,offset+4);
 				if (rpc_tree) {
@@ -1861,8 +1766,6 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 				}
 				offset += 8;
 			} else if (reject_state==AUTH_ERROR) {
-				if (!tvb_bytes_exist(tvb,offset,4))
-					return TRUE;
 				auth_state = tvb_get_ntohl(tvb,offset+0);
 				if (rpc_tree) {
 					proto_tree_add_uint(rpc_tree,
@@ -1897,21 +1800,20 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		if (ptree) {
 			proto_tree_add_uint(ptree,
-				hf_rpc_programversion, NullTVB, 0, 0, vers);
+				hf_rpc_programversion, tvb, 0, 0, vers);
 			proto_tree_add_uint_format(ptree,
-				hf_rpc_procedure, NullTVB, 0, 0, proc,
+				hf_rpc_procedure, tvb, 0, 0, proc,
 				"Procedure: %s (%u)", procname, proc);
 		}
 	}
 
-	if (!proto_is_protocol_enabled(proto)) {
-		old_dissect_function = NULL;
+	if (!proto_is_protocol_enabled(proto))
 		dissect_function = NULL;
-	}
 
 	/* RPCSEC_GSS processing. */
 	if (flavor == RPCSEC_GSS) {
 		switch (gss_proc) {
+
 		case RPCSEC_GSS_INIT:
 		case RPCSEC_GSS_CONTINUE_INIT:
 			if (msg_type == RPC_CALL) {
@@ -1923,18 +1825,17 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					pinfo, ptree, offset);
 			}
 			break;
+
 		case RPCSEC_GSS_DATA:
 			if (gss_svc == RPCSEC_GSS_SVC_NONE) {
 				offset = call_dissect_function(tvb, 
 						pinfo, ptree, offset,
-						old_dissect_function,
 						dissect_function,
 						progname);
 			}
 			else if (gss_svc == RPCSEC_GSS_SVC_INTEGRITY) {
 				offset = dissect_rpc_authgss_integ_data(tvb,
 						pinfo, ptree, offset,
-						old_dissect_function,
 						dissect_function,
 						progname);
 			}
@@ -1943,13 +1844,14 @@ dissect_rpc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						pinfo, ptree, offset);
 			}
 			break;
+
 		default:
 			break;
 		}
 	}
 	else {
 		offset=call_dissect_function(tvb, pinfo, ptree, offset,
-				old_dissect_function, dissect_function, progname);
+				dissect_function, progname);
 	}
 
 	/* dissect any remaining bytes (incomplete dissection) as pure data in
@@ -1993,121 +1895,145 @@ proto_register_rpc(void)
 	static hf_register_info hf[] = {
 		{ &hf_rpc_lastfrag, {
 			"Last Fragment", "rpc.lastfrag", FT_BOOLEAN, BASE_NONE,
-			&yesno, 0, "Last Fragment" }},
+			&yesno, 0, "Last Fragment", HFILL }},
 		{ &hf_rpc_fraglen, {
 			"Fragment Length", "rpc.fraglen", FT_UINT32, BASE_DEC,
-			NULL, 0, "Fragment Length" }},
+			NULL, 0, "Fragment Length", HFILL }},
 		{ &hf_rpc_xid, {
 			"XID", "rpc.xid", FT_UINT32, BASE_HEX,
-			NULL, 0, "XID" }},
+			NULL, 0, "XID", HFILL }},
 		{ &hf_rpc_msgtype, {
 			"Message Type", "rpc.msgtyp", FT_UINT32, BASE_DEC,
-			VALS(rpc_msg_type), 0, "Message Type" }},
+			VALS(rpc_msg_type), 0, "Message Type", HFILL }},
 		{ &hf_rpc_state_reply, {
 			"Reply State", "rpc.replystat", FT_UINT32, BASE_DEC,
-			VALS(rpc_reply_state), 0, "Reply State" }},
+			VALS(rpc_reply_state), 0, "Reply State", HFILL }},
 		{ &hf_rpc_state_accept, {
 			"Accept State", "rpc.state_accept", FT_UINT32, BASE_DEC,
-			VALS(rpc_accept_state), 0, "Accept State" }},
+			VALS(rpc_accept_state), 0, "Accept State", HFILL }},
 		{ &hf_rpc_state_reject, {
 			"Reject State", "rpc.state_reject", FT_UINT32, BASE_DEC,
-			VALS(rpc_reject_state), 0, "Reject State" }},
+			VALS(rpc_reject_state), 0, "Reject State", HFILL }},
 		{ &hf_rpc_state_auth, {
 			"Auth State", "rpc.state_auth", FT_UINT32, BASE_DEC,
-			VALS(rpc_auth_state), 0, "Auth State" }},
+			VALS(rpc_auth_state), 0, "Auth State", HFILL }},
 		{ &hf_rpc_version, {
 			"RPC Version", "rpc.version", FT_UINT32, BASE_DEC,
-			NULL, 0, "RPC Version" }},
+			NULL, 0, "RPC Version", HFILL }},
 		{ &hf_rpc_version_min, {
 			"RPC Version (Minimum)", "rpc.version.min", FT_UINT32, 
-			BASE_DEC, NULL, 0, "Program Version (Minimum)" }},
+			BASE_DEC, NULL, 0, "Program Version (Minimum)", HFILL }},
 		{ &hf_rpc_version_max, {
 			"RPC Version (Maximum)", "rpc.version.max", FT_UINT32, 
-			BASE_DEC, NULL, 0, "RPC Version (Maximum)" }},
+			BASE_DEC, NULL, 0, "RPC Version (Maximum)", HFILL }},
 		{ &hf_rpc_program, {
 			"Program", "rpc.program", FT_UINT32, BASE_DEC,
-			NULL, 0, "Program" }},
+			NULL, 0, "Program", HFILL }},
 		{ &hf_rpc_programversion, {
 			"Program Version", "rpc.programversion", FT_UINT32, 
-			BASE_DEC, NULL, 0, "Program Version" }},
+			BASE_DEC, NULL, 0, "Program Version", HFILL }},
 		{ &hf_rpc_programversion_min, {
 			"Program Version (Minimum)", "rpc.programversion.min", FT_UINT32, 
-			BASE_DEC, NULL, 0, "Program Version (Minimum)" }},
+			BASE_DEC, NULL, 0, "Program Version (Minimum)", HFILL }},
 		{ &hf_rpc_programversion_max, {
 			"Program Version (Maximum)", "rpc.programversion.max", FT_UINT32, 
-			BASE_DEC, NULL, 0, "Program Version (Maximum)" }},
+			BASE_DEC, NULL, 0, "Program Version (Maximum)", HFILL }},
 		{ &hf_rpc_procedure, {
 			"Procedure", "rpc.procedure", FT_UINT32, BASE_DEC,
-			NULL, 0, "Procedure" }},
+			NULL, 0, "Procedure", HFILL }},
 		{ &hf_rpc_auth_flavor, {
 			"Flavor", "rpc.auth.flavor", FT_UINT32, BASE_DEC,
-			VALS(rpc_auth_flavor), 0, "Flavor" }},
+			VALS(rpc_auth_flavor), 0, "Flavor", HFILL }},
 		{ &hf_rpc_auth_length, {
 			"Length", "rpc.auth.length", FT_UINT32, BASE_DEC,
-			NULL, 0, "Length" }},
+			NULL, 0, "Length", HFILL }},
 		{ &hf_rpc_auth_stamp, {
 			"Stamp", "rpc.auth.stamp", FT_UINT32, BASE_HEX,
-			NULL, 0, "Stamp" }},
+			NULL, 0, "Stamp", HFILL }},
 		{ &hf_rpc_auth_uid, {
 			"UID", "rpc.auth.uid", FT_UINT32, BASE_DEC,
-			NULL, 0, "UID" }},
+			NULL, 0, "UID", HFILL }},
 		{ &hf_rpc_auth_gid, {
 			"GID", "rpc.auth.gid", FT_UINT32, BASE_DEC,
-			NULL, 0, "GID" }},
+			NULL, 0, "GID", HFILL }},
 		{ &hf_rpc_authgss_v, {
 			"GSS Version", "rpc.authgss.version", FT_UINT32,
-			BASE_DEC, NULL, 0, "GSS Version" }},
+			BASE_DEC, NULL, 0, "GSS Version", HFILL }},
 		{ &hf_rpc_authgss_proc, {
 			"GSS Procedure", "rpc.authgss.procedure", FT_UINT32,
-			BASE_DEC, VALS(rpc_authgss_proc), 0, "GSS Procedure" }},
+			BASE_DEC, VALS(rpc_authgss_proc), 0, "GSS Procedure", HFILL }},
 		{ &hf_rpc_authgss_seq, {
 			"GSS Sequence Number", "rpc.authgss.seqnum", FT_UINT32,
-			BASE_DEC, NULL, 0, "GSS Sequence Number" }},
+			BASE_DEC, NULL, 0, "GSS Sequence Number", HFILL }},
 		{ &hf_rpc_authgss_svc, {
 			"GSS Service", "rpc.authgss.service", FT_UINT32,
-			BASE_DEC, VALS(rpc_authgss_svc), 0, "GSS Service" }},
+			BASE_DEC, VALS(rpc_authgss_svc), 0, "GSS Service", HFILL }},
 		{ &hf_rpc_authgss_ctx, {
 			"GSS Context", "rpc.authgss.context", FT_BYTES,
-			BASE_HEX, NULL, 0, "GSS Context" }},
+			BASE_HEX, NULL, 0, "GSS Context", HFILL }},
 		{ &hf_rpc_authgss_major, {
 			"GSS Major Status", "rpc.authgss.major", FT_UINT32,
-			BASE_DEC, NULL, 0, "GSS Major Status" }},
+			BASE_DEC, NULL, 0, "GSS Major Status", HFILL }},
 		{ &hf_rpc_authgss_minor, {
 			"GSS Minor Status", "rpc.authgss.minor", FT_UINT32,
-			BASE_DEC, NULL, 0, "GSS Minor Status" }},
+			BASE_DEC, NULL, 0, "GSS Minor Status", HFILL }},
 		{ &hf_rpc_authgss_window, {
 			"GSS Sequence Window", "rpc.authgss.window", FT_UINT32,
-			BASE_DEC, NULL, 0, "GSS Sequence Window" }},
+			BASE_DEC, NULL, 0, "GSS Sequence Window", HFILL }},
 		{ &hf_rpc_authgss_token, {
 			"GSS Token", "rpc.authgss.token", FT_BYTES,
-			BASE_HEX, NULL, 0, "GSS Token" }},
+			BASE_HEX, NULL, 0, "GSS Token", HFILL }},
 		{ &hf_rpc_authgss_data_length, {
 			"Length", "rpc.authgss.data.length", FT_UINT32,
-			BASE_DEC, NULL, 0, "Length" }},
+			BASE_DEC, NULL, 0, "Length", HFILL }},
 		{ &hf_rpc_authgss_data, {
 			"GSS Data", "rpc.authgss.data", FT_BYTES,
-			BASE_HEX, NULL, 0, "GSS Data" }},
+			BASE_HEX, NULL, 0, "GSS Data", HFILL }},
 		{ &hf_rpc_authgss_checksum, {
 			"GSS Checksum", "rpc.authgss.checksum", FT_BYTES,
-			BASE_HEX, NULL, 0, "GSS Checksum" }},
+			BASE_HEX, NULL, 0, "GSS Checksum", HFILL }},
+		{ &hf_rpc_authdes_namekind, {
+			"Namekind", "rpc.authdes.namekind", FT_UINT32, BASE_DEC,
+			VALS(rpc_authdes_namekind), 0, "Namekind", HFILL }},
+		{ &hf_rpc_authdes_netname, {
+			"Netname", "rpc.authdes.netname", FT_STRING,
+			BASE_DEC, NULL, 0, "Netname", HFILL }},
+		{ &hf_rpc_authdes_convkey, {
+			"Conversation Key (encrypted)", "rpc.authdes.convkey", FT_UINT32,
+			BASE_HEX, NULL, 0, "Conversation Key (encrypted)", HFILL }},
+		{ &hf_rpc_authdes_window, {
+			"Window (encrypted)", "rpc.authdes.window", FT_UINT32,
+			BASE_HEX, NULL, 0, "Windows (encrypted)", HFILL }},
+		{ &hf_rpc_authdes_nickname, {
+			"Nickname", "rpc.authdes.nickname", FT_UINT32, 
+			BASE_HEX, NULL, 0, "Nickname", HFILL }},
+		{ &hf_rpc_authdes_timestamp, {
+			"Timestamp (encrypted)", "rpc.authdes.timestamp", FT_UINT32,
+			BASE_HEX, NULL, 0, "Timestamp (encrypted)", HFILL }},
+		{ &hf_rpc_authdes_windowverf, {
+			"Window verifier (encrypted)", "rpc.authdes.windowverf", FT_UINT32,
+			BASE_HEX, NULL, 0, "Window verifier (encrypted)", HFILL }},
+		{ &hf_rpc_authdes_timeverf, {
+			"Timestamp verifier (encrypted)", "rpc.authdes.timeverf", FT_UINT32,
+			BASE_HEX, NULL, 0, "Timestamp verifier (encrypted)", HFILL }},
 		{ &hf_rpc_auth_machinename, {
 			"Machine Name", "rpc.auth.machinename", FT_STRING, 
-			BASE_DEC, NULL, 0, "Machine Name" }},
+			BASE_DEC, NULL, 0, "Machine Name", HFILL }},
 		{ &hf_rpc_dup, {
 			"Duplicate Transaction", "rpc.dup", FT_UINT32, BASE_DEC,
-			NULL, 0, "Duplicate Transaction" }},
+			NULL, 0, "Duplicate Transaction", HFILL }},
 		{ &hf_rpc_call_dup, {
 			"Duplicate Call", "rpc.call.dup", FT_UINT32, BASE_DEC,
-			NULL, 0, "Duplicate Call" }},
+			NULL, 0, "Duplicate Call", HFILL }},
 		{ &hf_rpc_reply_dup, {
 			"Duplicate Reply", "rpc.reply.dup", FT_UINT32, BASE_DEC,
-			NULL, 0, "Duplicate Reply" }},
+			NULL, 0, "Duplicate Reply", HFILL }},
 		{ &hf_rpc_value_follows, {
 			"Value Follows", "rpc.value_follows", FT_BOOLEAN, BASE_NONE,
-			&yesno, 0, "Value Follows" }},
+			&yesno, 0, "Value Follows", HFILL }},
 		{ &hf_rpc_array_len, {
 			"num", "rpc.array.len", FT_UINT32, BASE_DEC,
-			NULL, 0, "Length of RPC array" }},
+			NULL, 0, "Length of RPC array", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_rpc,
