@@ -2,10 +2,10 @@
  * Routines for rquota dissection
  * Copyright 2001, Mike Frisch <frisch@hummingbird.com>
  *
- * $Id: packet-rquota.c,v 1.2 2001/04/21 08:00:12 guy Exp $
+ * $Id: packet-rquota.c,v 1.4 2001/06/18 02:17:51 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-ypxfr.c
@@ -80,34 +80,34 @@ dissect_rquota(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 
 	lock_tree = proto_item_add_subtree(lock_item, ett_rquota_rquota);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_bsize, offset);
 
-	offset = dissect_rpc_bool_tvb(tvb, pinfo, lock_tree,
+	offset = dissect_rpc_bool(tvb, pinfo, lock_tree,
 			hf_rquota_active, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_bhardlimit, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_bsoftlimit, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_curblocks, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_fhardlimit, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_fsoftlimit, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_curfiles, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_btimeleft, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, lock_tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, lock_tree, 
 			hf_rquota_ftimeleft, offset);
 
 	return offset;
@@ -120,7 +120,7 @@ dissect_getquota_result(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tre
 
 	status = tvb_get_ntohl(tvb, offset);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, 
 			hf_rquota_status, offset);
 
 	if (status==Q_OK) {
@@ -133,10 +133,10 @@ dissect_getquota_result(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tre
 static int
 dissect_getquota_call(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
-	offset = dissect_rpc_string_tvb(tvb, pinfo, tree, 
+	offset = dissect_rpc_string(tvb, pinfo, tree, 
 			hf_rquota_pathp, offset, NULL);
 
-	offset = dissect_rpc_uint32_tvb(tvb, pinfo, tree, 
+	offset = dissect_rpc_uint32(tvb, pinfo, tree, 
 			hf_rquota_uid, offset);
 
 	return offset;
@@ -164,59 +164,59 @@ proto_register_rquota(void)
 	static hf_register_info hf[] = {
 		{ &hf_rquota_uid, {
 			"uid", "rquota.uid", FT_UINT32, BASE_DEC,
-			NULL, 0, "User ID" }},
+			NULL, 0, "User ID", HFILL }},
 
 		{ &hf_rquota_pathp, {
 			"pathp", "rquota.pathp", FT_STRING, BASE_DEC,
-			NULL, 0, "Filesystem of interest" }},
+			NULL, 0, "Filesystem of interest", HFILL }},
 
 		{ &hf_rquota_status, {
 			"status", "rquota.status", FT_UINT32, BASE_DEC,
-			VALS(names_rquota_status), 0, "Status code" }},
+			VALS(names_rquota_status), 0, "Status code", HFILL }},
 
 		{ &hf_rquota_rquota, {
 			"rquota", "rquota.rquota", FT_NONE, BASE_NONE,
-			NULL, 0, "Rquota structure" }},
+			NULL, 0, "Rquota structure", HFILL }},
 
 		{ &hf_rquota_bsize, {
 			"bsize", "rquota.bsize", FT_UINT32, BASE_DEC,
-			NULL, 0, "Block size" }},
+			NULL, 0, "Block size", HFILL }},
 
 		{ &hf_rquota_active, {
 			"active", "rquota.active", FT_BOOLEAN, BASE_NONE,
-			&tfs_active, 0, "Indicates whether quota is active" }},
+			&tfs_active, 0, "Indicates whether quota is active", HFILL }},
 
 		{ &hf_rquota_bhardlimit, {
 			"bhardlimit", "rquota.bhardlimit", FT_UINT32, BASE_DEC,
-			NULL, 0, "Hard limit for blocks" }},
+			NULL, 0, "Hard limit for blocks", HFILL }},
 
 		{ &hf_rquota_bsoftlimit, {
 			"bsoftlimit", "rquota.bsoftlimit", FT_UINT32, BASE_DEC,
-			NULL, 0, "Soft limit for blocks" }},
+			NULL, 0, "Soft limit for blocks", HFILL }},
 
 		{ &hf_rquota_curblocks, {
 			"curblocks", "rquota.curblocks", FT_UINT32, BASE_DEC,
-			NULL, 0, "Current block count" }},
+			NULL, 0, "Current block count", HFILL }},
 
 		{ &hf_rquota_fhardlimit, {
 			"fhardlimit", "rquota.fhardlimit", FT_UINT32, BASE_DEC,
-			NULL, 0, "Hard limit on allocated files" }},
+			NULL, 0, "Hard limit on allocated files", HFILL }},
 
 		{ &hf_rquota_fsoftlimit, {
 			"fsoftlimit", "rquota.fsoftlimit", FT_UINT32, BASE_DEC,
-			NULL, 0, "Soft limit of allocated files" }},
+			NULL, 0, "Soft limit of allocated files", HFILL }},
 
 		{ &hf_rquota_curfiles, {
 			"curfiles", "rquota.curfiles", FT_UINT32, BASE_DEC,
-			NULL, 0, "Current # allocated files" }},
+			NULL, 0, "Current # allocated files", HFILL }},
 
 		{ &hf_rquota_btimeleft, {
 			"btimeleft", "rquota.btimeleft", FT_UINT32, BASE_DEC,
-			NULL, 0, "Time left for excessive disk use" }},
+			NULL, 0, "Time left for excessive disk use", HFILL }},
 
 		{ &hf_rquota_ftimeleft, {
 			"ftimeleft", "rquota.ftimeleft", FT_UINT32, BASE_DEC,
-			NULL, 0, "Time left for excessive files" }},
+			NULL, 0, "Time left for excessive files", HFILL }},
 
 	};
 
