@@ -1,4 +1,6 @@
 /* packet-rtcp.c
+ *
+ * $Id: packet-rtcp.c,v 1.18 2001/07/03 04:56:45 guy Exp $
  *
  * Routines for RTCP dissection
  * RTCP = Real-time Transport Control Protocol
@@ -7,9 +9,8 @@
  * Written by Andreas Sikkema <andreas.sikkema@philips.com>
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -247,14 +248,14 @@ dissect_rtcp_heur( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 	 * a heuristic dissector called before us!
 	 * So we first check if the frame is really meant for us.
 	 */
-	if ( ( pconv = find_conversation( &pi.src, &fake_addr, pi.ptype,
-	    pi.srcport, 0, 0 ) ) == NULL ) {
+	if ( ( pconv = find_conversation( &pinfo->src, &fake_addr, pinfo->ptype,
+	    pinfo->srcport, 0, 0 ) ) == NULL ) {
 		/*
 		 * The source ip:port combination was not what we were
 		 * looking for, check the destination
 		 */
-		if ( ( pconv = find_conversation( &pi.dst, &fake_addr,
-		    pi.ptype, pi.destport, 0, 0 ) ) == NULL ) {
+		if ( ( pconv = find_conversation( &pinfo->dst, &fake_addr,
+		    pinfo->ptype, pinfo->destport, 0, 0 ) ) == NULL ) {
 			return FALSE;
 		}
 	}
@@ -759,15 +760,15 @@ dissect_rtcp( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree )
 					/* Packet length in 32 bit words MINUS one, 16 bits */
 					proto_tree_add_uint( rtcp_tree, hf_rtcp_length, tvb, offset, 2, tvb_get_ntohs( tvb, offset ) );
 					offset += 2;
-					dissect_rtcp_app( tvb, offset,
+					offset = dissect_rtcp_app( tvb, offset,
 					    pinfo->fd, rtcp_tree, padding_set,
 					    packet_length - 4 );
 					break;
 				case RTCP_FIR:
-					dissect_rtcp_fir( tvb, offset, pinfo->fd, rtcp_tree );
+					offset = dissect_rtcp_fir( tvb, offset, pinfo->fd, rtcp_tree );
 					break;
 				case RTCP_NACK:
-					dissect_rtcp_nack( tvb, offset, pinfo->fd, rtcp_tree );
+					offset = dissect_rtcp_nack( tvb, offset, pinfo->fd, rtcp_tree );
 					break;
 				default:
 					/*
@@ -807,7 +808,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				VALS(rtcp_version_vals), 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -819,7 +820,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -831,7 +832,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -843,7 +844,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -855,7 +856,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				VALS( rtcp_packet_type_vals ), 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -867,7 +868,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -879,7 +880,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -891,7 +892,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -903,7 +904,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -915,7 +916,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -927,7 +928,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -939,7 +940,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -951,7 +952,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -963,7 +964,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -975,7 +976,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -987,7 +988,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -999,7 +1000,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1011,7 +1012,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1023,7 +1024,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1035,7 +1036,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1047,7 +1048,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1059,7 +1060,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				VALS( rtcp_sdes_type_vals ), 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1071,7 +1072,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1083,7 +1084,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1095,7 +1096,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1107,7 +1108,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1119,7 +1120,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1131,7 +1132,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1143,7 +1144,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1155,7 +1156,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1167,7 +1168,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1179,7 +1180,7 @@ proto_register_rtcp(void)
 				BASE_DEC, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 		{ 
@@ -1191,7 +1192,7 @@ proto_register_rtcp(void)
 				BASE_NONE, 
 				NULL, 
 				0x0,
-				"" 
+				"", HFILL 
 			}
 		},
 };
