@@ -2,10 +2,10 @@
  * Routines for SMB mailslot packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-smb-mailslot.c,v 1.11 2001/03/18 03:34:22 guy Exp $
+ * $Id: packet-smb-mailslot.c,v 1.13 2001/07/12 23:37:48 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-pop.c
@@ -123,9 +123,11 @@ dissect_mailslot_smb(const u_char *pd, int offset, frame_data *fd,
  
   	if (command != NULL && strcmp(command, "BROWSE") == 0) { /* Decode a browse */
 
-    		return dissect_mailslot_browse(pd, offset, fd, parent, tree,
-    			si, max_data, SMB_offset, errcode, dirn, command,
-    			DataOffset, DataCount);
+		tvbuff_t *tvb;
+		packet_info *pinfo = &pi;
+		tvb = tvb_create_from_top(DataOffset);
+
+		return dissect_mailslot_browse(tvb, pinfo, parent);
   	}
 
   	else if (command != NULL && strcmp(command, "LANMAN") == 0) {
@@ -143,10 +145,11 @@ dissect_mailslot_smb(const u_char *pd, int offset, frame_data *fd,
 		  strncmp(command, "NET", strlen("NET")) == 0) ||
 		 (strcmp(command, "TEMP\\NETLOGON") == 0) ||
 		 (strcmp(command, "MSSP") == 0)){
+		tvbuff_t *tvb;
+		packet_info *pinfo = &pi;
+		tvb = tvb_create_from_top(DataOffset);
 
-		return dissect_smb_logon(pd, DataOffset, fd, parent, tree,
-			si, max_data, SMB_offset, errcode, dirn,
-			command, DataOffset, DataCount);
+		return dissect_smb_logon(tvb, pinfo, parent);
 		
 	 }
   	return TRUE;
