@@ -2,12 +2,12 @@
  * Routines for async NSM stat callback dissection
  * 2001 Ronnie Sahlberg <rsahlber@bigpond.net.au>
  *
+ * $Id: packet-stat-notify.c,v 1.5 2001/06/18 02:17:53 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -47,9 +47,9 @@ static int
 dissect_statnotify_mon(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree)
 {
 
-	offset = dissect_rpc_string_tvb(tvb,pinfo,tree,hf_statnotify_name,offset,NULL);
+	offset = dissect_rpc_string(tvb,pinfo,tree,hf_statnotify_name,offset,NULL);
 
-	offset = dissect_rpc_uint32_tvb(tvb,pinfo,tree,hf_statnotify_state,offset);
+	offset = dissect_rpc_uint32(tvb,pinfo,tree,hf_statnotify_state,offset);
 
 	proto_tree_add_item(tree,hf_statnotify_priv,tvb,offset,16,FALSE);
 	offset += 16;
@@ -75,13 +75,13 @@ proto_register_statnotify(void)
 	static hf_register_info hf[] = {
 		{ &hf_statnotify_name, {
 			"Name", "statnotify.name", FT_STRING, BASE_DEC,
-			NULL, 0, "Name of client that changed" }},
+			NULL, 0, "Name of client that changed", HFILL }},
 		{ &hf_statnotify_state, {
 			"State", "statnotify.state", FT_UINT32, BASE_DEC,
-			NULL, 0, "New state of client that changed" }},
+			NULL, 0, "New state of client that changed", HFILL }},
 		{ &hf_statnotify_priv, {
 			"Priv", "statnotify.priv", FT_BYTES, BASE_HEX,
-			NULL, 0, "Client supplied opaque data" }},
+			NULL, 0, "Client supplied opaque data", HFILL }},
 	};
 	
 	static gint *ett[] = {
