@@ -1,12 +1,11 @@
 /* packet-tcp.c
  * Routines for TCP packet disassembly
  *
- * $Id: packet-tcp.c,v 1.102 2001/04/23 17:51:34 guy Exp $
+ * $Id: packet-tcp.c,v 1.105 2001/06/18 02:17:53 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +43,6 @@
 # include "snprintf.h"
 #endif
 
-#include "globals.h"
 #include "resolv.h"
 #include "ipproto.h"
 #include "follow.h"
@@ -118,6 +116,9 @@ typedef struct _e_tcphdr {
   guint16 th_urp;
 } e_tcphdr;
 
+/* Minimum TCP header length. */
+#define	TCPH_MIN_LEN	20
+
 /*
  *	TCP option
  */
@@ -478,6 +479,20 @@ dissect_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   /* Compute the sequence number of next octet after this segment. */
   nxtseq = th.th_seq + seglen;
 
+  if (hlen < TCPH_MIN_LEN) {
+    if (check_col(pinfo->fd, COL_INFO))
+      col_add_fstr(pinfo->fd, COL_INFO, "Bogus TCP header length (%u, must be at least %u)",
+       hlen, TCPH_MIN_LEN);
+    ti = proto_tree_add_item(tree, proto_tcp, tvb, offset, hlen, FALSE);
+    tcp_tree = proto_item_add_subtree(ti, ett_tcp);
+    if (tree) {
+      proto_tree_add_uint_format(tcp_tree, hf_tcp_hdr_len, tvb, offset, 1, hlen,
+       "Header length: %u bytes (bogus, must be at least %u)", hlen,
+       TCPH_MIN_LEN);
+    }
+    return;
+  }
+
   if (check_col(pinfo->fd, COL_INFO)) {
     if (th.th_flags & TH_URG)
       col_append_fstr(pinfo->fd, COL_INFO, "%s > %s [%s] Seq=%u Ack=%u Win=%u Urg=%u Len=%d",
@@ -490,8 +505,12 @@ dissect_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   }
   
   if (tree) {
-    if (tcp_summary_in_tree) {
-	    ti = proto_tree_add_protocol_format(tree, proto_tcp, tvb, offset, hlen, "Transmission Control Protocol, Src Port: %s (%u), Dst Port: %s (%u), Seq: %u, Ack: %u", get_tcp_port(th.th_sport), th.th_sport, get_tcp_port(th.th_dport), th.th_dport, th.th_seq, th.th_ack);
+    if (tcp_summary_in_tree && hlen >= TCPH_MIN_LEN) {
+	    ti = proto_tree_add_protocol_format(tree, proto_tcp, tvb, offset,
+	        hlen,
+		"Transmission Control Protocol, Src Port: %s (%u), Dst Port: %s (%u), Seq: %u, Ack: %u",
+		get_tcp_port(th.th_sport), th.th_sport,
+		get_tcp_port(th.th_dport), th.th_dport, th.th_seq, th.th_ack);
     }
     else {
 	    ti = proto_tree_add_item(tree, proto_tcp, tvb, offset, hlen, FALSE);
@@ -640,83 +659,83 @@ proto_register_tcp(void)
 
 		{ &hf_tcp_srcport,
 		{ "Source Port",		"tcp.srcport", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_dstport,
 		{ "Destination Port",		"tcp.dstport", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_port,
 		{ "Source or Destination Port",	"tcp.port", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_seq,
 		{ "Sequence number",		"tcp.seq", FT_UINT32, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_nxtseq,
 		{ "Next sequence number",	"tcp.nxtseq", FT_UINT32, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_ack,
 		{ "Acknowledgement number",	"tcp.ack", FT_UINT32, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_hdr_len,
 		{ "Header Length",		"tcp.hdr_len", FT_UINT8, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags,
 		{ "Flags",			"tcp.flags", FT_UINT8, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_cwr,
 		{ "Congestion Window Reduced (CWR)",			"tcp.flags.cwr", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_CWR,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_ecn,
 		{ "ECN-Echo",			"tcp.flags.ecn", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_ECN,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_urg,
 		{ "Urgent",			"tcp.flags.urg", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_URG,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_ack,
 		{ "Acknowledgment",		"tcp.flags.ack", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_ACK,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_push,
 		{ "Push",			"tcp.flags.push", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_PUSH,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_reset,
 		{ "Reset",			"tcp.flags.reset", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_RST,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_syn,
 		{ "Syn",			"tcp.flags.syn", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_SYN,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_flags_fin,
 		{ "Fin",			"tcp.flags.fin", FT_BOOLEAN, 8, TFS(&flags_set_truth), TH_FIN,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_window_size,
 		{ "Window size",		"tcp.window_size", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_checksum,
 		{ "Checksum",			"tcp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_checksum_bad,
 		{ "Bad Checksum",		"tcp.checksum_bad", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_tcp_urgent_pointer,
 		{ "Urgent pointer",		"tcp.urgent_pointer", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_tcp,
