@@ -5,10 +5,10 @@
  * Craig Newell <CraigN@cheque.uq.edu.au>
  *	RFC2347 TFTP Option Extension
  *
- * $Id: packet-tftp.c,v 1.24 2001/02/09 06:08:11 guy Exp $
+ * $Id: packet-tftp.c,v 1.26 2001/06/18 02:17:53 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from packet-bootp.c
@@ -110,19 +110,23 @@ dissect_tftp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	 * and ports.
 	 *
 	 * If this packet went to the TFTP port, we check to see if
-	 * there's already a conversation with the source IP address
-	 * and port of this packet, the destination IP address of this
-	 * packet, and any destination UDP port.  If not, we create
-	 * one, with a wildcard UDP port, and give it the TFTP dissector
-	 * as a dissector.
+	 * there's already a conversation with one address/port pair
+	 * matching the source IP address and port of this packet,
+	 * the other address matching the destination IP address of this
+	 * packet, and any destination port.
+	 *
+	 * If not, we create one, with its address 1/port 1 pair being
+	 * the source address/port of this packet, its address 2 being
+	 * the destination address of this packet, and its port 2 being
+	 * wildcarded, and give it the TFTP dissector as a dissector.
 	 */
 	if (pinfo->destport == UDP_PORT_TFTP) {
 	  conversation = find_conversation(&pinfo->src, &pinfo->dst, PT_UDP,
-					   pinfo->srcport, 0, NO_DST_PORT);
+					   pinfo->srcport, 0, NO_PORT_B);
 	  if (conversation == NULL) {
 	    conversation = conversation_new(&pinfo->src, &pinfo->dst, PT_UDP,
 					    pinfo->srcport, 0, NULL,
-					    NO_DST_PORT);
+					    NO_PORT2);
 	    conversation_set_dissector(conversation, dissect_tftp);
 	  }
 	}
@@ -234,37 +238,37 @@ proto_register_tftp(void)
     { &hf_tftp_opcode,
       { "Opcode",	      "tftp.opcode",
 	FT_UINT16, BASE_DEC, VALS(tftp_opcode_vals), 0x0,
-      	"TFTP message type" }},
+      	"TFTP message type", HFILL }},
 
     { &hf_tftp_source_file,
       { "Source File",	      "tftp.source_file",
 	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"TFTP source file name" }},
+      	"TFTP source file name", HFILL }},
 
     { &hf_tftp_destination_file,
       { "DESTINATION File",   "tftp.destination_file",
 	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"TFTP source file name" }},
+      	"TFTP source file name", HFILL }},
 
     { &hf_tftp_transfer_type,
       { "Type",	              "tftp.type",
 	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"TFTP transfer type" }},
+      	"TFTP transfer type", HFILL }},
 
     { &hf_tftp_blocknum,
       { "Block",              "tftp.block",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
-      	"Block number" }},
+      	"Block number", HFILL }},
 
     { &hf_tftp_error_code,
       { "Error code",         "tftp.error.code",
 	FT_UINT16, BASE_DEC, VALS(tftp_error_code_vals), 0x0,
-      	"Error code in case of TFTP error message" }},
+      	"Error code in case of TFTP error message", HFILL }},
 
     { &hf_tftp_error_string,
       { "Error message",      "tftp.error.message",
 	FT_STRINGZ, BASE_DEC, NULL, 0x0,
-      	"Error string in case of TFTP error message" }}
+      	"Error string in case of TFTP error message", HFILL }}
   };
   static gint *ett[] = {
     &ett_tftp,
