@@ -1,7 +1,7 @@
 /* packet-udp.c
  * Routines for UDP packet disassembly
  *
- * $Id: packet-udp.c,v 1.91 2001/04/23 17:56:42 guy Exp $
+ * $Id: packet-udp.c,v 1.94 2001/06/18 02:17:53 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -42,10 +42,11 @@
 #include <string.h>
 
 #include <glib.h>
-#include "globals.h"
+#include "packet.h"
 #include "resolv.h"
 #include "ipproto.h"
 #include "in_cksum.h"
+#include "prefs.h"
 
 #include "packet-udp.h"
 
@@ -62,6 +63,9 @@ static int hf_udp_checksum_bad = -1;
 
 static gint ett_udp = -1;
 
+/* Place UDP summary in proto tree */
+static gboolean udp_summary_in_tree = TRUE;
+
 /* UDP structs and definitions */
 
 typedef struct _e_udphdr {
@@ -138,7 +142,13 @@ dissect_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    get_udp_port(uh_sport), get_udp_port(uh_dport));
     
   if (tree) {
-    ti = proto_tree_add_item(tree, proto_udp, tvb, offset, 8, FALSE);
+    if (udp_summary_in_tree) {
+      ti = proto_tree_add_protocol_format(tree, proto_udp, tvb, offset, 8,
+      "User Datagram Protocol, Src Port: %s (%u), Dst Port: %s (%u)",
+      get_udp_port(uh_sport), uh_sport, get_udp_port(uh_dport), uh_dport);
+    } else {
+      ti = proto_tree_add_item(tree, proto_udp, tvb, offset, 8, FALSE);
+    }
     udp_tree = proto_item_add_subtree(ti, ett_udp);
 
     proto_tree_add_uint_format(udp_tree, hf_udp_srcport, tvb, offset, 2, uh_sport,
@@ -221,30 +231,31 @@ dissect_udp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 void
 proto_register_udp(void)
 {
+	module_t *udp_module;
 	static hf_register_info hf[] = {
 		{ &hf_udp_srcport,
 		{ "Source Port",	"udp.srcport", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_udp_dstport,
 		{ "Destination Port",	"udp.dstport", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_udp_port,
 		{ "Source or Destination Port",	"udp.port", FT_UINT16, BASE_DEC,  NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_udp_length,
 		{ "Length",		"udp.length", FT_UINT16, BASE_DEC, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_udp_checksum_bad,
 		{ "Bad Checksum",	"udp.checksum_bad", FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 
 		{ &hf_udp_checksum,
 		{ "Checksum",		"udp.checksum", FT_UINT16, BASE_HEX, NULL, 0x0,
-			"" }},
+			"", HFILL }},
 	};
 	static gint *ett[] = {
 		&ett_udp,
@@ -259,6 +270,13 @@ proto_register_udp(void)
 	udp_dissector_table = register_dissector_table("udp.port");
 	register_heur_dissector_list("udp", &heur_subdissector_list);
 	register_conv_dissector_list("udp", &conv_subdissector_list);
+	
+	/* Register configuration preferences */
+	udp_module = prefs_register_protocol(proto_udp, NULL);
+	prefs_register_bool_preference(udp_module, "udp_summary_in_tree",
+	"Show UDP summary in protocol treee", 
+	"Whether the UDP summary line should be shown in the protocol tree",
+	&udp_summary_in_tree);
 }
 
 void
