@@ -1,11 +1,12 @@
 /* packet-wccp.h
+ * Declarations for Cisco Web Cache Coordination Protocol
  *
- * $Id: packet-wccp.h,v 1.1 2000/02/15 21:03:27 gram Exp $
+ * $Id: packet-wccp.h,v 1.3 2000/11/29 06:17:34 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
  * Copyright 1998 Gerald Combs
- *
+ * 
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,6 +22,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-
-
-void dissect_wccp(const u_char *, int, frame_data *, proto_tree *);
+ 
+/*
+ * Maps service ID values to service names.
+ */
+extern const value_string service_id_vals[];
