@@ -2,7 +2,7 @@
  * Routines for Wellfleet Compression frame disassembly
  * Copyright 2001, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-wcp.c,v 1.9 2001/04/10 19:10:09 guy Exp $
+ * $Id: packet-wcp.c,v 1.10 2001/06/18 02:17:54 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -648,79 +648,79 @@ proto_register_wcp(void)
     static hf_register_info hf[] = {
 	{ &hf_wcp_cmd,
 	  { "Command", "wcp.cmd", FT_UINT8, BASE_HEX, VALS(cmd_string), WCP_CMD, 
-	  	"Compression Command" }},
+	  	"Compression Command", HFILL }},
 	{ &hf_wcp_ext_cmd,
 	  { "Extended Command", "wcp.ext_cmd", FT_UINT8, BASE_HEX, VALS(ext_cmd_string), WCP_EXT_CMD, 
-	  	"Extended Compression Command" }},
+	  	"Extended Compression Command", HFILL }},
 	{ &hf_wcp_seq,
 	  { "SEQ", "wcp.seq", FT_UINT16, BASE_HEX, NULL, WCP_SEQ, 
-	  	"Sequence Number" }},
+	  	"Sequence Number", HFILL }},
 	{ &hf_wcp_chksum,
 	  { "Checksum", "wcp.checksum", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Packet Checksum" }},
+	  	"Packet Checksum", HFILL }},
 	{ &hf_wcp_tid,
 	  { "TID", "wcp.tid", FT_UINT16, BASE_DEC, NULL, 0,
-	  	"TID" }},
+	  	"TID", HFILL }},
 	{ &hf_wcp_rev,
 	  { "Revision", "wcp.rev", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Revision" }},
+	  	"Revision", HFILL }},
 	{ &hf_wcp_init,
 	  { "Initiator", "wcp.init", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Initiator" }},
+	  	"Initiator", HFILL }},
 	{ &hf_wcp_seq_size,
 	  { "Seq Size", "wcp.seq_size", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Sequence Size"}},
+	  	"Sequence Size", HFILL }},
 	{ &hf_wcp_alg_cnt,
 	  { "Alg Count", "wcp.alg_cnt", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm Count"}},
+	  	"Algorithm Count", HFILL }},
 	{ &hf_wcp_alg_a,
 	  { "Alg 1", "wcp.alg1", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm #1"}},
+	  	"Algorithm #1", HFILL }},
 	{ &hf_wcp_alg_b,
 	  { "Alg 2", "wcp.alg2", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm #2"}},
+	  	"Algorithm #2", HFILL }},
 	{ &hf_wcp_alg_c,
 	  { "Alg 3", "wcp.alg3", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm #3"}},
+	  	"Algorithm #3", HFILL }},
 	{ &hf_wcp_alg_d,
 	  { "Alg 4", "wcp.alg4", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm #4"}},
+	  	"Algorithm #4", HFILL }},
 	{ &hf_wcp_alg,
 	  { "Alg", "wcp.alg", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Algorithm"}},
+	  	"Algorithm", HFILL }},
 	{ &hf_wcp_rexmit,
 	  { "Rexmit", "wcp.rexmit", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Retransmit"}},
+	  	"Retransmit", HFILL }},
 	{ &hf_wcp_hist_size,
 	  { "History", "wcp.hist", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"History Size"}},
+	  	"History Size", HFILL }},
 	{ &hf_wcp_ppc,
 	  { "PerPackComp", "wcp.ppc", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"Per Packet Compression"}},
+	  	"Per Packet Compression", HFILL }},
 	{ &hf_wcp_pib,
 	  { "PIB", "wcp.pib", FT_UINT8, BASE_DEC, NULL, 0,
-	  	"PIB"}},
+	  	"PIB", HFILL }},
 	{ &hf_wcp_comp_bits,
 	  { "Compress Flag", "wcp.flag", FT_UINT8, BASE_HEX, NULL, 0,
-	  	"Compressed byte flag"}},
+	  	"Compressed byte flag", HFILL }},
 	{ &hf_wcp_comp_marker,
 	  { "Compress Marker", "wcp.mark", FT_UINT8, BASE_BIN, NULL, 0,
-	  	"Compressed marker"}},
+	  	"Compressed marker", HFILL }},
 	{ &hf_wcp_offset,
 	  { "Source offset", "wcp.off", FT_UINT16, BASE_HEX, NULL, WCP_OFFSET_MASK,
-	  	"Data source offset"}},
+	  	"Data source offset", HFILL }},
 	{ &hf_wcp_short_len,
 	  { "Compress Length", "wcp.short_len", FT_UINT8, BASE_HEX, NULL, 0xf0,
-	  	"Compressed length"}},
+	  	"Compressed length", HFILL }},
 	{ &hf_wcp_long_len,
 	  { "Compress Length", "wcp.long_len", FT_UINT8, BASE_HEX, NULL, 0,
-	  	"Compressed length"}},
+	  	"Compressed length", HFILL }},
 	{ &hf_wcp_long_run,
 	  { "Long Compression", "wcp.long_comp", FT_UINT16, BASE_HEX, NULL, 0,
-	  	"Long Compression type"}},
+	  	"Long Compression type", HFILL }},
 	{ &hf_wcp_short_run,
 	  { "Short Compression", "wcp.short_comp", FT_UINT8, BASE_HEX, NULL, 0,
-	  	"Short Compression type"}},
+	  	"Short Compression type", HFILL }},
 
    };
 
