@@ -2,10 +2,10 @@
  *
  * Routines to dissect WSP component of WAP traffic.
  * 
- * $Id: packet-wsp.c,v 1.20 2001/04/23 04:29:54 guy Exp $
+ * $Id: packet-wsp.c,v 1.23 2001/07/03 09:53:21 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Didier Jorand
  *
  * WAP dissector based on original work by Ben Fowler
@@ -66,7 +66,15 @@ static int hf_wsp_header_pdu_type				= HF_EMPTY;
 static int hf_wsp_version_major					= HF_EMPTY;
 static int hf_wsp_version_minor					= HF_EMPTY;
 static int hf_wsp_capability_length				= HF_EMPTY;
-static int hf_wsp_capabilities_section			= HF_EMPTY;
+static int hf_wsp_capabilities_section				= HF_EMPTY;
+static int hf_wsp_capabilities_client_SDU			= HF_EMPTY;
+static int hf_wsp_capabilities_server_SDU			= HF_EMPTY;
+static int hf_wsp_capabilities_protocol_opt			= HF_EMPTY;
+static int hf_wsp_capabilities_method_MOR			= HF_EMPTY;
+static int hf_wsp_capabilities_push_MOR				= HF_EMPTY;
+static int hf_wsp_capabilities_extended_methods			= HF_EMPTY;
+static int hf_wsp_capabilities_header_code_pages		= HF_EMPTY;
+static int hf_wsp_capabilities_aliases				= HF_EMPTY;
 static int hf_wsp_header_uri_len				= HF_EMPTY;
 static int hf_wsp_header_uri					= HF_EMPTY;
 static int hf_wsp_server_session_id				= HF_EMPTY;
@@ -79,6 +87,7 @@ static int hf_wsp_parameter_well_known_charset	= HF_EMPTY;
 static int hf_wsp_reply_data					= HF_EMPTY;
 static int hf_wsp_post_data						= HF_EMPTY;
 
+static int hf_wsp_header_shift_code					= HF_EMPTY;
 static int hf_wsp_header_accept					= HF_EMPTY;
 static int hf_wsp_header_accept_str				= HF_EMPTY;
 static int hf_wsp_header_accept_charset			= HF_EMPTY;
@@ -419,10 +428,13 @@ static guint add_parameter (proto_tree *, tvbuff_t *, guint);
 static guint add_parameter_charset (proto_tree *, tvbuff_t *, guint, guint);
 static void add_post_data (proto_tree *, tvbuff_t *, guint);
 static void add_post_variable (proto_tree *, tvbuff_t *, guint, guint, guint, guint);
+static gint get_long_integer (tvbuff_t *, guint *, guint , guint *);
+static void add_capabilities (proto_tree *tree, tvbuff_t *tvb);
+static guint get_uintvar (tvbuff_t *, guint, guint);
 
 /* Code to actually dissect the packets */
 static void
-dissect_wsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+dissect_wsp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	frame_data *fdata = pinfo->fd;
 	int offset = 0;
@@ -446,26 +458,11 @@ dissect_wsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	proto_item *ti;
 	proto_tree *wsp_tree;
 /*	proto_tree *wsp_header_fixed; */
-	proto_tree *wsp_capabilities;
 	
 /* This field shows up as the "Info" column in the display; you should make
    it, if possible, summarize what's in the packet, so that a user looking
    at the list of packets can tell what type of packet it is. */
     
-	/* Display protocol type depending on the port */
-	if (check_col(fdata, COL_PROTOCOL)) 
-	{
-		switch ( pinfo->match_port )
-		{
-			case UDP_PORT_WSP:
-				col_set_str(fdata, COL_PROTOCOL, "WSP" );
-				break;
-			case UDP_PORT_WTLS_WSP:
-				col_set_str(fdata, COL_PROTOCOL, "WTLS+WSP" );
-				break;
-		}
-	}
-
 	/* Clear the Info column before we fetch anything from the packet */
 	if (check_col(fdata, COL_INFO))
 	{
@@ -539,8 +536,8 @@ dissect_wsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					ti = proto_tree_add_uint (wsp_tree, hf_wsp_header_length,tvb,headerStart,count,headerLength);
 					if (capabilityLength > 0)
 					{
-						ti = proto_tree_add_item (wsp_tree, hf_wsp_capabilities_section,tvb,offset,capabilityLength,bo_little_endian);
-						wsp_capabilities = proto_item_add_subtree( ti, ett_capabilities );
+						tmp_tvb = tvb_new_subset (tvb, offset, capabilityLength, capabilityLength);
+						add_capabilities (wsp_tree, tmp_tvb);
 						offset += capabilityLength;
 					}
 
@@ -571,8 +568,8 @@ dissect_wsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					ti = proto_tree_add_uint (wsp_tree, hf_wsp_header_length,tvb,headerStart,count,headerLength);
 					if (capabilityLength > 0)
 					{
-						ti = proto_tree_add_item (wsp_tree, hf_wsp_capabilities_section,tvb,offset,capabilityLength,bo_little_endian);
-						wsp_capabilities = proto_item_add_subtree( ti, ett_capabilities );
+						tmp_tvb = tvb_new_subset (tvb, offset, capabilityLength, capabilityLength);
+						add_capabilities (wsp_tree, tmp_tvb);
 						offset += capabilityLength;
 					}
 
@@ -664,6 +661,30 @@ dissect_wsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	}
 }
 
+/*
+ * Called directly from UDP.
+ * Put "WSP" into the "Protocol" column.
+ */
+static void
+dissect_wsp_fromudp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	if (check_col(pinfo->fd, COL_PROTOCOL))
+		col_set_str(pinfo->fd, COL_PROTOCOL, "WSP" );
+
+	dissect_wsp_common(tvb, pinfo, tree);
+}
+
+/*
+ * Called from a higher-level WAP dissector.
+ * Leave the "Protocol" column alone - the dissector calling us should
+ * have set it.
+ */
+static void
+dissect_wsp_fromwap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	dissect_wsp_common(tvb, pinfo, tree);
+}
+
 static void
 add_uri (proto_tree *tree, tvbuff_t *tvb, guint URILenOffset, guint URIOffset)
 {
@@ -706,6 +727,7 @@ add_headers (proto_tree *tree, tvbuff_t *tvb)
 	guint count = 0;
 	guint valueStart = 0;
 	guint valueEnd = 0;
+	guint pageCode = 1;
 
 #ifdef DEBUG
 	fprintf (stderr, "dissect_wsp: Offset is %d, size is %d\n", offset, headersLen);
@@ -734,13 +756,17 @@ add_headers (proto_tree *tree, tvbuff_t *tvb)
 
 		if (peek < 32)		/* Short-cut shift delimeter */
 		{
-			fprintf (stderr, "dissect_wsp: header: short-cut shift %d (0x%02X)\n", peek, peek);
-			offset++;
+			pageCode = peek;
+			proto_tree_add_uint (wsp_headers, hf_wsp_header_shift_code, tvb , offset, 1, peek);
+			offset+=1;
+			continue;
 		}
 		else if (peek == 0x7F)	/* Shift delimeter */
 		{
-			fprintf (stderr, "dissect_wsp: header: shift delimeter %d (0x%02X)\n", peek, peek);
-			offset++;
+			pageCode = tvb_get_guint8(tvb,offset+1);
+			proto_tree_add_uint (wsp_headers, hf_wsp_header_shift_code, tvb , offset, 2, pageCode);
+			offset+=2;
+			continue;
 		}
 		else if (peek < 127)
 		{
@@ -800,10 +826,18 @@ add_headers (proto_tree *tree, tvbuff_t *tvb)
 		fprintf (stderr, "dissect_wsp: Creating value buffer from offset %d, size=%d\n", headerStart, (offset-headerStart));
 #endif
 
-		header_buff = tvb_new_subset (tvb, headerStart, (offset-headerStart), (offset-headerStart));
-		value_buff = tvb_new_subset (tvb, valueStart, (valueEnd-valueStart), (valueEnd-valueStart));
+		if (pageCode == 1)
+		{
+			header_buff = tvb_new_subset (tvb, headerStart, (offset-headerStart), (offset-headerStart));
+			value_buff = tvb_new_subset (tvb, valueStart, (valueEnd-valueStart), (valueEnd-valueStart));
+			add_header (wsp_headers, header_buff, value_buff);
+		}
+		else 
+		{
+			proto_tree_add_text (wsp_headers, tvb , headerStart, valueEnd-headerStart,
+				       "Unsupported Header (0x%02X)", (tvb_get_guint8 (tvb, headerStart) & 0x7F));
+		}
 
-		add_header (wsp_headers, header_buff, value_buff);
 	}
 }
 
@@ -818,9 +852,11 @@ add_header (proto_tree *tree, tvbuff_t *header_buff, tvbuff_t *value_buff)
 	guint valueLen = tvb_reported_length (value_buff);
 	guint peek = 0;
 	struct timeval timeValue;
+	guint offsetNew = 0;
 	guint value = 0;
 	guint valueLength = 0;
 	char valString[100];
+	char valNum1[100];
 	char *valMatch = NULL;
 	double q_value = 1.0;
 
@@ -847,14 +883,84 @@ add_header (proto_tree *tree, tvbuff_t *header_buff, tvbuff_t *value_buff)
 		switch (headerType)
 		{
 			case 0x00:		/* Accept */
-				if (peek & 0x80)
+				if (peek & 0x80) /* Constrained-media (short-integer) */
 				{
 					proto_tree_add_uint (tree, hf_wsp_header_accept, header_buff, offset, headerLen, (peek & 0x7F));
+					break;
 				}
-				else
+				if (peek >= 32) /* Constrained-media (text) */
 				{
-					proto_tree_add_string (tree, hf_wsp_header_accept_str,header_buff,offset,headerLen,tvb_get_ptr (value_buff, 0, valueLen));
+					proto_tree_add_string (tree, hf_wsp_header_accept_str,header_buff,offset,headerLen,
+								tvb_get_ptr (value_buff, 0, valueLen));
+					break;
 				}
+				/* general form (short length) */
+				offsetNew = offset+1;
+				valueLength = tvb_get_guint8 (value_buff, offsetNew);
+				if (valueLength & 0x80) /* short integer */
+				{
+					valMatch = match_strval(valueLength & 0x7f, vals_content_types);
+					offsetNew++;
+				}
+				else if (valueLength < 32) /* long integer */
+				{
+					if (get_long_integer(value_buff,&offsetNew,offset+peek,&value) < 0)
+					{
+						fprintf (stderr, "dissect_wsp: accept get_long_interger invalid\n");
+					}
+					valMatch = match_strval(value, vals_content_types);
+					offsetNew+=valueLength;
+					if (valMatch == NULL)
+					{
+						snprintf(valNum1,100,"Unsupported type (%d)",value);
+						valMatch = valNum1;
+					}
+				}
+				else /* text */
+				{
+					/* TODO */
+				}
+				if ((offsetNew - offset) < peek) /* Parameter */
+				{
+					value = tvb_get_guint8 (value_buff, offsetNew);
+					offsetNew++;
+					if (value & 0x80) /* well Know type */
+					{
+						switch (value & 0x7f)
+						{
+							case 0x03 :
+								valueLength = tvb_get_guint8 (value_buff, offsetNew);
+								if (valueLength & 0x80) /* short integer */
+								{
+									value = valueLength & 0x7F;
+									offsetNew++;
+								}
+								else if (valueLength < 32) /* Long integer */
+								{
+									if (get_long_integer(value_buff,&offsetNew,offset+peek,&value) < 0)
+									{
+										fprintf (stderr, "dissect_wsp: accept get_long_interger parameter invalid\n");
+									}
+								}
+								snprintf (valString, 100, "%s type %d", valMatch,value);
+								break;
+							case 0x00 :
+							case 0x01 :
+							case 0x02 :
+							case 0x04 :
+							default :
+								break;
+						}
+					}
+				}
+				else  /* no parameter */
+				{
+					snprintf (valString, 100, "%s", valMatch);
+				}
+				/* Add string to tree */
+				proto_tree_add_string (tree, hf_wsp_header_accept_str,
+						       header_buff, 0, headerLen, valString);
+					
 				break;
 
 			case 0x01:		/* Accept-Charset */
@@ -947,10 +1053,10 @@ add_header (proto_tree *tree, tvbuff_t *header_buff, tvbuff_t *value_buff)
 							snprintf (valString, 100, "%s; Q=%5.3f", valMatch,q_value);
 						}
 					}
+                                        /* Add string to tree */
+                                        proto_tree_add_string (tree, hf_wsp_header_accept_charset_str,
+				                               header_buff, 0, headerLen, valString);
 
-					/* Add string to tree */
-					proto_tree_add_string (tree, hf_wsp_header_accept_charset_str,
-						header_buff, 0, headerLen, valString);
 				}
 				else						/* Constrained-charset */
 				{
@@ -1237,6 +1343,161 @@ add_header (proto_tree *tree, tvbuff_t *header_buff, tvbuff_t *value_buff)
 
 }
 
+static void
+add_capabilities (proto_tree *tree, tvbuff_t *tvb)
+{
+	proto_item *ti;
+	proto_tree *wsp_capabilities;
+	guint offset = 0;
+	guint offsetStr = 0;
+	guint capabilitiesLen = tvb_reported_length (tvb);
+	guint8 capabilitiesStart = 0;
+	guint peek = 0;
+	guint length = 0;
+	guint value = 0;
+	guint i;
+	char valString[200];
+
+#ifdef DEBUG
+	fprintf (stderr, "dissect_wsp: Offset is %d, size is %d\n", offset, capabilitiesLen);
+#endif
+
+	/* End of buffer */
+	if (capabilitiesLen <= 0)
+	{
+		fprintf (stderr, "dissect_wsp: Capabilities = 0\n");
+		return;
+	}
+
+#ifdef DEBUG
+	fprintf (stderr, "dissect_wsp: capabilities to process\n");
+#endif
+
+	ti = proto_tree_add_item (tree, hf_wsp_capabilities_section,tvb,offset,capabilitiesLen,bo_little_endian);
+	wsp_capabilities = proto_item_add_subtree( ti, ett_capabilities );
+
+	/* Parse Headers */
+
+	while (offset < capabilitiesLen)
+	{
+		/* Loop round each header */
+		capabilitiesStart = offset;
+		length = tvb_get_guint8 (tvb, capabilitiesStart);
+
+		if (length >= 127)		/* length */
+		{
+#ifdef DEBUG
+			fprintf (stderr, "dissect_wsp: capabilities length invalid %d\n",length);
+#endif
+			offset+=length;
+			continue;
+		}
+		offset++;
+		peek = tvb_get_guint8 (tvb, offset);
+		offset++;
+		switch (peek & 0x7f)
+		{
+			case 0x00 : /* Client-SDU-Size */
+				value = get_uintvar (tvb, offset, length+capabilitiesStart+1);
+				proto_tree_add_uint (wsp_capabilities, hf_wsp_capabilities_client_SDU, tvb, capabilitiesStart, length+1, value);
+				break;
+			case 0x01 : /* Server-SDU-Size */
+				value = get_uintvar (tvb, offset, length+capabilitiesStart+1);
+				proto_tree_add_uint (wsp_capabilities, hf_wsp_capabilities_server_SDU, tvb, capabilitiesStart, length+1, value);
+				break;
+			case 0x02 : /* Protocol Options */ 
+				value = get_uintvar (tvb, offset, length+capabilitiesStart+1);
+				i = 0;
+				valString[0]=0;
+				if (value & 0x80)
+				{
+					i += snprintf(valString+i,200-1,"%s","(Confirmed push facility) ");
+				}
+				if (value & 0x40)
+				{
+					i += snprintf(valString+i,200-1,"%s","(Push facility) ");
+				}
+				if (value & 0x20)
+				{
+					i += snprintf(valString+i,200-1,"%s","(Session resume facility) ");
+				}
+				if (value & 0x10)
+				{
+					i += snprintf(valString+i,200-1,"%s","(Acknowledgement headers) ");
+				}
+				proto_tree_add_string(wsp_capabilities, hf_wsp_capabilities_protocol_opt, tvb, capabilitiesStart, length+1, valString);
+				break;
+			case 0x03 : /* Method-MOR */ 
+				value = tvb_get_guint8(tvb, offset);
+				proto_tree_add_uint (wsp_capabilities, hf_wsp_capabilities_method_MOR, tvb, capabilitiesStart, length+1, value);
+				break;
+			case 0x04 : /* Push-MOR */ 
+				value = tvb_get_guint8(tvb, offset);
+				proto_tree_add_uint (wsp_capabilities, hf_wsp_capabilities_push_MOR, tvb, capabilitiesStart, length+1, value);
+				break;
+				break;
+			case 0x05 : /* Extended Methods */ 
+				offsetStr = offset;
+				offset++;
+				i = 0;
+				while ((offsetStr-capabilitiesStart) <= length)
+				{
+					value = tvb_get_guint8(tvb, offsetStr);
+					i += snprintf(valString+i,200-i,"(%d - ",value);
+					offsetStr++;
+					for (;(valString[i] = tvb_get_guint8(tvb, offsetStr));i++,offsetStr++);
+					offsetStr++;
+					valString[i++] = ')';
+					valString[i++] = ' ';
+				}
+				valString[i]=0;
+				proto_tree_add_string(wsp_capabilities, hf_wsp_capabilities_extended_methods, tvb, capabilitiesStart, length+1, valString);
+				break;
+			case 0x06 : /* Header Code Pages */ 
+				offsetStr = offset;
+				offset++;
+				i = 0;
+				while ((offsetStr-capabilitiesStart) <= length)
+				{
+					value = tvb_get_guint8(tvb, offsetStr);
+					i += snprintf(valString+i,200-i,"(%d - ",value);
+					offsetStr++;
+					for (;(valString[i] = tvb_get_guint8(tvb, offsetStr));i++,offsetStr++);
+					offsetStr++;
+					valString[i++] = ')';
+					valString[i++] = ' ';
+				}
+				valString[i]=0;
+				proto_tree_add_string(wsp_capabilities, hf_wsp_capabilities_header_code_pages, tvb, capabilitiesStart, length+1, valString);
+				break;
+			case 0x07 : /* Aliases */
+				break;
+			default:
+				proto_tree_add_text (wsp_capabilities, tvb , capabilitiesStart, length+1,
+				       "Unsupported Header (0x%02X)", peek & 0x7F);
+				break;
+		}
+		offset=capabilitiesStart+length+1;
+	}
+}
+
+static guint
+get_uintvar (tvbuff_t *tvb, guint offset, guint offsetEnd)
+{
+	guint value = 0;
+	guint octet;
+
+	do
+	{
+       		octet = tvb_get_guint8 (tvb, offset);
+		offset++;
+		value <<= 7;
+		value += octet & 0x7f;
+	}
+	while ((offsetEnd > offset) && (octet & 0x80));
+	return value;
+}
+
 static guint
 get_value_length (tvbuff_t *tvb, guint offset, guint *nextOffset)
 {
@@ -1503,112 +1764,120 @@ proto_register_wsp(void)
 			{ 	"Transmission ID",           
 				"wsp.TID",
 				 FT_UINT8, BASE_HEX, NULL, 0x00,
-				"Transmission ID" 
+				"Transmission ID", HFILL
 			}
 		},
 		{ &hf_wsp_header_pdu_type,
 			{ 	"PDU Type",           
 				"wsp.pdu_type",
 				 FT_UINT8, BASE_HEX, VALS( vals_pdu_type ), 0x00,
-				"PDU Type" 
+				"PDU Type", HFILL
 			}
 		},
 		{ &hf_wsp_version_major,
 			{ 	"Version (Major)",           
 				"wsp.version.major",
 				 FT_UINT8, BASE_DEC, NULL, 0xF0,
-				"Version (Major)" 
+				"Version (Major)", HFILL
 			}
 		},
 		{ &hf_wsp_version_minor,
 			{ 	"Version (Minor)",           
 				"wsp.version.minor",
 				 FT_UINT8, BASE_DEC, NULL, 0x0F,
-				"Version (Minor)" 
+				"Version (Minor)", HFILL
 			}
 		},
 		{ &hf_wsp_capability_length,
 			{ 	"Capability Length",           
 				"wsp.capability.length",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"Capability Length" 
+				"Capability Length", HFILL
 			}
 		},
 		{ &hf_wsp_header_length,
 			{ 	"Headers Length",           
 				"wsp.headers_length",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"Headers Length" 
+				"Headers Length", HFILL
 			}
 		},
 		{ &hf_wsp_capabilities_section,
 			{ 	"Capabilities",           
 				"wsp.capabilities",
 				 FT_NONE, BASE_DEC, NULL, 0x00,
-				"Capabilities" 
+				"Capabilities", HFILL
 			}
 		},
 		{ &hf_wsp_headers_section,
 			{ 	"Headers",           
 				"wsp.headers",
 				 FT_NONE, BASE_DEC, NULL, 0x00,
-				"Headers" 
+				"Headers", HFILL
 			}
 		},
 		{ &hf_wsp_header,
 			{ 	"Header",           
 				"wsp.headers.header",
 				 FT_NONE, BASE_DEC, NULL, 0x00,
-				"Header" 
+				"Header", HFILL
 			}
 		},
 		{ &hf_wsp_header_uri_len,
 			{ 	"URI Length",           
 				"wsp.uri_length",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"URI Length" 
+				"URI Length", HFILL
 			}
 		},
 		{ &hf_wsp_header_uri,
 			{ 	"URI",           
 				"wsp.uri",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"URI" 
+				"URI", HFILL
 			}
 		},
 		{ &hf_wsp_server_session_id,
 			{ 	"Server Session ID",           
 				"wsp.server.session_id",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"Server Session ID" 
+				"Server Session ID", HFILL
 			}
 		},
 		{ &hf_wsp_header_status,
 			{ 	"Status",           
 				"wsp.reply.status",
 				 FT_UINT8, BASE_HEX, VALS( vals_status ), 0x00,
-				"Status" 
+				"Status", HFILL
 			}
 		},
 		{ &hf_wsp_content_type,
 			{ 	"Content Type",           
 				"wsp.content_type.type",
 				 FT_UINT8, BASE_HEX, VALS ( vals_content_types ), 0x00,
-				"Content Type" 
+				"Content Type", HFILL
 			}
 		},
 		{ &hf_wsp_parameter_well_known_charset,
 			{ 	"Charset",           
 				"wsp.content_type.parameter.charset",
 				 FT_UINT16, BASE_HEX, VALS ( vals_character_sets ), 0x00,
-				"Charset" 
+				"Charset", HFILL
 			}
 		},
 		{ &hf_wsp_reply_data,
 			{ 	"Data",           
 				"wsp.reply.data",
 				 FT_NONE, BASE_NONE, NULL, 0x00,
-				"Data" 
+				"Data", HFILL
+			}
+		},
+		{ &hf_wsp_header_shift_code,
+			{ 	"Shift code",           
+				"wsp.header.shift",
+				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
+				 FT_UINT8, BASE_HEX, NULL, 0x00,
+				"Shift code", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept,
@@ -1616,77 +1885,77 @@ proto_register_wsp(void)
 				"wsp.header.accept",
 				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
 				 FT_UINT8, BASE_HEX, VALS ( vals_content_types ), 0x00,
-				"Accept" 
+				"Accept", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_str,
 			{ 	"Accept",           
 				"wsp.header.accept.string",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Accept" 
+				"Accept", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_charset,
 			{ 	"Accept-Charset",           
 				"wsp.header.accept_charset",
 				 FT_UINT16, BASE_HEX, VALS ( vals_character_sets ), 0x00,
-				"Accept-Charset" 
+				"Accept-Charset", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_charset_str,
 			{ 	"Accept-Charset",           
 				"wsp.header.accept_charset.string",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Accept-Charset" 
+				"Accept-Charset", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_language,
 			{ 	"Accept-Language",           
 				"wsp.header.accept_language",
 				 FT_UINT8, BASE_HEX, VALS ( vals_languages ), 0x00,
-				"Accept-Language" 
+				"Accept-Language", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_language_str,
 			{ 	"Accept-Language",           
 				"wsp.header.accept_language.string",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Accept-Language" 
+				"Accept-Language", HFILL
 			}
 		},
 		{ &hf_wsp_header_accept_ranges,
 			{ 	"Accept-Ranges",           
 				"wsp.header.accept_ranges",
 				 FT_UINT8, BASE_HEX, VALS ( vals_accept_ranges ), 0x00,
-				"Accept-Ranges" 
+				"Accept-Ranges", HFILL
 			}
 		},
 		{ &hf_wsp_header_age,
 			{ 	"Age",           
 				"wsp.header.age",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"Age" 
+				"Age", HFILL
 			}
 		},
 		{ &hf_wsp_header_cache_control,
 			{ 	"Cache-Control",           
 				"wsp.header.cache_control",
 				 FT_UINT8, BASE_HEX, VALS ( vals_cache_control ), 0x00,
-				"Cache-Control" 
+				"Cache-Control", HFILL
 			}
 		},
 		{ &hf_wsp_header_content_length,
 			{ 	"Content-Length",           
 				"wsp.header.content_length",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
-				"Content-Length" 
+				"Content-Length", HFILL
 			}
 		},
 		{ &hf_wsp_header_date,
 			{ 	"Date",           
 				"wsp.header.date",
 				 FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-				"Date" 
+				"Date", HFILL
 			}
 		},
 		{ &hf_wsp_header_etag,
@@ -1694,35 +1963,35 @@ proto_register_wsp(void)
 				"wsp.header.etag",
 				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Etag" 
+				"Etag", HFILL
 			}
 		},
 		{ &hf_wsp_header_expires,
 			{ 	"Expires",           
 				"wsp.header.expires",
 				 FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-				"Expires" 
+				"Expires", HFILL
 			}
 		},
 		{ &hf_wsp_header_last_modified,
 			{ 	"Last-Modified",           
 				"wsp.header.last_modified",
 				 FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-				"Last-Modified" 
+				"Last-Modified", HFILL
 			}
 		},
 		{ &hf_wsp_header_location,
 			{ 	"Location",           
 				"wsp.header.location",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Location" 
+				"Location", HFILL
 			}
 		},
 		{ &hf_wsp_header_if_modified_since,
 			{ 	"If-Modified-Since",           
 				"wsp.header.if_modified_since",
 				 FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-				"If-Modified-Since" 
+				"If-Modified-Since", HFILL
 			}
 		},
 		{ &hf_wsp_header_server,
@@ -1730,7 +1999,7 @@ proto_register_wsp(void)
 				"wsp.header.server",
 				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Server" 
+				"Server", HFILL
 			}
 		},
 		{ &hf_wsp_header_transfer_encoding,
@@ -1738,14 +2007,14 @@ proto_register_wsp(void)
 				"wsp.header.transfer_enc",
 				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
 				 FT_UINT8, BASE_HEX, VALS ( vals_transfer_encoding ), 0x00,
-				"Transfer Encoding" 
+				"Transfer Encoding", HFILL
 			}
 		},
 		{ &hf_wsp_header_transfer_encoding_str,
 			{ 	"Transfer Encoding",           
 				"wsp.header.transfer_enc_str",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Transfer Encoding" 
+				"Transfer Encoding", HFILL
 			}
 		},
 		{ &hf_wsp_header_user_agent,
@@ -1753,42 +2022,98 @@ proto_register_wsp(void)
 				"wsp.header.user_agent",
 				 /*FT_NONE, BASE_DEC, NULL, 0x00,*/
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"User-Agent" 
+				"User-Agent", HFILL
 			}
 		},
 		{ &hf_wsp_header_via,
 			{ 	"Via",           
 				"wsp.header.via",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Via" 
+				"Via", HFILL
 			}
 		},
 		{ &hf_wsp_header_application_header,
 			{ 	"Application Header",           
 				"wsp.header.application_header",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Application Header" 
+				"Application Header", HFILL
 			}
 		},
 		{ &hf_wsp_header_application_value,
 			{ 	"Application Header Value",           
 				"wsp.header.application_header.value",
 				 FT_STRING, BASE_NONE, NULL, 0x00,
-				"Application Header Value" 
+				"Application Header Value", HFILL
 			}
 		},
 		{ &hf_wsp_header_x_wap_tod,
 			{ 	"X-WAP.TOD",           
 				"wsp.header.x_wap_tod",
 				 FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-				"X-WAP.TOD" 
+				"X-WAP.TOD", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_client_SDU,
+			{	"Client SDU",
+				"wsp.capabilities.client_SDU",
+				 FT_UINT8, BASE_DEC, NULL, 0x00,
+				"Client SDU", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_server_SDU,
+			{	"Server SDU",
+				"wsp.capabilities.server_SDU",
+				 FT_UINT8, BASE_DEC, NULL, 0x00,
+				"Server SDU", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_protocol_opt,
+			{	"Protocol Options",
+				"wsp.capabilities.protocol_opt",
+				 FT_STRING, BASE_HEX, NULL, 0x00,
+				"Protocol Options", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_method_MOR,
+			{	"Method MOR",
+				"wsp.capabilities.method_mor",
+				 FT_UINT8, BASE_DEC, NULL, 0x00,
+				"Method MOR", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_push_MOR,
+			{	"Push MOR",
+				"wsp.capabilities.push_mor",
+				 FT_UINT8, BASE_DEC, NULL, 0x00,
+				"Push MOR", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_extended_methods,
+			{	"Extended Methods",
+				"wsp.capabilities.extend_methods",
+				 FT_STRING, BASE_HEX, NULL, 0x00,
+				"Extended Methods", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_header_code_pages,
+			{	"Header Code Pages",
+				"wsp.capabilities.code_pages",
+				 FT_STRING, BASE_HEX, NULL, 0x00,
+				"Header Code Pages", HFILL
+			}
+		},
+		{ &hf_wsp_capabilities_aliases,
+			{	"Aliases",
+				"wsp.capabilities.aliases",
+				 FT_UINT8, BASE_HEX, NULL, 0x00,
+				"Aliases", HFILL
 			}
 		},
 		{ &hf_wsp_post_data,
 			{ 	"Post Data",           
 				"wsp.post.data",
 				 FT_NONE, BASE_NONE, NULL, 0x00,
-				"Post Data" 
+				"Post Data", HFILL
 			}
 		},
 	};
@@ -1806,7 +2131,7 @@ proto_register_wsp(void)
 	proto_wsp = proto_register_protocol(
 		"Wireless Session Protocol",   	/* protocol name for use by ethereal */ 
 		"WSP",                          /* short version of name */
-		"wap-wsp"                    	/* Abbreviated protocol name, should Match IANA 
+		"wap-wsp"                   	/* Abbreviated protocol name, should Match IANA 
 						    < URL:http://www.isi.edu/in-notes/iana/assignments/port-numbers/ >
 						  */
 	);
@@ -1815,7 +2140,7 @@ proto_register_wsp(void)
 	proto_register_field_array(proto_wsp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
 
-	register_dissector("wsp", dissect_wsp, proto_wsp);
+	register_dissector("wsp", dissect_wsp_fromwap, proto_wsp);
 };
 
 void
@@ -1827,7 +2152,42 @@ proto_reg_handoff_wsp(void)
 	wmlc_handle = find_dissector("wmlc");	/* Coming soon :) */
 
 	/* Only connection-less WSP has no previous handler */
-	dissector_add("udp.port", UDP_PORT_WSP, dissect_wsp, proto_wsp);
+	dissector_add("udp.port", UDP_PORT_WSP, dissect_wsp_fromudp, proto_wsp);
 
 	/* This dissector is also called from the WTP and WTLS dissectors */
 }
+
+static gint get_long_integer (tvbuff_t *tvb, guint *offset, guint offset_end, guint *value)
+{
+	guint valueLength;
+
+	valueLength = tvb_get_guint8(tvb,*offset);
+	if ((valueLength+*offset) > offset_end)
+	{
+		*value = 0;
+		return (-1);
+	}
+	(*offset)++;
+	switch (valueLength)
+	{
+		case 1:
+			*value = tvb_get_guint8(tvb,*offset);
+			break;
+		case 2:
+			*value = tvb_get_ntohs(tvb,*offset);
+			break;
+		case 3:
+		        *value = tvb_get_ntoh24(tvb,*offset);
+			break;
+		case 4:
+			*value = tvb_get_ntohl(tvb,*offset);
+			break;
+		default:
+		        /* TODO: Need to read peek octets */
+		        *value = 0;
+		        fprintf (stderr, "dissect_wsp: get_long_integer size %d NYI\n", valueLength);
+	        	break;
+	}
+	(*offset) += valueLength;
+	return 0;
+}
