@@ -2,7 +2,7 @@
  *
  * Routines to dissect WTP component of WAP traffic.
  * 
- * $Id: packet-wtp.c,v 1.13 2001/04/17 18:57:09 guy Exp $
+ * $Id: packet-wtp.c,v 1.15 2001/07/03 09:53:22 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -180,7 +180,7 @@ static char retransmission_indicator(unsigned char octet);
 
 /* Code to actually dissect the packets */
 static void
-dissect_wtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+dissect_wtp_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	frame_data *fdata = pinfo->fd;
 
@@ -212,27 +212,10 @@ dissect_wtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int i;
 	tvbuff_t *wsp_tvb = NULL;
 
-/* Make entries in Protocol column and Info column of summary display */
-
 #ifdef DEBUG
 	fprintf( stderr, "dissect_wtp: (Entering) Frame data at %p\n", fdata ); 
 	fprintf( stderr, "dissect_wtp: tvb length is %d\n", tvb_reported_length( tvb ) ); 
 #endif
-	/* Display protocol type depending on the port */
-	if (check_col(fdata, COL_PROTOCOL)) 
-	{
-		switch ( pinfo->match_port )
-		{
-			case UDP_PORT_WTP_WSP:
-				col_add_fstr(fdata, COL_PROTOCOL, "WTP+WSP" );
-				break;
-			case UDP_PORT_WTLS_WTP_WSP:
-				col_add_fstr(fdata, COL_PROTOCOL, "WTLS+WTP+WSP" );
-				break;
-			default:
-				break;
-		}
-	}
 	if (check_col(fdata, COL_INFO)) {
 		col_clear(fdata, COL_INFO);
 	};
@@ -428,7 +411,7 @@ dissect_wtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		fprintf( stderr, "dissect_wtp: (4) tree was %p\n", tree ); 
 #endif
 	}
-		
+
 	/* Any remaining data ought to be WSP data,
 	 * so hand off to the WSP dissector */
 	if (tvb_reported_length (tvb) > cbHeader)
@@ -443,6 +426,37 @@ dissect_wtp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 #endif
 }
 
+/*
+ * Called directly from UDP.
+ * Put "WTP+WSP" into the "Protocol" column.
+ */
+static void
+dissect_wtp_fromudp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	if (check_col(pinfo->fd, COL_PROTOCOL))
+		col_set_str(pinfo->fd, COL_PROTOCOL, "WTP+WSP" );
+
+	dissect_wtp_common(tvb, pinfo, tree);
+}
+
+/*
+ * Called from a higher-level WAP dissector, presumably WTLS.
+ * Put "WTLS+WSP+WTP" to the "Protocol" column.
+ *
+ * XXX - is this supposed to be called from WTLS?  If so, we're not
+ * calling it....
+ *
+ * XXX - can this be called from any other dissector?
+ */
+static void
+dissect_wtp_fromwap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+	if (check_col(pinfo->fd, COL_PROTOCOL))
+		col_set_str(pinfo->fd, COL_PROTOCOL, "WTLS+WTP+WSP" );
+
+	dissect_wtp_common(tvb, pinfo, tree);
+}
+
 static char pdu_type(unsigned char octet)
 {
 	char ch = (octet >> 3) & 0x0F;
@@ -482,105 +496,105 @@ proto_register_wtp(void)
 			{ 	"Header",           
 				"wtp.header_fixed_part",
 				FT_BYTES, BASE_HEX, NULL, 0x0,          
-				"Fixed part of the header" 
+				"Fixed part of the header", HFILL
 			}
 		},
 		{ &hf_wtp_header_flag_continue,
 			{ 	"Continue Flag",           
 				"wtp.continue_flag",
 				FT_BOOLEAN, 8, TFS( &continue_truth ), 0x80,          
-				"Continue Flag" 
+				"Continue Flag", HFILL
 			}
 		},
 		{ &hf_wtp_header_pdu_type,
 			{ 	"PDU Type",           
 				"wtp.pdu_type",
 				 FT_UINT8, BASE_HEX, VALS( vals_pdu_type ), 0x78,
-				"PDU Type" 
+				"PDU Type", HFILL
 			}
 		},
 		{ &hf_wtp_header_flag_Trailer,
 			{ 	"Trailer Flags",           
 				"wtp.trailer_flags",
 				 FT_UINT8, BASE_HEX, VALS( vals_transmission_trailer ), 0x06,
-				"PDU Type" 
+				"PDU Type", HFILL
 			}
 		},
 		{ &hf_wtp_header_flag_RID,
 			{ 	"Re-transmission Indicator",           
 				"wtp.RID",
 				 FT_BOOLEAN, 8, TFS( &RID_truth ), 0x01,
-				"Re-transmission Indicator" 
+				"Re-transmission Indicator", HFILL
 			}
 		},
 		{ &hf_wtp_header_flag_TID_response,
 			{ 	"TID Response",           
 				"wtp.TID.response",
 				FT_BOOLEAN, 16, TFS( &tid_response_truth ), 0x8000,
-				"TID Response" 
+				"TID Response", HFILL
 			}
 		},
 		{ &hf_wtp_header_flag_TID,
 			{ 	"Transmission ID",           
 				"wtp.TID",
 				 FT_UINT16, BASE_HEX, NULL, 0x7FFF,
-				"Transmission ID" 
+				"Transmission ID", HFILL
 			}
 		},
 		{ &hf_wtp_header_Inv_version,
 			{ 	"Version",           
 				"wtp.header.version",
 				 FT_UINT8, BASE_HEX, VALS( vals_version ), 0xC0,
-				"Version" 
+				"Version", HFILL
 			}
 		},
 		{ &hf_wtp_header_Inv_flag_TIDNew,
 			{ 	"TIDNew",           
 				"wtp.header.TIDNew",
 				 FT_BOOLEAN, 8, TFS( &TIDNew_truth ), 0x20,
-				"TIDNew" 
+				"TIDNew", HFILL
 			}
 		},
 		{ &hf_wtp_header_Inv_flag_UP,
 			{ 	"U/P flag",           
 				"wtp.header.UP",
 				 FT_BOOLEAN, 8, TFS( &UP_truth ), 0x10,
-				"U/P Flag" 
+				"U/P Flag", HFILL
 			}
 		},
 		{ &hf_wtp_header_Inv_Reserved,
 			{ 	"Reserved",           
 				"wtp.inv.reserved",
 				 FT_UINT8, BASE_HEX, NULL, 0x0C,
-				"Reserved" 
+				"Reserved", HFILL
 			}
 		},
 		{ &hf_wtp_header_Inv_TransactionClass,
 			{ 	"Transaction Class",           
 				"wtp.inv.transaction_class",
 				 FT_UINT8, BASE_HEX, NULL, 0x03,
-				"Transaction Class" 
+				"Transaction Class", HFILL
 			}
 		},
 		{ &hf_wtp_header_Ack_flag_TVETOK,
 			{ 	"Tve/Tok flag",           
 				"wtp.ack.tvetok",
 				 FT_BOOLEAN, 8, TFS( &TVETOK_truth ), 0x04,
-			 	"Tve/Tok flag"
+			 	"Tve/Tok flag", HFILL
 			}
 		},
 		{ &hf_wtp_header_Abort_type,
 			{ 	"Abort Type",           
 				"wtp.abort.type",
 				 FT_UINT8, BASE_HEX, VALS ( vals_abort_type ), 0x07,
-				"Abort Type" 
+				"Abort Type", HFILL
 			}
 		},
 		{ &hf_wtp_header_Abort_reason_provider,
 			{ 	"Abort Reason",           
 				"wtp.abort.reason.provider",
 				 FT_UINT8, BASE_HEX, VALS ( vals_abort_reason_provider ), 0x00,
-				"Abort Reason" 
+				"Abort Reason", HFILL
 			}
 		},
 		/* Assume WSP is the user and use its reason codes */
@@ -588,35 +602,35 @@ proto_register_wtp(void)
 			{ 	"Abort Reason",           
 				"wtp.abort.reason.user",
 				 FT_UINT8, BASE_HEX, VALS ( vals_wsp_reason_codes ), 0x00,
-				"Abort Reason" 
+				"Abort Reason", HFILL
 			}
 		},
 		{ &hf_wtp_header_sequence_number,
 			{ 	"Packet Sequence Number",           
 				"wtp.header.sequence",
 				 FT_UINT8, BASE_HEX, NULL, 0x00,
-				"Packet Sequence Number" 
+				"Packet Sequence Number", HFILL
 			}
 		},
 		{ &hf_wtp_header_missing_packets,
 			{ 	"Missing Packets",           
 				"wtp.header.missing_packets",
 				 FT_UINT8, BASE_HEX, NULL, 0x00,
-				"Missing Packets" 
+				"Missing Packets", HFILL
 			}
 		},
 		{ &hf_wtp_header_variable_part,
 			{ 	"Header: Variable part",           
 				"wtp.header_variable_part",
 				FT_BYTES, BASE_HEX, NULL, 0x0,          
-				"Variable part of the header" 
+				"Variable part of the header", HFILL
 			}
 		},
 		{ &hf_wtp_data,
 			{ 	"Data",           
 				"wtp.header_data",
 				FT_BYTES, BASE_HEX, NULL, 0x0,          
-				"Data" 
+				"Data", HFILL
 			}
 		},
 	};
@@ -631,7 +645,7 @@ proto_register_wtp(void)
 	proto_wtp = proto_register_protocol(
 		"Wireless Transaction Protocol",   /* protocol name for use by ethereal */ 
 		"WTP",                             /* short version of name */
-		"wap-wsp-wtp"                    /* Abbreviated protocol name, should Match IANA 
+		"wap-wsp-wtp"                      /* Abbreviated protocol name, should Match IANA 
 						    < URL:http://www.isi.edu/in-notes/iana/assignments/port-numbers/ >
 						  */
 	);
@@ -639,6 +653,8 @@ proto_register_wtp(void)
 /* Required function calls to register the header fields and subtrees used */
 	proto_register_field_array(proto_wtp, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
+
+	register_dissector("wtp", dissect_wtp_fromwap, proto_wtp);
 };
 
 void
@@ -649,5 +665,6 @@ proto_reg_handoff_wtp(void)
 	 */
 	wsp_handle = find_dissector("wsp");
 
-	dissector_add("udp.port", UDP_PORT_WTP_WSP, dissect_wtp, proto_wtp);
+	dissector_add("udp.port", UDP_PORT_WTP_WSP, dissect_wtp_fromudp,
+	    proto_wtp);
 }
