@@ -3,7 +3,7 @@
  *
  * Jochen Friedrich <jochen@scram.de>
  *
- * $Id: packet-zebra.c,v 1.12 2001/04/23 04:29:54 guy Exp $
+ * $Id: packet-zebra.c,v 1.13 2001/06/18 02:17:58 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -529,111 +529,111 @@ proto_register_zebra(void)
     { &hf_zebra_len,
       { "Length",		"zebra.len",
 	FT_UINT16, BASE_DEC, NULL, 0x0,
-	"Length of ZEBRA request" }},
+	"Length of ZEBRA request", HFILL }},
     { &hf_zebra_request,
       { "Request",		"zebra.request",
 	FT_BOOLEAN, BASE_NONE, NULL, 0x0,
-	"TRUE if ZEBRA request" }},
+	"TRUE if ZEBRA request", HFILL }},
     { &hf_zebra_command,
       { "Command",		"zebra.command",
 	FT_UINT8, BASE_DEC, VALS(messages), 0x0,
-	"ZEBRA command" }},
+	"ZEBRA command", HFILL }},
     { &hf_zebra_interface,
       { "Interface",		"zebra.interface",
 	FT_STRING, BASE_NONE, NULL, 0x0,
-	"Interface name of ZEBRA request" }},
+	"Interface name of ZEBRA request", HFILL }},
     { &hf_zebra_index,
       { "Index",		"zebra.index",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Index of interface" }},
+	"Index of interface", HFILL }},
     { &hf_zebra_indexnum,
       { "Index Number",		"zebra.indexnum",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Number of indices for route" }},
+	"Number of indices for route", HFILL }},
     { &hf_zebra_intflags,
       { "Flags",		"zebra.intflags",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Flags of interface" }},
+	"Flags of interface", HFILL }},
     { &hf_zebra_rtflags,
       { "Flags",		"zebra.rtflags",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Flags of route" }},
+	"Flags of route", HFILL }},
     { &hf_zebra_message,
       { "Message",		"zebra.message",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Message type of route" }},
+	"Message type of route", HFILL }},
     { &hf_zebra_msg_nexthop,
       { "Message Nexthop",	"zebra.message.nexthop",
 	FT_BOOLEAN, 8, NULL, ZEBRA_ZAPI_MESSAGE_NEXTHOP,
-	"Message contains nexthop" }},
+	"Message contains nexthop", HFILL }},
     { &hf_zebra_msg_index,
       { "Message Index",	"zebra.message.index",
 	FT_BOOLEAN, 8, NULL, ZEBRA_ZAPI_MESSAGE_IFINDEX,
-	"Message contains index" }},
+	"Message contains index", HFILL }},
     { &hf_zebra_msg_distance,
       { "Message Distance",	"zebra.message.distance",
 	FT_BOOLEAN, 8, NULL, ZEBRA_ZAPI_MESSAGE_DISTANCE,
-	"Message contains distance" }},
+	"Message contains distance", HFILL }},
     { &hf_zebra_msg_metric,
       { "Message Metric",	"zebra.message.metric",
 	FT_BOOLEAN, 8, NULL, ZEBRA_ZAPI_MESSAGE_METRIC,
-	"Message contains metric" }},
+	"Message contains metric", HFILL }},
     { &hf_zebra_type,
       { "Type",			"zebra.type",
 	FT_UINT8, BASE_DEC, VALS(routes), 0x0,
-	"Type of route" }},
+	"Type of route", HFILL }},
     { &hf_zebra_distance,
       { "Distance",		"zebra.distance",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Distance of route" }},
+	"Distance of route", HFILL }},
     { &hf_zebra_metric,
       { "Metric",		"zebra.metric",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Metric of interface or route" }},
+	"Metric of interface or route", HFILL }},
     { &hf_zebra_mtu,
       { "MTU",			"zebra.mtu",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"MTU of interface" }},
+	"MTU of interface", HFILL }},
     { &hf_zebra_bandwidth,
       { "Bandwidth",		"zebra.bandwidth",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Bandwidth of interface" }},
+	"Bandwidth of interface", HFILL }},
     { &hf_zebra_family,
       { "Family",		"zebra.family",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Family of IP address" }},
+	"Family of IP address", HFILL }},
     { &hf_zebra_dest4,
       { "Destination",		"zebra.dest4",
 	FT_IPv4, BASE_NONE, NULL, 0x0,
-	"Destination IPv4 field" }},
+	"Destination IPv4 field", HFILL }},
     { &hf_zebra_dest6,
       { "Destination",		"zebra.dest6",
 	FT_IPv6, BASE_NONE, NULL, 0x0,
-	"Destination IPv6 field" }},
+	"Destination IPv6 field", HFILL }},
     { &hf_zebra_nexthopnum,
       { "Nexthop Number",	"zebra.nexthopnum",
 	FT_UINT8, BASE_DEC, NULL, 0x0,
-	"Number of nexthops in route" }},
+	"Number of nexthops in route", HFILL }},
     { &hf_zebra_nexthop4,
       { "Nexthop",		"zebra.nexthop4",
 	FT_IPv4, BASE_NONE, NULL, 0x0,
-	"Nethop IPv4 field of route" }},
+	"Nethop IPv4 field of route", HFILL }},
     { &hf_zebra_nexthop6,
       { "Nexthop",		"zebra.nexthop6",
 	FT_IPv6, BASE_NONE, NULL, 0x0,
-	"Nethop IPv6 field of route" }},
+	"Nethop IPv6 field of route", HFILL }},
     { &hf_zebra_prefixlen,
       { "Prefix length",	"zebra.prefixlen",
 	FT_UINT32, BASE_DEC, NULL, 0x0,
-	"Prefix length" }},
+	"Prefix length", HFILL }},
     { &hf_zebra_prefix4,
       { "Prefix",		"zebra.prefix4",
 	FT_IPv4, BASE_NONE, NULL, 0x0,
-	"Prefix IPv4" }},
+	"Prefix IPv4", HFILL }},
     { &hf_zebra_prefix6,
       { "Prefix",		"zebra.prefix6",
 	FT_IPv6, BASE_NONE, NULL, 0x0,
-	"Prefix IPv6" }},
+	"Prefix IPv6", HFILL }},
   };
 
   static gint *ett[] = {
