@@ -2,7 +2,7 @@
  * Routines for mgcp packet disassembly
  * RFC 2705
  *
- * $Id: packet-mgcp.c,v 1.21 2001/04/23 04:12:51 guy Exp $
+ * $Id: packet-mgcp.c,v 1.26 2001/07/08 21:51:34 hagbard Exp $
  * 
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  *
@@ -51,14 +51,16 @@
 #include "prefs.h"
 #include "strutil.h"
 
+#ifndef __ETHEREAL_STATIC__
 G_MODULE_EXPORT const gchar version[] = VERSION;
+#endif
 
 #define TCP_PORT_MGCP_GATEWAY 2427
 #define UDP_PORT_MGCP_GATEWAY 2427
 #define TCP_PORT_MGCP_CALLAGENT 2727
 #define UDP_PORT_MGCP_CALLAGENT 2727
 
-static void proto_reg_handoff_mgcp(void);
+void proto_reg_handoff_mgcp(void);
 
 
 /* Define the mgcp proto */
@@ -388,109 +390,109 @@ proto_register_mgcp(void)
   static hf_register_info hf[] = {
     { &hf_mgcp_req,
       { "Request", "mgcp.req", FT_BOOLEAN, BASE_NONE, NULL, 0x0, 
-	"True if MGCP request" }},
+	"True if MGCP request", HFILL }},
     { &hf_mgcp_rsp,
       { "Response", "mgcp.rsp", FT_BOOLEAN, BASE_NONE, NULL, 0x0, 
-	"TRUE if MGCP response" }},
+	"TRUE if MGCP response", HFILL }},
     { &hf_mgcp_req_verb,
       { "Verb", "mgcp.req.verb", FT_STRING, BASE_DEC, NULL, 0x0, 
-	"Name of the verb"}},
+	"Name of the verb", HFILL }},
     { &hf_mgcp_req_endpoint,
       { "Endpoint", "mgcp.req.endpoint", FT_STRING, BASE_DEC, NULL, 0x0,
-	"Endpoint referenced by the message"}},
+	"Endpoint referenced by the message", HFILL }},
     { &hf_mgcp_transid,
       { "Transaction ID", "mgcp.transid", FT_STRING, BASE_DEC, NULL, 0x0,
-	"Transaction ID of this message"}},
+	"Transaction ID of this message", HFILL }},
     { &hf_mgcp_version, 
       { "Version", "mgcp.version", FT_STRING, BASE_DEC, NULL, 0x0,
-	"MGCP Version"}},
+	"MGCP Version", HFILL }},
     { &hf_mgcp_rsp_rspcode, 
       { "Response Code", "mgcp.rsp.rspcode", FT_STRING, BASE_DEC, NULL, 0x0,
-	"Response Code"}},
+	"Response Code", HFILL }},
     { &hf_mgcp_rsp_rspstring,
       { "Response String", "mgcp.rsp.rspstring", FT_STRING, BASE_DEC, NULL, 
-	0x0, "Response String"}},
+	0x0, "Response String", HFILL }},
     { &hf_mgcp_param_rspack,
       { "ResponseAck (K)", "mgcp.param.rspack", FT_STRING, BASE_DEC, NULL,
-	0x0, "Response Ack"}},
+	0x0, "Response Ack", HFILL }},
     { &hf_mgcp_param_bearerinfo,
       { "BearerInformation (B)", "mgcp.param.bearerinfo", FT_STRING, BASE_DEC, 
-	NULL, 0x0, "Bearer Information"}},
+	NULL, 0x0, "Bearer Information", HFILL }},
     { &hf_mgcp_param_callid,
       { "CallId (C)", "mgcp.param.callid", FT_STRING, BASE_DEC, NULL, 0x0,
-	"Call Id"}},
+	"Call Id", HFILL }},
     { &hf_mgcp_param_connectionid,
       {"ConnectionIdentifier (I)", "mgcp.param.connectionid", FT_STRING, 
-       BASE_DEC, NULL, 0x0, "Connection Identifier"}},
+       BASE_DEC, NULL, 0x0, "Connection Identifier", HFILL }},
     { &hf_mgcp_param_secondconnectionid,
       { "SecondConnectionID (I2)", "mgcp.param.secondconnectionid", FT_STRING, 
-       BASE_DEC, NULL, 0x0, "Second Connection Identifier"}},
+       BASE_DEC, NULL, 0x0, "Second Connection Identifier", HFILL }},
     { &hf_mgcp_param_notifiedentity,
       { "NotifiedEntity (N)", "mgcp.param.notifiedentity", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Notified Entity"}},
+	NULL, 0x0, "Notified Entity", HFILL }},
     { &hf_mgcp_param_requestid,
       { "RequestIdentifier (X)", "mgcp.param.requestid", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Request Identifier"}},
+	NULL, 0x0, "Request Identifier", HFILL }},
     { &hf_mgcp_param_localconnoptions,
       { "LocalConnectionOptions (L)", "mgcp.param.localconnectionoptions", 
-	FT_STRING, BASE_DEC, NULL, 0x0, "Local Connection Options"}},
+	FT_STRING, BASE_DEC, NULL, 0x0, "Local Connection Options", HFILL }},
     { &hf_mgcp_param_connectionmode,
       { "ConnectionMode (M)", "mgcp.param.connectionmode", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Connection Mode" }},
+	NULL, 0x0, "Connection Mode", HFILL }},
     { &hf_mgcp_param_reqevents,
       { "RequestedEvents (R)", "mgcp.param.reqevents", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Requested Events"}},
+	NULL, 0x0, "Requested Events", HFILL }},
     { &hf_mgcp_param_signalreq,
       { "SignalRequests (S)", "mgcp.param.signalreq", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Signal Request"}},
+	NULL, 0x0, "Signal Request", HFILL }},
     { &hf_mgcp_param_restartmethod, 
       { "RestartMethod (RM)", "mgcp.param.restartmethod", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Restart Method"}},
+	NULL, 0x0, "Restart Method", HFILL }},
     { &hf_mgcp_param_restartdelay,
       { "RestartDelay (RD)", "mgcp.param.restartdelay", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Restart Delay"}},
+	NULL, 0x0, "Restart Delay", HFILL }},
     { &hf_mgcp_param_digitmap, 
       { "DigitMap (D)", "mgcp.param.digitmap", FT_STRING, BASE_DEC, NULL, 0x0,
-	"Digit Map"}},
+	"Digit Map", HFILL }},
     { &hf_mgcp_param_observedevent, 
       { "ObservedEvents (O)", "mgcp.param.observedevents", FT_STRING, 
-	BASE_DEC, NULL, 0x0, "Observed Events"}},
+	BASE_DEC, NULL, 0x0, "Observed Events", HFILL }},
     { &hf_mgcp_param_connectionparam,
       { "ConnectionParameters (P)", "mgcp.param.connectionparam", FT_STRING, 
-	BASE_DEC, NULL, 0x0, "Connection Parameters"}},
+	BASE_DEC, NULL, 0x0, "Connection Parameters", HFILL }},
     { &hf_mgcp_param_reasoncode,
       { "ReasonCode (E)", "mgcp.param.reasoncode", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Reason Code"}},
+	NULL, 0x0, "Reason Code", HFILL }},
     { &hf_mgcp_param_eventstates,
       { "EventStates (ES)", "mgcp.param.eventstates", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Event States"}},
+	NULL, 0x0, "Event States", HFILL }},
     { &hf_mgcp_param_specificendpoint,
       { "SpecificEndpointID (Z)", "mgcp.param.specificendpointid", FT_STRING,
-	BASE_DEC, NULL, 0x0, "Specific Endpoint ID"}},
+	BASE_DEC, NULL, 0x0, "Specific Endpoint ID", HFILL }},
     { &hf_mgcp_param_secondendpointid,
       { "SecondEndpointID (Z2)", "mgcp.param.secondendpointid", FT_STRING,
-	BASE_DEC, NULL, 0x0, "Second Endpoing ID"}},
+	BASE_DEC, NULL, 0x0, "Second Endpoing ID", HFILL }},
     { &hf_mgcp_param_reqinfo,
       { "RequestedInfo (F)", "mgcp.param.reqinfo", FT_STRING, BASE_DEC, 
-	NULL, 0x0,"Requested Info"}},
+	NULL, 0x0,"Requested Info", HFILL }},
     { &hf_mgcp_param_quarantinehandling, 
       { "QuarantineHandling (Q)", "mgcp.param.quarantinehandling", FT_STRING,
-	BASE_DEC, NULL, 0x0, "Quarantine Handling"}},
+	BASE_DEC, NULL, 0x0, "Quarantine Handling", HFILL }},
     { &hf_mgcp_param_detectedevents,
       { "DetectedEvents (T)", "mgcp.param.detectedevents", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Detected Events"}},
+	NULL, 0x0, "Detected Events", HFILL }},
     { &hf_mgcp_param_capabilities,
       { "Capabilities (A)", "mgcp.param.capabilities", FT_STRING, BASE_DEC,
-	NULL, 0x0, "Capabilities"}},
+	NULL, 0x0, "Capabilities", HFILL }},
     { &hf_mgcp_param_extention,
       { "Extention Parameter (X-*)", "mgcp.param.extention", FT_STRING, 
-	BASE_DEC, NULL, 0x0, "Extension Parameter"}},
+	BASE_DEC, NULL, 0x0, "Extension Parameter", HFILL }},
     { &hf_mgcp_param_invalid,
       { "Invalid Parameter", "mgcp.param.invalid", FT_STRING, 
-	BASE_DEC, NULL, 0x0, "Invalid Parameter"}},
+	BASE_DEC, NULL, 0x0, "Invalid Parameter", HFILL }},
     { &hf_mgcp_messagecount, 
       { "MGCP Message Count", "mgcp.messagecount", FT_UINT32, 
-	BASE_DEC, NULL, 0x0, "Number of MGCP message in a packet"}},
+	BASE_DEC, NULL, 0x0, "Number of MGCP message in a packet", HFILL }},
     /* Add more fields here */
   };
   static gint *ett[] = {
@@ -557,11 +559,16 @@ proto_register_mgcp(void)
 }
 
 /* The registration hand-off routine */
-static void
+void
 proto_reg_handoff_mgcp(void)
 {
   static int mgcp_prefs_initialized = FALSE;
 
+  /*
+   * Get a handle for the SDP dissector.
+   */
+  sdp_handle = find_dissector("sdp");
+
   if (mgcp_prefs_initialized) {
     dissector_delete("tcp.port", gateway_tcp_port, dissect_mgcp);
     dissector_delete("udp.port", gateway_udp_port, dissect_mgcp);
@@ -835,14 +842,15 @@ static gint tvb_parse_param(tvbuff_t* tvb, gint offset, gint len, int** hf){
       tvb_current_offset++;
       tvb_current_offset = tvb_skip_wsp(tvb,tvb_current_offset,
 					(len - tvb_current_offset + offset));
-      if(len > tvb_current_offset - offset){
-	returnvalue = tvb_current_offset;
-      }
+      returnvalue = tvb_current_offset;
     }
     else {
       *hf = &hf_mgcp_param_invalid;
     }
   }
+  else{
+    *hf = &hf_mgcp_param_invalid;
+  }
   if(*hf == &hf_mgcp_param_invalid){
     returnvalue = offset;
   }
@@ -1242,14 +1250,12 @@ static gint tvb_find_dot_line(tvbuff_t* tvb, gint offset,
 }
 
 /* Start the functions we need for the plugin stuff */
+
+#ifndef __ETHEREAL_STATIC__
+
 G_MODULE_EXPORT void
 plugin_reg_handoff(void){
   proto_reg_handoff_mgcp();
-
-  /*
-   * Get a handle for the SDP dissector.
-   */
-  sdp_handle = find_dissector("sdp");
 }
 
 G_MODULE_EXPORT void
@@ -1261,4 +1267,9 @@ plugin_init(plugin_address_table_t *pat){
     proto_register_mgcp();
   }
 }
+
+#endif
+
 /* End the functions we need for plugin stuff */
+
+
