@@ -1,7 +1,7 @@
 /* plugin_table.h
  * Table of exported addresses for Ethereal plugins.
  *
- * $Id: plugin_table.h,v 1.18 2001/04/02 09:55:34 guy Exp $
+ * $Id: plugin_table.h,v 1.20 2001/04/25 08:41:22 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * Copyright 2000 by Gilbert Ramirez <gram@xiexie.org>
@@ -36,14 +36,13 @@ typedef void (*addr_col_add_fstr)(frame_data*, gint, gchar*, ...);
 typedef void (*addr_col_append_fstr)(frame_data*, gint, gchar*, ...);
 typedef void (*addr_col_add_str)(frame_data*, gint, const gchar*);
 typedef void (*addr_col_append_str)(frame_data*, gint, gchar*);
+typedef void (*addr_col_set_str)(frame_data*, gint, gchar*);
 
 typedef int (*addr_proto_register_protocol)(char*, char*, char*);
 typedef void (*addr_proto_register_field_array)(int, hf_register_info*, int);
 typedef void (*addr_proto_register_subtree_array)(int**, int);
 
 typedef void (*addr_dissector_add)(const char *, guint32, dissector_t, int);
-typedef void (*addr_old_dissector_add)(const char *, guint32, old_dissector_t,
-    int);
 typedef void (*addr_dissector_delete)(const char *, guint32, dissector_t);
 
 typedef void (*addr_heur_dissector_add)(const char *, heur_dissector_t, int);
@@ -54,7 +53,6 @@ typedef void (*addr_call_dissector)(dissector_handle_t, tvbuff_t *,
     packet_info *, proto_tree *);
 
 typedef void (*addr_dissect_data)(tvbuff_t *, int, packet_info *, proto_tree *);
-typedef void (*addr_old_dissect_data)(const u_char *, int, frame_data *, proto_tree *);
 
 typedef gboolean (*addr_proto_is_protocol_enabled)(int);
 
@@ -120,6 +118,7 @@ typedef guint (*addr_tvb_length_remaining)(tvbuff_t*, gint);
 typedef gboolean (*addr_tvb_bytes_exist)(tvbuff_t*, gint, gint);
 typedef gboolean (*addr_tvb_offset_exists)(tvbuff_t*, gint);
 typedef guint (*addr_tvb_reported_length)(tvbuff_t*);
+typedef guint (*addr_tvb_reported_length_remaining)(tvbuff_t*, gint);
 
 typedef guint8 (*addr_tvb_get_guint8)(tvbuff_t*, gint);
 
@@ -177,6 +176,7 @@ typedef struct  {
 	addr_col_append_fstr			p_col_append_fstr;
 	addr_col_add_str			p_col_add_str;
 	addr_col_append_str			p_col_append_str;
+	addr_col_set_str			p_col_set_str;
 
 	packet_info				*p_pi;
 
@@ -185,7 +185,6 @@ typedef struct  {
 	addr_proto_register_subtree_array	p_proto_register_subtree_array;
 
 	addr_dissector_add			p_dissector_add;
-	addr_old_dissector_add			p_old_dissector_add;
 	addr_dissector_delete			p_dissector_delete;
 
 	addr_heur_dissector_add			p_heur_dissector_add;
@@ -195,7 +194,6 @@ typedef struct  {
 	addr_call_dissector			p_call_dissector;
 
 	addr_dissect_data			p_dissect_data;
-	addr_old_dissect_data			p_old_dissect_data;
 
 	addr_proto_is_protocol_enabled		p_proto_is_protocol_enabled;
 
@@ -249,6 +247,7 @@ typedef struct  {
 	addr_tvb_bytes_exist			p_tvb_bytes_exist;
 	addr_tvb_offset_exists			p_tvb_offset_exists;
 	addr_tvb_reported_length		p_tvb_reported_length;
+	addr_tvb_reported_length_remaining	p_tvb_reported_length_remaining;
 
 	addr_tvb_get_guint8			p_tvb_get_guint8;
 
