@@ -1,14 +1,13 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c,v 1.32 2001/03/24 23:49:14 guy Exp $
+ * $Id: print.c,v 1.36 2001/06/18 01:49:17 guy Exp $
  *
  * Gilbert Ramirez <gram@xiexie.org>
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
- *
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,6 +39,7 @@
 #include "print.h"
 #include "ps.h"
 #include "util.h"
+#include "tvbuff.h"
 
 static void proto_tree_print_node_text(GNode *node, gpointer data);
 static void proto_tree_print_node_ps(GNode *node, gpointer data);
@@ -56,7 +56,7 @@ extern int proto_data; /* in packet-data.c */
 typedef struct {
 	int		level;
 	FILE		*fh;
-	const guint8	*pd;
+	GSList		*src_list;
 	gboolean	print_all_levels;
 	gboolean	print_hex_for_data;
 	char_enc	encoding;
@@ -97,14 +97,14 @@ void print_finale(FILE *fh, gint format)
 }
 
 void proto_tree_print(gboolean print_one_packet, print_args_t *print_args,
-    GNode *protocol_tree, const u_char *pd, frame_data *fd, FILE *fh)
+    GNode *protocol_tree, frame_data *fd, FILE *fh)
 {
 	print_data data;
 
 	/* Create the output */
 	data.level = 0;
 	data.fh = fh;
-	data.pd = pd;
+	data.src_list = fd->data_src;
 	data.encoding = fd->flags.encoding;
 	data.print_all_levels = print_args->expand_all;
 	data.print_hex_for_data = !print_args->print_hex;
@@ -120,6 +120,29 @@ void proto_tree_print(gboolean print_one_packet, print_args_t *print_args,
 	}
 }
 
+/*
+ * Find the data source tvbuff with a specified name, and return a
+ * pointer to the data in it.
+ */
+static const guint8 *
+get_field_data(GSList *src_list, field_info *fi)
+{
+	GSList *src;
+	tvbuff_t *src_tvb;
+
+	for (src = src_list; src != NULL; src = g_slist_next(src)) {
+		src_tvb = src->data;
+		if (strcmp(fi->ds_name, tvb_get_name(src_tvb)) == 0) {
+			/*
+			 * Found it.
+			 */
+			return tvb_get_ptr(src_tvb, fi->start, fi->length);
+		}
+	}
+	g_assert_not_reached();
+	return NULL;	/* not found */
+}
+
 /* Print a tree's data, and any child nodes, in plain text */
 static
 void proto_tree_print_node_text(GNode *node, gpointer data)
@@ -129,6 +152,7 @@ void proto_tree_print_node_text(GNode *node, gpointer data)
 	int		i;
 	int		num_spaces;
 	char		space[41];
+	const guint8	*pd;
 	gchar		label_str[ITEM_LABEL_LENGTH];
 	gchar		*label_ptr;
 
@@ -161,9 +185,13 @@ void proto_tree_print_node_text(GNode *node, gpointer data)
 
 	/* If it's uninterpreted data, dump it (unless our caller will
 	   be printing the entire packet in hex). */
-	if (fi->hfinfo->id == proto_data && pdata->print_hex_for_data)
-		print_hex_data_text(pdata->fh, &pdata->pd[fi->start],
-				fi->length, pdata->encoding);
+	if (fi->hfinfo->id == proto_data && pdata->print_hex_for_data) {
+		/*
+		 * Find the data for this field.
+		 */
+		pd = get_field_data(pdata->src_list, fi);
+		print_hex_data_text(pdata->fh, pd, fi->length, pdata->encoding);
+	}
 
 	/* If we're printing all levels, or if this level is expanded,
 	   recurse into the subtree, if it exists. */
@@ -221,9 +249,9 @@ static
 void print_hex_data_text(FILE *fh, register const u_char *cp,
 		register u_int length, char_enc encoding)
 {
-        register int ad, i, j, k;
+        register unsigned int ad, i, j, k;
         u_char c;
-        u_char line[60];
+        u_char line[80];
 	static u_char binhex[16] = {
 		'0', '1', '2', '3', '4', '5', '6', '7',
 		'8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
@@ -234,13 +262,13 @@ void print_hex_data_text(FILE *fh, register const u_char *cp,
                 c = *cp++;
                 line[j++] = binhex[c>>4];
                 line[j++] = binhex[c&0xf];
-                if (i&1) j++;
+                j++;
 		if (encoding == CHAR_EBCDIC) {
 			c = EBCDIC_to_ASCII1(c);
 		}
-                line[42+k++] = c >= ' ' && c < 0x7f ? c : '.';
+                line[50+k++] = c >= ' ' && c < 0x7f ? c : '.';
                 if ((i & 15) == 15) {
-                        fprintf (fh, "\n%4x  %s", ad, line);
+                        fprintf (fh, "\n%04x  %s", ad, line);
                         /*if (i==15) printf (" %d", length);*/
                         memset (line, ' ', sizeof line);
                         line[sizeof (line)-1] = j = k = 0;
@@ -248,7 +276,7 @@ void print_hex_data_text(FILE *fh, register const u_char *cp,
                 }
         }
 
-        if (line[0] != ' ') fprintf (fh, "\n%4x  %s", ad, line);
+        if (line[0] != ' ') fprintf (fh, "\n%04x  %s", ad, line);
         fprintf(fh, "\n");
         return;
 
@@ -264,6 +292,7 @@ void proto_tree_print_node_ps(GNode *node, gpointer data)
 	print_data	*pdata = (print_data*) data;
 	gchar		label_str[ITEM_LABEL_LENGTH];
 	gchar		*label_ptr;
+	const guint8	*pd;
 	char		psbuffer[MAX_LINE_LENGTH]; /* static sized buffer! */
 
 	if (!fi->visible)
@@ -285,8 +314,11 @@ void proto_tree_print_node_ps(GNode *node, gpointer data)
 	/* If it's uninterpreted data, dump it (unless our caller will
 	   be printing the entire packet in hex). */
 	if (fi->hfinfo->id == proto_data && pdata->print_hex_for_data) {
-		print_hex_data_ps(pdata->fh, &pdata->pd[fi->start], fi->length,
-				pdata->encoding);
+		/*
+		 * Find the data for this field.
+		 */
+		pd = get_field_data(pdata->src_list, fi);
+		print_hex_data_ps(pdata->fh, pd, fi->length, pdata->encoding);
 	}
 
 	/* Recurse into the subtree, if it exists */
@@ -330,7 +362,7 @@ static
 void print_hex_data_ps(FILE *fh, register const u_char *cp,
 		register u_int length, char_enc encoding)
 {
-        register int ad, i, j, k;
+        register unsigned int ad, i, j, k;
         u_char c;
         u_char line[60];
 	static u_char binhex[16] = {
