@@ -1,6 +1,6 @@
 /* iptrace.c
  *
- * $Id: iptrace.c,v 1.32 2000/09/21 04:41:30 gram Exp $
+ * $Id: iptrace.c,v 1.33 2001/03/10 06:33:57 guy Exp $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@xiexie.org>
@@ -52,8 +52,6 @@ int iptrace_open(wtap *wth, int *err)
 	int bytes_read;
 	char name[12];
 
-	file_seek(wth->fh, 0, SEEK_SET);
-	wth->data_offset = 0;
 	errno = WTAP_ERR_CANT_READ;
 	bytes_read = file_read(name, 1, 11, wth->fh);
 	if (bytes_read != 11) {
