@@ -1,6 +1,6 @@
 /* netmon.c
  *
- * $Id: netmon.c,v 1.37 2001/03/10 06:33:57 guy Exp $
+ * $Id: netmon.c,v 1.38 2001/07/13 00:55:58 guy Exp $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@xiexie.org>
@@ -126,7 +126,7 @@ int netmon_open(wtap *wth, int *err)
 	int frame_table_size;
 	guint32 *frame_table;
 #ifdef WORDS_BIGENDIAN
-	int i;
+	unsigned int i;
 #endif
 
 	/* Read in the string that should be at the start of a Network
